<?php

/**
 * Edit User Page
 * Allows administrators to edit existing users
 */
require_once '../includes/header.php';

// Check if user has admin privileges
if (!hasRole('admin')) {
    setFlashMessage('You do not have permission to access this page.', 'danger');
    redirect('index.php');
}

// Check if ID is provided
if (!isset($_GET['id']) || empty($_GET['id'])) {
    setFlashMessage('User ID is required.', 'danger');
    redirect('admin/users.php');
}

$userId = (int)$_GET['id'];

// Get user data
$sql = "SELECT * FROM users WHERE id = $userId";
$result = executeQuery($conn, $sql);

if (!$result || $result->num_rows === 0) {
    setFlashMessage('User not found.', 'danger');
    redirect('admin/users.php');
}

$user = $result->fetch_assoc();

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Sanitize input
    $fullName = sanitizeInput($conn, $_POST['full_name']);
    $email = sanitizeInput($conn, $_POST['email']);
    $role = sanitizeInput($conn, $_POST['role']);
    $active = isset($_POST['active']) ? 1 : 0;
    $changePassword = isset($_POST['change_password']) && $_POST['change_password'] === '1';
    $newPassword = $_POST['new_password'] ?? '';
    $confirmPassword = $_POST['confirm_password'] ?? '';

    // Validate input
    $errors = [];

    if (empty($fullName)) {
        $errors[] = 'Full name is required.';
    }

    if (empty($email)) {
        $errors[] = 'Email is required.';
    } elseif (!filter_var($email, FILTER_VALIDATE_EMAIL)) {
        $errors[] = 'Please enter a valid email address.';
    }

    if (empty($role)) {
        $errors[] = 'Role is required.';
    }

    // Check if email is already in use by another user
    $checkEmailSql = "SELECT COUNT(*) AS count FROM users WHERE email = '$email' AND id != $userId";
    $checkEmailResult = executeQuery($conn, $checkEmailSql);
    $checkEmail = $checkEmailResult->fetch_assoc();

    if ($checkEmail['count'] > 0) {
        $errors[] = 'Email is already in use by another user.';
    }

    // If changing password, validate it
    if ($changePassword) {
        if (empty($newPassword)) {
            $errors[] = 'New password is required.';
        } elseif (strlen($newPassword) < 8) {
            $errors[] = 'Password must be at least 8 characters long.';
        }

        if ($newPassword !== $confirmPassword) {
            $errors[] = 'Passwords do not match.';
        }
    }

    // If this is the only admin, don't allow changing role or deactivating
    if ($user['role'] === 'admin') {
        $adminCountSql = "SELECT COUNT(*) AS count FROM users WHERE role = 'admin' AND active = 1";
        $adminCountResult = executeQuery($conn, $adminCountSql);
        $adminCount = $adminCountResult->fetch_assoc();

        if ($adminCount['count'] <= 1 && ($role !== 'admin' || !$active)) {
            $errors[] = 'Cannot change role or deactivate the only admin user.';
        }
    }

    // If no errors, update user
    if (empty($errors)) {
        // Start building the SQL query
        $sql = "UPDATE users SET 
                full_name = '$fullName', 
                email = '$email', 
                role = '$role', 
                active = $active";

        // Add password update if needed
        if ($changePassword) {
            $hashedPassword = password_hash($newPassword, PASSWORD_DEFAULT);
            $sql .= ", password = '$hashedPassword'";
        }

        $sql .= " WHERE id = $userId";

        if (executeQuery($conn, $sql)) {
            logActivity('edit_user', "Updated user ID: $userId");

            setFlashMessage('User updated successfully.', 'success');
            redirect('admin/users.php');
        } else {
            $errors[] = 'Error updating user. Please try again.';
        }
    }
}
?>

<div class="d-flex justify-content-between align-items-center mb-4">
    <h1>Edit User</h1>
    <a href="users.php" class="btn btn-secondary">
        <i class="fas fa-arrow-left"></i> Back to Users
    </a>
</div>

<?php if (!empty($errors)): ?>
    <div class="alert alert-danger">
        <ul class="mb-0">
            <?php foreach ($errors as $error): ?>
                <li><?php echo $error; ?></li>
            <?php endforeach; ?>
        </ul>
    </div>
<?php endif; ?>

<div class="card shadow mb-4">
    <div class="card-header py-3">
        <h6 class="m-0 font-weight-bold text-primary">User Information</h6>
    </div>
    <div class="card-body">
        <form method="post" action="">
            <div class="row mb-3">
                <div class="col-md-6">
                    <label for="username" class="form-label">Username</label>
                    <input type="text" class="form-control" id="username" value="<?php echo htmlspecialchars($user['username']); ?>" disabled>
                    <small class="text-muted">Username cannot be changed</small>
                </div>
                <div class="col-md-6">
                    <label for="full_name" class="form-label">Full Name *</label>
                    <input type="text" class="form-control" id="full_name" name="full_name" value="<?php echo htmlspecialchars($user['full_name']); ?>" required>
                </div>
            </div>

            <div class="row mb-3">
                <div class="col-md-6">
                    <label for="email" class="form-label">Email Address *</label>
                    <input type="email" class="form-control" id="email" name="email" value="<?php echo htmlspecialchars($user['email']); ?>" required>
                </div>
                <div class="col-md-6">
                    <label for="role" class="form-label">Role *</label>
                    <select name="role" id="role" class="form-select" required>
                        <option value="">Select Role</option>
                        <option value="admin" <?php echo ($user['role'] === 'admin') ? 'selected' : ''; ?>>Administrator</option>
                        <option value="manager" <?php echo ($user['role'] === 'manager') ? 'selected' : ''; ?>>Manager</option>
                        <option value="staff" <?php echo ($user['role'] === 'staff') ? 'selected' : ''; ?>>Staff</option>
                    </select>
                </div>
            </div>

            <div class="mb-3">
                <div class="form-check">
                    <input class="form-check-input" type="checkbox" id="active" name="active" value="1" <?php echo $user['active'] ? 'checked' : ''; ?>>
                    <label class="form-check-label" for="active">Active</label>
                    <small class="text-muted d-block">Inactive users cannot log in to the system</small>
                </div>
            </div>

            <div class="mb-3">
                <div class="form-check">
                    <input class="form-check-input" type="checkbox" id="change_password" name="change_password" value="1">
                    <label class="form-check-label" for="change_password">Change Password</label>
                </div>
            </div>

            <div id="password_fields" style="display: none;">
                <div class="row mb-3">
                    <div class="col-md-6">
                        <label for="new_password" class="form-label">New Password *</label>
                        <input type="password" class="form-control" id="new_password" name="new_password">
                        <small class="text-muted">Password must be at least 8 characters long</small>
                    </div>
                    <div class="col-md-6">
                        <label for="confirm_password" class="form-label">Confirm Password *</label>
                        <input type="password" class="form-control" id="confirm_password" name="confirm_password">
                    </div>
                </div>
            </div>

            <div class="alert alert-info">
                <i class="fas fa-info-circle"></i> User roles define access levels:
                <ul class="mb-0">
                    <li><strong>Administrator:</strong> Full access to all features</li>
                    <li><strong>Manager:</strong> Access to operations and reports, but not user management</li>
                    <li><strong>Staff:</strong> Basic access to daily operations</li>
                </ul>
            </div>

            <div class="d-grid gap-2 d-md-flex justify-content-md-end">
                <a href="users.php" class="btn btn-secondary me-md-2">Cancel</a>
                <button type="submit" class="btn btn-primary">Update User</button>
            </div>
        </form>
    </div>
</div>

<script>
    // Show/hide password fields based on checkbox
    document.getElementById('change_password').addEventListener('change', function() {
        var passwordFields = document.getElementById('password_fields');
        passwordFields.style.display = this.checked ? 'block' : 'none';

        // Toggle required attribute on password fields
        document.getElementById('new_password').required = this.checked;
        document.getElementById('confirm_password').required = this.checked;
    });
</script>

<?php require_once '../includes/footer.php'; ?>