<?php

/**
 * Activity Logs Page
 * Displays system activity logs for auditing and troubleshooting
 */
require_once '../includes/header.php';

// Check if user has admin privileges
if (!hasRole('admin')) {
    setFlashMessage('You do not have permission to access this page.', 'danger');
    redirect('index.php');
}

// Handle log clear request
if (isset($_GET['clear']) && $_GET['clear'] === 'all') {
    $confirmClear = isset($_GET['confirm']) && $_GET['confirm'] === 'yes';

    if ($confirmClear) {
        $clearSql = "TRUNCATE TABLE activity_log";
        if (executeQuery($conn, $clearSql)) {
            setFlashMessage('Activity logs cleared successfully.', 'success');
        } else {
            setFlashMessage('Error clearing activity logs.', 'danger');
        }
        redirect('admin/logs.php');
    } else {
        // Display confirmation dialog
        $showConfirmation = true;
    }
}

// Get filter parameters
$userFilter = isset($_GET['user_id']) ? (int)$_GET['user_id'] : 0;
$actionFilter = isset($_GET['action']) ? sanitizeInput($conn, $_GET['action']) : '';
$dateFrom = isset($_GET['date_from']) ? sanitizeInput($conn, $_GET['date_from']) : '';
$dateTo = isset($_GET['date_to']) ? sanitizeInput($conn, $_GET['date_to']) : '';
$searchTerm = isset($_GET['search']) ? sanitizeInput($conn, $_GET['search']) : '';

// Pagination parameters
$page = isset($_GET['page']) ? (int)$_GET['page'] : 1;
$itemsPerPage = 50;
$offset = ($page - 1) * $itemsPerPage;

// Build the query with filters
$countSql = "SELECT COUNT(*) AS total FROM activity_log WHERE 1=1";
$sql = "SELECT al.*, u.username, u.full_name 
        FROM activity_log al
        LEFT JOIN users u ON al.user_id = u.id
        WHERE 1=1";

$filterParams = [];

if ($userFilter > 0) {
    $countSql .= " AND user_id = $userFilter";
    $sql .= " AND al.user_id = $userFilter";
    $filterParams[] = "user_id=$userFilter";
}

if (!empty($actionFilter)) {
    $countSql .= " AND action = '$actionFilter'";
    $sql .= " AND al.action = '$actionFilter'";
    $filterParams[] = "action=$actionFilter";
}

if (!empty($dateFrom)) {
    $countSql .= " AND DATE(created_at) >= '$dateFrom'";
    $sql .= " AND DATE(al.created_at) >= '$dateFrom'";
    $filterParams[] = "date_from=$dateFrom";
}

if (!empty($dateTo)) {
    $countSql .= " AND DATE(created_at) <= '$dateTo'";
    $sql .= " AND DATE(al.created_at) <= '$dateTo'";
    $filterParams[] = "date_to=$dateTo";
}

if (!empty($searchTerm)) {
    $countSql .= " AND (action LIKE '%$searchTerm%' OR description LIKE '%$searchTerm%')";
    $sql .= " AND (al.action LIKE '%$searchTerm%' OR al.description LIKE '%$searchTerm%')";
    $filterParams[] = "search=$searchTerm";
}

// Get total count for pagination
$countResult = executeQuery($conn, $countSql);
$totalItems = $countResult->fetch_assoc()['total'];
$totalPages = ceil($totalItems / $itemsPerPage);

// Ensure page is within valid range
if ($page < 1) $page = 1;
if ($page > $totalPages && $totalPages > 0) $page = $totalPages;

// Add pagination to the query
$sql .= " ORDER BY al.created_at DESC LIMIT $offset, $itemsPerPage";

$result = executeQuery($conn, $sql);

// Get list of users for filter dropdown
$usersSql = "SELECT DISTINCT u.id, u.username, u.full_name 
             FROM users u
             JOIN activity_log al ON u.id = al.user_id
             ORDER BY u.username";
$usersResult = executeQuery($conn, $usersSql);
$users = [];

if ($usersResult && $usersResult->num_rows > 0) {
    while ($user = $usersResult->fetch_assoc()) {
        $users[$user['id']] = $user;
    }
}

// Get list of unique actions for filter dropdown
$actionsSql = "SELECT DISTINCT action FROM activity_log ORDER BY action";
$actionsResult = executeQuery($conn, $actionsSql);
$actions = [];

if ($actionsResult && $actionsResult->num_rows > 0) {
    while ($action = $actionsResult->fetch_assoc()) {
        $actions[] = $action['action'];
    }
}

// Build pagination URL
$paginationUrl = 'logs.php?';
if (!empty($filterParams)) {
    $paginationUrl .= implode('&', $filterParams) . '&';
}
?>

<div class="d-flex justify-content-between align-items-center mb-4">
    <h1>Activity Logs</h1>
    <div>
        <a href="settings.php" class="btn btn-secondary me-2">
            <i class="fas fa-cog"></i> System Settings
        </a>
        <a href="logs.php?clear=all" class="btn btn-danger" onclick="return confirm('Are you sure you want to clear all logs? This action cannot be undone.');">
            <i class="fas fa-trash"></i> Clear Logs
        </a>
    </div>
</div>

<?php if (isset($showConfirmation) && $showConfirmation): ?>
    <div class="alert alert-warning">
        <h4 class="alert-heading">Confirm Clear Logs</h4>
        <p>Are you sure you want to clear all activity logs? This action cannot be undone.</p>
        <hr>
        <div class="d-flex justify-content-end">
            <a href="logs.php" class="btn btn-secondary me-2">Cancel</a>
            <a href="logs.php?clear=all&confirm=yes" class="btn btn-danger">Yes, Clear All Logs</a>
        </div>
    </div>
<?php endif; ?>

<!-- Filters -->
<div class="card mb-4">
    <div class="card-header">
        <i class="fas fa-filter"></i> Filter Logs
    </div>
    <div class="card-body">
        <form method="get" action="" class="row g-3">
            <div class="col-md-3">
                <label for="user_id" class="form-label">User</label>
                <select name="user_id" id="user_id" class="form-select">
                    <option value="">All Users</option>
                    <?php foreach ($users as $id => $user): ?>
                        <option value="<?php echo $id; ?>" <?php echo ($userFilter == $id) ? 'selected' : ''; ?>>
                            <?php echo htmlspecialchars($user['username'] . ' (' . $user['full_name'] . ')'); ?>
                        </option>
                    <?php endforeach; ?>
                </select>
            </div>
            <div class="col-md-3">
                <label for="action" class="form-label">Action</label>
                <select name="action" id="action" class="form-select">
                    <option value="">All Actions</option>
                    <?php foreach ($actions as $action): ?>
                        <option value="<?php echo $action; ?>" <?php echo ($actionFilter === $action) ? 'selected' : ''; ?>>
                            <?php echo ucwords(str_replace('_', ' ', $action)); ?>
                        </option>
                    <?php endforeach; ?>
                </select>
            </div>
            <div class="col-md-2">
                <label for="date_from" class="form-label">Date From</label>
                <input type="date" class="form-control" id="date_from" name="date_from" value="<?php echo htmlspecialchars($dateFrom); ?>">
            </div>
            <div class="col-md-2">
                <label for="date_to" class="form-label">Date To</label>
                <input type="date" class="form-control" id="date_to" name="date_to" value="<?php echo htmlspecialchars($dateTo); ?>">
            </div>
            <div class="col-md-2">
                <label for="search" class="form-label">Search</label>
                <input type="text" class="form-control" id="search" name="search" value="<?php echo htmlspecialchars($searchTerm); ?>" placeholder="Search...">
            </div>
            <div class="col-12 d-flex justify-content-end">
                <button type="submit" class="btn btn-primary me-2">Apply Filters</button>
                <a href="logs.php" class="btn btn-secondary">Reset</a>
            </div>
        </form>
    </div>
</div>

<!-- Activity Logs Table -->
<div class="card shadow mb-4">
    <div class="card-header py-3 d-flex justify-content-between align-items-center">
        <h6 class="m-0 font-weight-bold text-primary">System Activity Logs</h6>
        <span class="badge bg-info">Total: <?php echo number_format($totalItems); ?> logs</span>
    </div>
    <div class="card-body">
        <div class="table-responsive">
            <table class="table table-bordered" width="100%" cellspacing="0">
                <thead>
                    <tr>
                        <th>ID</th>
                        <th>Date & Time</th>
                        <th>User</th>
                        <th>Action</th>
                        <th>Description</th>
                    </tr>
                </thead>
                <tbody>
                    <?php if ($result && $result->num_rows > 0): ?>
                        <?php while ($row = $result->fetch_assoc()): ?>
                            <tr>
                                <td><?php echo $row['id']; ?></td>
                                <td><?php echo formatDate($row['created_at'], 'Y-m-d H:i:s'); ?></td>
                                <td>
                                    <?php if ($row['username']): ?>
                                        <?php echo htmlspecialchars($row['username']); ?>
                                        <small class="text-muted d-block"><?php echo htmlspecialchars($row['full_name']); ?></small>
                                    <?php else: ?>
                                        <span class="text-muted">System</span>
                                    <?php endif; ?>
                                </td>
                                <td>
                                    <span class="badge bg-<?php
                                                            echo (strpos($row['action'], 'delete') !== false) ? 'danger' : ((strpos($row['action'], 'add') !== false || strpos($row['action'], 'create') !== false) ? 'success' : ((strpos($row['action'], 'edit') !== false || strpos($row['action'], 'update') !== false) ? 'warning' : 'info'));
                                                            ?>">
                                        <?php echo ucwords(str_replace('_', ' ', $row['action'])); ?>
                                    </span>
                                </td>
                                <td><?php echo htmlspecialchars($row['description'] ?? 'N/A'); ?></td>
                            </tr>
                        <?php endwhile; ?>
                    <?php else: ?>
                        <tr>
                            <td colspan="5" class="text-center">No activity logs found</td>
                        </tr>
                    <?php endif; ?>
                </tbody>
            </table>
        </div>

        <!-- Pagination -->
        <?php if ($totalPages > 1): ?>
            <nav aria-label="Page navigation">
                <ul class="pagination justify-content-center mt-4">
                    <li class="page-item <?php echo ($page <= 1) ? 'disabled' : ''; ?>">
                        <a class="page-link" href="<?php echo $paginationUrl; ?>page=<?php echo $page - 1; ?>" aria-label="Previous">
                            <span aria-hidden="true">&laquo;</span>
                        </a>
                    </li>

                    <?php
                    $startPage = max(1, $page - 2);
                    $endPage = min($totalPages, $page + 2);

                    if ($startPage > 1) {
                        echo '<li class="page-item"><a class="page-link" href="' . $paginationUrl . 'page=1">1</a></li>';
                        if ($startPage > 2) {
                            echo '<li class="page-item disabled"><a class="page-link" href="#">...</a></li>';
                        }
                    }

                    for ($i = $startPage; $i <= $endPage; $i++) {
                        echo '<li class="page-item ' . (($i == $page) ? 'active' : '') . '"><a class="page-link" href="' . $paginationUrl . 'page=' . $i . '">' . $i . '</a></li>';
                    }

                    if ($endPage < $totalPages) {
                        if ($endPage < $totalPages - 1) {
                            echo '<li class="page-item disabled"><a class="page-link" href="#">...</a></li>';
                        }
                        echo '<li class="page-item"><a class="page-link" href="' . $paginationUrl . 'page=' . $totalPages . '">' . $totalPages . '</a></li>';
                    }
                    ?>

                    <li class="page-item <?php echo ($page >= $totalPages) ? 'disabled' : ''; ?>">
                        <a class="page-link" href="<?php echo $paginationUrl; ?>page=<?php echo $page + 1; ?>" aria-label="Next">
                            <span aria-hidden="true">&raquo;</span>
                        </a>
                    </li>
                </ul>
            </nav>
        <?php endif; ?>
    </div>
</div>

<?php require_once '../includes/footer.php'; ?>