<?php

/**
 * System Settings Page
 * Allows administrators to configure system settings
 */
require_once '../includes/header.php';

// Check if user has admin privileges
if (!hasRole('admin')) {
    setFlashMessage('You do not have permission to access this page.', 'danger');
    redirect('index.php');
}

// Create settings table if it doesn't exist
$createTableSql = "CREATE TABLE IF NOT EXISTS system_settings (
    id INT AUTO_INCREMENT PRIMARY KEY,
    setting_key VARCHAR(50) NOT NULL UNIQUE,
    setting_value TEXT,
    setting_description TEXT,
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP
)";

executeQuery($conn, $createTableSql);

// Define default settings
$defaultSettings = [
    [
        'key' => 'company_name',
        'value' => 'Darul Kitab',
        'description' => 'Your company name as it appears in reports and documents'
    ],
    [
        'key' => 'company_address',
        'value' => '',
        'description' => 'Your business address for documents and reports'
    ],
    [
        'key' => 'company_phone',
        'value' => '',
        'description' => 'Contact phone number'
    ],
    [
        'key' => 'company_email',
        'value' => '',
        'description' => 'Contact email address'
    ],
    [
        'key' => 'currency_symbol',
        'value' => '₹',
        'description' => 'Currency symbol used throughout the system'
    ],
    [
        'key' => 'low_stock_threshold',
        'value' => '100',
        'description' => 'Quantity level at which materials are considered low stock'
    ],
    [
        'key' => 'financial_year_start',
        'value' => '04-01',
        'description' => 'Start of financial year (MM-DD)'
    ],
    [
        'key' => 'default_payment_terms',
        'value' => '30',
        'description' => 'Default payment terms in days'
    ],
    [
        'key' => 'enable_email_notifications',
        'value' => '0',
        'description' => 'Enable email notifications for system events'
    ],
    [
        'key' => 'smtp_host',
        'value' => '',
        'description' => 'SMTP server for sending emails'
    ],
    [
        'key' => 'smtp_port',
        'value' => '587',
        'description' => 'SMTP server port'
    ],
    [
        'key' => 'smtp_username',
        'value' => '',
        'description' => 'SMTP username'
    ],
    [
        'key' => 'smtp_password',
        'value' => '',
        'description' => 'SMTP password'
    ],
    [
        'key' => 'smtp_encryption',
        'value' => 'tls',
        'description' => 'SMTP encryption (tls/ssl)'
    ]
];

// Insert default settings if they don't exist
foreach ($defaultSettings as $setting) {
    $key = $setting['key'];
    $value = $setting['value'];
    $description = $setting['description'];

    $checkSql = "SELECT COUNT(*) AS count FROM system_settings WHERE setting_key = '$key'";
    $checkResult = executeQuery($conn, $checkSql);
    $check = $checkResult->fetch_assoc();

    if ($check['count'] == 0) {
        $insertSql = "INSERT INTO system_settings (setting_key, setting_value, setting_description) 
                     VALUES ('$key', '$value', '$description')";
        executeQuery($conn, $insertSql);
    }
}

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Get all settings from the form
    foreach ($_POST as $key => $value) {
        // Skip the submit button and other non-setting fields
        if ($key === 'submit' || !preg_match('/^setting_/', $key)) {
            continue;
        }

        // Extract the actual setting key
        $settingKey = substr($key, 8); // Remove 'setting_' prefix
        $settingValue = sanitizeInput($conn, $value);

        // Update the setting
        $updateSql = "UPDATE system_settings SET setting_value = '$settingValue' WHERE setting_key = '$settingKey'";
        executeQuery($conn, $updateSql);
    }

    logActivity('update_settings', 'Updated system settings');
    setFlashMessage('Settings updated successfully.', 'success');
    redirect('admin/settings.php');
}

// Get all settings
$settingsSql = "SELECT * FROM system_settings ORDER BY id";
$settingsResult = executeQuery($conn, $settingsSql);
$settings = [];

if ($settingsResult && $settingsResult->num_rows > 0) {
    while ($row = $settingsResult->fetch_assoc()) {
        $settings[$row['setting_key']] = $row;
    }
}
?>

<div class="d-flex justify-content-between align-items-center mb-4">
    <h1>System Settings</h1>
    <a href="users.php" class="btn btn-secondary">
        <i class="fas fa-users"></i> User Management
    </a>
</div>

<div class="card shadow mb-4">
    <div class="card-header py-3">
        <h6 class="m-0 font-weight-bold text-primary">General Settings</h6>
    </div>
    <div class="card-body">
        <form method="post" action="">
            <!-- Company Information -->
            <h5 class="mb-3">Company Information</h5>
            <div class="row mb-4">
                <div class="col-md-6 mb-3">
                    <label for="setting_company_name" class="form-label">Company Name</label>
                    <input type="text" class="form-control" id="setting_company_name" name="setting_company_name"
                        value="<?php echo htmlspecialchars($settings['company_name']['setting_value'] ?? ''); ?>">
                    <small class="text-muted"><?php echo $settings['company_name']['setting_description'] ?? ''; ?></small>
                </div>
                <div class="col-md-6 mb-3">
                    <label for="setting_company_email" class="form-label">Company Email</label>
                    <input type="email" class="form-control" id="setting_company_email" name="setting_company_email"
                        value="<?php echo htmlspecialchars($settings['company_email']['setting_value'] ?? ''); ?>">
                    <small class="text-muted"><?php echo $settings['company_email']['setting_description'] ?? ''; ?></small>
                </div>
                <div class="col-md-6 mb-3">
                    <label for="setting_company_phone" class="form-label">Company Phone</label>
                    <input type="text" class="form-control" id="setting_company_phone" name="setting_company_phone"
                        value="<?php echo htmlspecialchars($settings['company_phone']['setting_value'] ?? ''); ?>">
                    <small class="text-muted"><?php echo $settings['company_phone']['setting_description'] ?? ''; ?></small>
                </div>
                <div class="col-md-6 mb-3">
                    <label for="setting_company_address" class="form-label">Company Address</label>
                    <textarea class="form-control" id="setting_company_address" name="setting_company_address" rows="3"><?php echo htmlspecialchars($settings['company_address']['setting_value'] ?? ''); ?></textarea>
                    <small class="text-muted"><?php echo $settings['company_address']['setting_description'] ?? ''; ?></small>
                </div>
            </div>

            <!-- Business Settings -->
            <h5 class="mb-3">Business Settings</h5>
            <div class="row mb-4">
                <div class="col-md-6 mb-3">
                    <label for="setting_currency_symbol" class="form-label">Currency Symbol</label>
                    <input type="text" class="form-control" id="setting_currency_symbol" name="setting_currency_symbol"
                        value="<?php echo htmlspecialchars($settings['currency_symbol']['setting_value'] ?? ''); ?>">
                    <small class="text-muted"><?php echo $settings['currency_symbol']['setting_description'] ?? ''; ?></small>
                </div>
                <div class="col-md-6 mb-3">
                    <label for="setting_low_stock_threshold" class="form-label">Low Stock Threshold</label>
                    <input type="number" class="form-control" id="setting_low_stock_threshold" name="setting_low_stock_threshold"
                        value="<?php echo htmlspecialchars($settings['low_stock_threshold']['setting_value'] ?? ''); ?>">
                    <small class="text-muted"><?php echo $settings['low_stock_threshold']['setting_description'] ?? ''; ?></small>
                </div>
                <div class="col-md-6 mb-3">
                    <label for="setting_financial_year_start" class="form-label">Financial Year Start</label>
                    <input type="text" class="form-control" id="setting_financial_year_start" name="setting_financial_year_start"
                        value="<?php echo htmlspecialchars($settings['financial_year_start']['setting_value'] ?? ''); ?>" placeholder="MM-DD">
                    <small class="text-muted"><?php echo $settings['financial_year_start']['setting_description'] ?? ''; ?></small>
                </div>
                <div class="col-md-6 mb-3">
                    <label for="setting_default_payment_terms" class="form-label">Default Payment Terms (days)</label>
                    <input type="number" class="form-control" id="setting_default_payment_terms" name="setting_default_payment_terms"
                        value="<?php echo htmlspecialchars($settings['default_payment_terms']['setting_value'] ?? ''); ?>">
                    <small class="text-muted"><?php echo $settings['default_payment_terms']['setting_description'] ?? ''; ?></small>
                </div>
            </div>

            <!-- Email Settings -->
            <h5 class="mb-3">Email Settings</h5>
            <div class="row mb-4">
                <div class="col-md-6 mb-3">
                    <div class="form-check form-switch">
                        <input class="form-check-input" type="checkbox" id="setting_enable_email_notifications" name="setting_enable_email_notifications"
                            value="1" <?php echo ($settings['enable_email_notifications']['setting_value'] ?? '0') == '1' ? 'checked' : ''; ?>>
                        <label class="form-check-label" for="setting_enable_email_notifications">Enable Email Notifications</label>
                    </div>
                    <small class="text-muted"><?php echo $settings['enable_email_notifications']['setting_description'] ?? ''; ?></small>
                </div>
            </div>

            <div id="email_settings" style="display: <?php echo ($settings['enable_email_notifications']['setting_value'] ?? '0') == '1' ? 'block' : 'none'; ?>">
                <div class="row">
                    <div class="col-md-6 mb-3">
                        <label for="setting_smtp_host" class="form-label">SMTP Host</label>
                        <input type="text" class="form-control" id="setting_smtp_host" name="setting_smtp_host"
                            value="<?php echo htmlspecialchars($settings['smtp_host']['setting_value'] ?? ''); ?>">
                        <small class="text-muted"><?php echo $settings['smtp_host']['setting_description'] ?? ''; ?></small>
                    </div>
                    <div class="col-md-6 mb-3">
                        <label for="setting_smtp_port" class="form-label">SMTP Port</label>
                        <input type="text" class="form-control" id="setting_smtp_port" name="setting_smtp_port"
                            value="<?php echo htmlspecialchars($settings['smtp_port']['setting_value'] ?? ''); ?>">
                        <small class="text-muted"><?php echo $settings['smtp_port']['setting_description'] ?? ''; ?></small>
                    </div>
                    <div class="col-md-6 mb-3">
                        <label for="setting_smtp_username" class="form-label">SMTP Username</label>
                        <input type="text" class="form-control" id="setting_smtp_username" name="setting_smtp_username"
                            value="<?php echo htmlspecialchars($settings['smtp_username']['setting_value'] ?? ''); ?>">
                        <small class="text-muted"><?php echo $settings['smtp_username']['setting_description'] ?? ''; ?></small>
                    </div>
                    <div class="col-md-6 mb-3">
                        <label for="setting_smtp_password" class="form-label">SMTP Password</label>
                        <input type="password" class="form-control" id="setting_smtp_password" name="setting_smtp_password"
                            value="<?php echo htmlspecialchars($settings['smtp_password']['setting_value'] ?? ''); ?>">
                        <small class="text-muted"><?php echo $settings['smtp_password']['setting_description'] ?? ''; ?></small>
                    </div>
                    <div class="col-md-6 mb-3">
                        <label for="setting_smtp_encryption" class="form-label">SMTP Encryption</label>
                        <select class="form-select" id="setting_smtp_encryption" name="setting_smtp_encryption">
                            <option value="tls" <?php echo ($settings['smtp_encryption']['setting_value'] ?? '') === 'tls' ? 'selected' : ''; ?>>TLS</option>
                            <option value="ssl" <?php echo ($settings['smtp_encryption']['setting_value'] ?? '') === 'ssl' ? 'selected' : ''; ?>>SSL</option>
                            <option value="none" <?php echo ($settings['smtp_encryption']['setting_value'] ?? '') === 'none' ? 'selected' : ''; ?>>None</option>
                        </select>
                        <small class="text-muted"><?php echo $settings['smtp_encryption']['setting_description'] ?? ''; ?></small>
                    </div>
                </div>
            </div>

            <!-- Submit Button -->
            <div class="d-grid gap-2 d-md-flex justify-content-md-end mt-4">
                <button type="submit" name="submit" class="btn btn-primary">Save Settings</button>
            </div>
        </form>
    </div>
</div>

<div class="card shadow mb-4">
    <div class="card-header py-3">
        <h6 class="m-0 font-weight-bold text-primary">System Information</h6>
    </div>
    <div class="card-body">
        <div class="row">
            <div class="col-md-6 mb-3">
                <h5>Application Information</h5>
                <table class="table table-bordered">
                    <tr>
                        <th>Application Name</th>
                        <td><?php echo APP_NAME; ?></td>
                    </tr>
                    <tr>
                        <th>Version</th>
                        <td><?php echo APP_VERSION; ?></td>
                    </tr>
                    <tr>
                        <th>Base URL</th>
                        <td><?php echo BASE_URL; ?></td>
                    </tr>
                </table>
            </div>
            <div class="col-md-6 mb-3">
                <h5>Server Information</h5>
                <table class="table table-bordered">
                    <tr>
                        <th>PHP Version</th>
                        <td><?php echo phpversion(); ?></td>
                    </tr>
                    <tr>
                        <th>MySQL Version</th>
                        <td><?php echo $conn->server_info; ?></td>
                    </tr>
                    <tr>
                        <th>Server Software</th>
                        <td><?php echo $_SERVER['SERVER_SOFTWARE']; ?></td>
                    </tr>
                </table>
            </div>
        </div>
    </div>
</div>

<script>
    // Show/hide email settings based on checkbox
    document.getElementById('setting_enable_email_notifications').addEventListener('change', function() {
        var emailSettings = document.getElementById('email_settings');
        emailSettings.style.display = this.checked ? 'block' : 'none';
    });
</script>

<?php require_once '../includes/footer.php'; ?>