<?php

/**
 * Admin User Management Page
 * Lists all users and provides options to add, edit or deactivate users
 */
require_once '../includes/header.php';

// Check if user has admin privileges
if (!hasRole('admin')) {
    setFlashMessage('You do not have permission to access this page.', 'danger');
    redirect('index.php');
}

// Handle user activation/deactivation
if (isset($_GET['toggle']) && !empty($_GET['toggle'])) {
    $userId = (int)$_GET['toggle'];

    // Don't allow deactivating own account
    if ($userId === $_SESSION['user_id']) {
        setFlashMessage('You cannot deactivate your own account.', 'danger');
    } else {
        $toggleSql = "UPDATE users SET active = NOT active WHERE id = $userId";

        if (executeQuery($conn, $toggleSql)) {
            // Get current status to show appropriate message
            $checkSql = "SELECT active FROM users WHERE id = $userId";
            $checkResult = executeQuery($conn, $checkSql);
            $user = $checkResult->fetch_assoc();

            $status = $user['active'] ? 'activated' : 'deactivated';
            setFlashMessage("User $status successfully.", 'success');
            logActivity('toggle_user_status', "Changed user ID: $userId status to $status");
        } else {
            setFlashMessage('Error changing user status.', 'danger');
        }
    }
    redirect('admin/users.php');
}

// Handle user deletion
if (isset($_GET['delete']) && !empty($_GET['delete'])) {
    $userId = (int)$_GET['delete'];

    // Don't allow deleting own account
    if ($userId === $_SESSION['user_id']) {
        setFlashMessage('You cannot delete your own account.', 'danger');
    } else {
        // Check if this is the last admin
        $adminCheckSql = "SELECT COUNT(*) as admin_count FROM users WHERE role = 'admin' AND active = 1";
        $adminCheckResult = executeQuery($conn, $adminCheckSql);
        $adminCount = $adminCheckResult->fetch_assoc();

        $userCheckSql = "SELECT role FROM users WHERE id = $userId";
        $userCheckResult = executeQuery($conn, $userCheckSql);
        $userRole = $userCheckResult->fetch_assoc();

        // If this is the last admin, don't allow deletion
        if ($adminCount['admin_count'] <= 1 && $userRole['role'] === 'admin') {
            setFlashMessage('Cannot delete the last admin user.', 'danger');
        } else {
            $deleteSql = "DELETE FROM users WHERE id = $userId";

            if (executeQuery($conn, $deleteSql)) {
                setFlashMessage('User deleted successfully.', 'success');
                logActivity('delete_user', "Deleted user ID: $userId");
            } else {
                setFlashMessage('Error deleting user.', 'danger');
            }
        }
    }
    redirect('admin/users.php');
}

// Get all users
$sql = "SELECT * FROM users ORDER BY username";
$result = executeQuery($conn, $sql);
?>

<div class="d-flex justify-content-between align-items-center mb-4">
    <h1>User Management</h1>
    <a href="add_user.php" class="btn btn-primary">
        <i class="fas fa-user-plus"></i> Add New User
    </a>
</div>

<div class="card shadow mb-4">
    <div class="card-header py-3">
        <h6 class="m-0 font-weight-bold text-primary">System Users</h6>
    </div>
    <div class="card-body">
        <div class="table-responsive">
            <table class="table table-bordered" width="100%" cellspacing="0">
                <thead>
                    <tr>
                        <th>ID</th>
                        <th>Username</th>
                        <th>Full Name</th>
                        <th>Email</th>
                        <th>Role</th>
                        <th>Status</th>
                        <th>Last Login</th>
                        <th>Actions</th>
                    </tr>
                </thead>
                <tbody>
                    <?php if ($result && $result->num_rows > 0): ?>
                        <?php while ($row = $result->fetch_assoc()): ?>
                            <tr>
                                <td><?php echo $row['id']; ?></td>
                                <td><?php echo htmlspecialchars($row['username']); ?></td>
                                <td><?php echo htmlspecialchars($row['full_name']); ?></td>
                                <td><?php echo htmlspecialchars($row['email']); ?></td>
                                <td>
                                    <span class="badge bg-<?php
                                                            echo ($row['role'] === 'admin') ? 'danger' : (($row['role'] === 'manager') ? 'warning' : 'info');
                                                            ?>">
                                        <?php echo ucfirst($row['role']); ?>
                                    </span>
                                </td>
                                <td>
                                    <span class="badge bg-<?php echo $row['active'] ? 'success' : 'secondary'; ?>">
                                        <?php echo $row['active'] ? 'Active' : 'Inactive'; ?>
                                    </span>
                                </td>
                                <td><?php echo $row['last_login'] ? formatDate($row['last_login'], 'Y-m-d H:i:s') : 'Never'; ?></td>
                                <td>
                                    <div class="btn-group">
                                        <a href="edit_user.php?id=<?php echo $row['id']; ?>" class="btn btn-primary btn-sm">
                                            <i class="fas fa-edit"></i>
                                        </a>
                                        <a href="users.php?toggle=<?php echo $row['id']; ?>" class="btn btn-warning btn-sm" <?php echo ($row['id'] === $_SESSION['user_id']) ? 'disabled' : ''; ?>>
                                            <i class="fas fa-<?php echo $row['active'] ? 'ban' : 'check'; ?>"></i>
                                        </a>
                                        <a href="users.php?delete=<?php echo $row['id']; ?>" class="btn btn-danger btn-sm"
                                            onclick="return confirm('Are you sure you want to delete this user? This cannot be undone.');"
                                            <?php echo ($row['id'] === $_SESSION['user_id']) ? 'disabled' : ''; ?>>
                                            <i class="fas fa-trash"></i>
                                        </a>
                                    </div>
                                </td>
                            </tr>
                        <?php endwhile; ?>
                    <?php else: ?>
                        <tr>
                            <td colspan="8" class="text-center">No users found</td>
                        </tr>
                    <?php endif; ?>
                </tbody>
            </table>
        </div>
    </div>
</div>

<div class="card shadow mb-4">
    <div class="card-header py-3">
        <h6 class="m-0 font-weight-bold text-primary">User Roles</h6>
    </div>
    <div class="card-body">
        <div class="row">
            <div class="col-md-4 mb-3">
                <div class="card h-100">
                    <div class="card-header bg-danger text-white">
                        Administrator
                    </div>
                    <div class="card-body">
                        <p>Administrators have full access to all system features, including:</p>
                        <ul>
                            <li>User management</li>
                            <li>System settings</li>
                            <li>All operational features</li>
                            <li>Financial reports and data</li>
                        </ul>
                    </div>
                </div>
            </div>
            <div class="col-md-4 mb-3">
                <div class="card h-100">
                    <div class="card-header bg-warning text-dark">
                        Manager
                    </div>
                    <div class="card-body">
                        <p>Managers have access to operational features and limited administrative functions:</p>
                        <ul>
                            <li>All operational features</li>
                            <li>Financial reports and data</li>
                            <li>Cannot manage users</li>
                            <li>Cannot access system settings</li>
                        </ul>
                    </div>
                </div>
            </div>
            <div class="col-md-4 mb-3">
                <div class="card h-100">
                    <div class="card-header bg-info text-white">
                        Staff
                    </div>
                    <div class="card-body">
                        <p>Staff members have limited access to operational features:</p>
                        <ul>
                            <li>Basic inventory management</li>
                            <li>Production process tracking</li>
                            <li>Sales order entry</li>
                            <li>No access to financial data</li>
                        </ul>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<?php require_once '../includes/footer.php'; ?>