<?php

/**
 * Edit Book Page
 * Allows editing existing books in the catalog
 */
require_once '../includes/header.php';

// Check if ID is provided
if (!isset($_GET['id']) || empty($_GET['id'])) {
    setFlashMessage('Book ID is required.', 'danger');
    redirect('books/list.php');
}

$id = (int)$_GET['id'];

// Get book data
$sql = "SELECT * FROM books WHERE id = $id";
$result = executeQuery($conn, $sql);

if (!$result || $result->num_rows === 0) {
    setFlashMessage('Book not found.', 'danger');
    redirect('books/list.php');
}

$book = $result->fetch_assoc();

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Sanitize input
    $title = sanitizeInput($conn, $_POST['title']);
    $author = sanitizeInput($conn, $_POST['author']);
    $isbn = sanitizeInput($conn, $_POST['isbn']);
    $pagesPerBook = (int)$_POST['pages_per_book'];
    $wholesalePrice = (float)$_POST['wholesale_price'];
    $retailPrice = (float)$_POST['retail_price'];
    $active = isset($_POST['active']) ? 1 : 0;

    // Validate input
    $errors = [];

    if (empty($title)) {
        $errors[] = 'Book title is required.';
    }

    if (empty($author)) {
        $errors[] = 'Author name is required.';
    }

    if ($pagesPerBook <= 0) {
        $errors[] = 'Pages per book must be greater than zero.';
    }

    if ($wholesalePrice <= 0) {
        $errors[] = 'Wholesale price must be greater than zero.';
    }

    if ($retailPrice <= 0) {
        $errors[] = 'Retail price must be greater than zero.';
    }

    if ($retailPrice <= $wholesalePrice) {
        $errors[] = 'Retail price should be greater than wholesale price.';
    }

    // Check if ISBN is unique (if provided)
    if (!empty($isbn) && $isbn !== $book['isbn']) {
        $checkSql = "SELECT COUNT(*) AS count FROM books WHERE isbn = '$isbn' AND id != $id";
        $checkResult = executeQuery($conn, $checkSql);
        $row = $checkResult->fetch_assoc();

        if ($row['count'] > 0) {
            $errors[] = 'ISBN already exists in the system. Please use a unique ISBN.';
        }
    }

    // If no errors, update data
    if (empty($errors)) {
        $sql = "UPDATE books SET 
                title = '$title', 
                author = '$author', 
                isbn = " . (!empty($isbn) ? "'$isbn'" : "NULL") . ", 
                pages_per_book = $pagesPerBook, 
                wholesale_price = $wholesalePrice, 
                retail_price = $retailPrice, 
                active = $active
                WHERE id = $id";

        if (executeQuery($conn, $sql)) {
            logActivity('edit_book', "Updated book: $title");

            setFlashMessage('Book updated successfully.', 'success');
            redirect('books/list.php');
        } else {
            $errors[] = 'Error updating book. Please try again.';
        }
    }
}
?>

<div class="d-flex justify-content-between align-items-center mb-4">
    <h1>Edit Book</h1>
    <div>
        <a href="view.php?id=<?php echo $id; ?>" class="btn btn-info me-2">
            <i class="fas fa-eye"></i> View Book
        </a>
        <a href="list.php" class="btn btn-secondary">
            <i class="fas fa-arrow-left"></i> Back to List
        </a>
    </div>
</div>

<?php if (!empty($errors)): ?>
    <div class="alert alert-danger">
        <ul class="mb-0">
            <?php foreach ($errors as $error): ?>
                <li><?php echo $error; ?></li>
            <?php endforeach; ?>
        </ul>
    </div>
<?php endif; ?>

<div class="card shadow mb-4">
    <div class="card-header py-3">
        <h6 class="m-0 font-weight-bold text-primary">Book Details</h6>
    </div>
    <div class="card-body">
        <form method="post" action="">
            <div class="row mb-3">
                <div class="col-md-6">
                    <label for="title" class="form-label">Book Title *</label>
                    <input type="text" class="form-control" id="title" name="title" value="<?php echo htmlspecialchars($book['title']); ?>" required>
                </div>
                <div class="col-md-6">
                    <label for="author" class="form-label">Author *</label>
                    <input type="text" class="form-control" id="author" name="author" value="<?php echo htmlspecialchars($book['author']); ?>" required>
                </div>
            </div>

            <div class="row mb-3">
                <div class="col-md-6">
                    <label for="isbn" class="form-label">ISBN</label>
                    <input type="text" class="form-control" id="isbn" name="isbn" value="<?php echo htmlspecialchars($book['isbn'] ?? ''); ?>">
                    <small class="text-muted">Optional. Must be unique if provided.</small>
                </div>
                <div class="col-md-6">
                    <label for="pages_per_book" class="form-label">Pages Per Book *</label>
                    <input type="number" class="form-control" id="pages_per_book" name="pages_per_book" value="<?php echo htmlspecialchars($book['pages_per_book']); ?>" min="1" required>
                </div>
            </div>

            <div class="row mb-3">
                <div class="col-md-6">
                    <label for="wholesale_price" class="form-label">Wholesale Price *</label>
                    <div class="input-group">
                        <span class="input-group-text">₹</span>
                        <input type="number" class="form-control" id="wholesale_price" name="wholesale_price" value="<?php echo htmlspecialchars($book['wholesale_price']); ?>" min="0.01" step="0.01" required>
                    </div>
                    <small class="text-muted">Price for wholesale customers</small>
                </div>
                <div class="col-md-6">
                    <label for="retail_price" class="form-label">Retail Price *</label>
                    <div class="input-group">
                        <span class="input-group-text">₹</span>
                        <input type="number" class="form-control" id="retail_price" name="retail_price" value="<?php echo htmlspecialchars($book['retail_price']); ?>" min="0.01" step="0.01" required>
                    </div>
                    <small class="text-muted">Price for retail customers</small>
                </div>
            </div>

            <div class="mb-3">
                <div class="form-check">
                    <input class="form-check-input" type="checkbox" id="active" name="active" value="1" <?php echo $book['active'] ? 'checked' : ''; ?>>
                    <label class="form-check-label" for="active">Active</label>
                    <small class="text-muted d-block">Inactive books won't appear in sales and production forms</small>
                </div>
            </div>

            <div class="d-grid gap-2 d-md-flex justify-content-md-end">
                <a href="list.php" class="btn btn-secondary me-md-2">Cancel</a>
                <button type="submit" class="btn btn-primary">Update Book</button>
            </div>
        </form>
    </div>
</div>

<!-- Book Usage Information -->
<?php
// Get inventory information
$inventorySql = "SELECT SUM(quantity) AS total_quantity 
                FROM finished_inventory 
                WHERE book_id = $id";
$inventoryResult = executeQuery($conn, $inventorySql);
$inventory = $inventoryResult->fetch_assoc();

// Get production orders information
$productionSql = "SELECT COUNT(*) AS order_count, SUM(quantity) AS total_ordered 
                 FROM production_orders 
                 WHERE book_id = $id";
$productionResult = executeQuery($conn, $productionSql);
$production = $productionResult->fetch_assoc();

// Get sales information
$salesSql = "SELECT COUNT(*) AS order_count, SUM(quantity) AS total_sold 
            FROM sales_order_items 
            WHERE book_id = $id";
$salesResult = executeQuery($conn, $salesSql);
$sales = $salesResult->fetch_assoc();
?>

<div class="card shadow mb-4">
    <div class="card-header py-3">
        <h6 class="m-0 font-weight-bold text-primary">Book Usage Information</h6>
    </div>
    <div class="card-body">
        <div class="row">
            <div class="col-md-4">
                <div class="card border-left-primary shadow h-100 py-2">
                    <div class="card-body">
                        <div class="row no-gutters align-items-center">
                            <div class="col mr-2">
                                <div class="text-xs font-weight-bold text-primary text-uppercase mb-1">
                                    Current Inventory</div>
                                <div class="h5 mb-0 font-weight-bold text-gray-800">
                                    <?php echo number_format($inventory['total_quantity'] ?? 0); ?> books
                                </div>
                            </div>
                            <div class="col-auto">
                                <i class="fas fa-boxes fa-2x text-gray-300"></i>
                            </div>
                        </div>
                    </div>
                </div>
            </div>

            <div class="col-md-4">
                <div class="card border-left-success shadow h-100 py-2">
                    <div class="card-body">
                        <div class="row no-gutters align-items-center">
                            <div class="col mr-2">
                                <div class="text-xs font-weight-bold text-success text-uppercase mb-1">
                                    Production Orders</div>
                                <div class="h5 mb-0 font-weight-bold text-gray-800">
                                    <?php echo number_format($production['order_count'] ?? 0); ?> orders<br>
                                    <?php echo number_format($production['total_ordered'] ?? 0); ?> books
                                </div>
                            </div>
                            <div class="col-auto">
                                <i class="fas fa-industry fa-2x text-gray-300"></i>
                            </div>
                        </div>
                    </div>
                </div>
            </div>

            <div class="col-md-4">
                <div class="card border-left-info shadow h-100 py-2">
                    <div class="card-body">
                        <div class="row no-gutters align-items-center">
                            <div class="col mr-2">
                                <div class="text-xs font-weight-bold text-info text-uppercase mb-1">
                                    Sales</div>
                                <div class="h5 mb-0 font-weight-bold text-gray-800">
                                    <?php echo number_format($sales['order_count'] ?? 0); ?> orders<br>
                                    <?php echo number_format($sales['total_sold'] ?? 0); ?> books
                                </div>
                            </div>
                            <div class="col-auto">
                                <i class="fas fa-shopping-cart fa-2x text-gray-300"></i>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>

        <div class="alert alert-info mt-4">
            <i class="fas fa-info-circle"></i> This book is currently being used in the system. Any changes to the book details will affect all related records.
        </div>
    </div>
</div>

<?php require_once '../includes/footer.php'; ?>