<?php

/**
 * Finished Inventory Page
 * Displays finished books inventory
 */
require_once '../includes/header.php';

// Get search parameters
$bookId = isset($_GET['book_id']) ? (int)$_GET['book_id'] : 0;
$dateFrom = isset($_GET['date_from']) ? sanitizeInput($conn, $_GET['date_from']) : '';
$dateTo = isset($_GET['date_to']) ? sanitizeInput($conn, $_GET['date_to']) : '';

// Build query with filters
$sql = "SELECT fi.*, b.title AS book_title, b.author, b.wholesale_price, b.retail_price
        FROM finished_inventory fi
        JOIN books b ON fi.book_id = b.id
        WHERE 1=1";

if ($bookId > 0) {
    $sql .= " AND fi.book_id = $bookId";
}

if (!empty($dateFrom)) {
    $sql .= " AND fi.receipt_date >= '$dateFrom'";
}

if (!empty($dateTo)) {
    $sql .= " AND fi.receipt_date <= '$dateTo'";
}

$sql .= " ORDER BY fi.receipt_date DESC";

$result = executeQuery($conn, $sql);

// Get all books for the filter dropdown
$booksSql = "SELECT id, title FROM books ORDER BY title";
$booksResult = executeQuery($conn, $booksSql);
$books = [];

if ($booksResult && $booksResult->num_rows > 0) {
    while ($book = $booksResult->fetch_assoc()) {
        $books[$book['id']] = $book['title'];
    }
}

// Calculate inventory summary
$summarySql = "SELECT b.id, b.title, b.wholesale_price, b.retail_price, SUM(fi.quantity) AS total_quantity, 
                b.wholesale_price * SUM(fi.quantity) AS wholesale_value, 
                b.retail_price * SUM(fi.quantity) AS retail_value
               FROM finished_inventory fi
               JOIN books b ON fi.book_id = b.id
               GROUP BY b.id
               ORDER BY total_quantity DESC";
$summaryResult = executeQuery($conn, $summarySql);

// Calculate totals
$totalBooks = 0;
$totalWholesaleValue = 0;
$totalRetailValue = 0;

if ($summaryResult && $summaryResult->num_rows > 0) {
    while ($row = $summaryResult->fetch_assoc()) {
        $totalBooks += $row['total_quantity'];
        $totalWholesaleValue += $row['wholesale_value'];
        $totalRetailValue += $row['retail_value'];
    }
    // Reset pointer to beginning
    $summaryResult->data_seek(0);
}
?>

<div class="d-flex justify-content-between align-items-center mb-4">
    <h1>Finished Books Inventory</h1>
    <div>
        <a href="../production/binding.php" class="btn btn-info me-2">
            <i class="fas fa-book-open"></i> Binding Jobs
        </a>
        <a href="../sales/orders.php?action=new" class="btn btn-primary">
            <i class="fas fa-shopping-cart"></i> New Sales Order
        </a>
    </div>
</div>

<!-- Filters -->
<div class="card mb-4">
    <div class="card-header">
        <i class="fas fa-filter"></i> Filter Inventory
    </div>
    <div class="card-body">
        <form method="get" action="" class="row g-3">
            <div class="col-md-4">
                <label for="book_id" class="form-label">Book</label>
                <select name="book_id" id="book_id" class="form-select">
                    <option value="">All Books</option>
                    <?php foreach ($books as $id => $title): ?>
                        <option value="<?php echo $id; ?>" <?php echo ($bookId == $id) ? 'selected' : ''; ?>>
                            <?php echo htmlspecialchars($title); ?>
                        </option>
                    <?php endforeach; ?>
                </select>
            </div>
            <div class="col-md-3">
                <label for="date_from" class="form-label">Date From</label>
                <input type="date" class="form-control" id="date_from" name="date_from" value="<?php echo htmlspecialchars($dateFrom); ?>">
            </div>
            <div class="col-md-3">
                <label for="date_to" class="form-label">Date To</label>
                <input type="date" class="form-control" id="date_to" name="date_to" value="<?php echo htmlspecialchars($dateTo); ?>">
            </div>
            <div class="col-md-2 d-flex align-items-end">
                <button type="submit" class="btn btn-primary w-100">Filter</button>
            </div>
        </form>
    </div>
</div>

<!-- Inventory Summary -->
<div class="card shadow mb-4">
    <div class="card-header py-3 d-flex justify-content-between align-items-center">
        <h6 class="m-0 font-weight-bold text-primary">Inventory Summary</h6>
        <div>
            <span class="badge bg-info">Total Books: <?php echo number_format($totalBooks); ?></span>
            <span class="badge bg-success">Wholesale Value: <?php echo formatCurrency($totalWholesaleValue); ?></span>
            <span class="badge bg-primary">Retail Value: <?php echo formatCurrency($totalRetailValue); ?></span>
        </div>
    </div>
    <div class="card-body">
        <div class="table-responsive">
            <table class="table table-bordered" width="100%" cellspacing="0">
                <thead>
                    <tr>
                        <th>Book Title</th>
                        <th>Quantity</th>
                        <th>Wholesale Price</th>
                        <th>Retail Price</th>
                        <th>Wholesale Value</th>
                        <th>Retail Value</th>
                    </tr>
                </thead>
                <tbody>
                    <?php if ($summaryResult && $summaryResult->num_rows > 0): ?>
                        <?php while ($row = $summaryResult->fetch_assoc()): ?>
                            <tr>
                                <td><?php echo htmlspecialchars($row['title']); ?></td>
                                <td><?php echo number_format($row['total_quantity']); ?></td>
                                <td><?php echo formatCurrency($row['wholesale_price']); ?></td>
                                <td><?php echo formatCurrency($row['retail_price']); ?></td>
                                <td><?php echo formatCurrency($row['wholesale_value']); ?></td>
                                <td><?php echo formatCurrency($row['retail_value']); ?></td>
                            </tr>
                        <?php endwhile; ?>
                    <?php else: ?>
                        <tr>
                            <td colspan="6" class="text-center">No inventory found</td>
                        </tr>
                    <?php endif; ?>
                </tbody>
            </table>
        </div>
    </div>
</div>

<!-- Inventory Details Table -->
<div class="card shadow mb-4">
    <div class="card-header py-3">
        <h6 class="m-0 font-weight-bold text-primary">Inventory Details</h6>
    </div>
    <div class="card-body">
        <div class="table-responsive">
            <table class="table table-bordered" width="100%" cellspacing="0">
                <thead>
                    <tr>
                        <th>ID</th>
                        <th>Book</th>
                        <th>Quantity</th>
                        <th>Production Cost/Unit</th>
                        <th>Total Production Cost</th>
                        <th>Receipt Date</th>
                        <th>Binding Job</th>
                    </tr>
                </thead>
                <tbody>
                    <?php if ($result && $result->num_rows > 0): ?>
                        <?php while ($row = $result->fetch_assoc()): ?>
                            <tr>
                                <td><?php echo $row['id']; ?></td>
                                <td><?php echo htmlspecialchars($row['book_title']); ?></td>
                                <td><?php echo number_format($row['quantity']); ?></td>
                                <td><?php echo formatCurrency($row['production_cost_per_unit']); ?></td>
                                <td><?php echo formatCurrency($row['production_cost_per_unit'] * $row['quantity']); ?></td>
                                <td><?php echo formatDate($row['receipt_date']); ?></td>
                                <td>
                                    <a href="../production/binding.php?id=<?php echo $row['binding_job_id']; ?>" class="btn btn-info btn-sm">
                                        #<?php echo $row['binding_job_id']; ?>
                                    </a>
                                </td>
                            </tr>
                        <?php endwhile; ?>
                    <?php else: ?>
                        <tr>
                            <td colspan="7" class="text-center">No inventory records found</td>
                        </tr>
                    <?php endif; ?>
                </tbody>
            </table>
        </div>
    </div>
</div>

<?php require_once '../includes/footer.php'; ?>