<?php

/**
 * Books List Page
 * Displays all books in the system
 */
require_once '../includes/header.php';

// Handle delete request
if (isset($_GET['delete']) && !empty($_GET['delete'])) {
    $id = (int)$_GET['delete'];

    // Check if the book can be deleted (not used in production or sales)
    $checkSql = "SELECT 
                  (SELECT COUNT(*) FROM production_orders WHERE book_id = $id) +
                  (SELECT COUNT(*) FROM sales_order_items WHERE book_id = $id) +
                  (SELECT COUNT(*) FROM finished_inventory WHERE book_id = $id) AS usage_count";
    $checkResult = executeQuery($conn, $checkSql);
    $row = $checkResult->fetch_assoc();

    if ($row['usage_count'] > 0) {
        setFlashMessage('Cannot delete book as it is used in production orders, inventory, or sales.', 'danger');
    } else {
        $deleteSql = "DELETE FROM books WHERE id = $id";
        if (executeQuery($conn, $deleteSql)) {
            setFlashMessage('Book deleted successfully.', 'success');
            logActivity('delete_book', "Deleted book ID: $id");
        } else {
            setFlashMessage('Error deleting book.', 'danger');
        }
    }
    redirect('books/list.php');
}

// Handle status toggle
if (isset($_GET['toggle']) && !empty($_GET['toggle'])) {
    $id = (int)$_GET['toggle'];
    $statusSql = "UPDATE books SET active = NOT active WHERE id = $id";

    if (executeQuery($conn, $statusSql)) {
        // Get current status to show appropriate message
        $checkSql = "SELECT active FROM books WHERE id = $id";
        $checkResult = executeQuery($conn, $checkSql);
        $book = $checkResult->fetch_assoc();

        $status = $book['active'] ? 'active' : 'inactive';
        setFlashMessage("Book marked as $status successfully.", 'success');
        logActivity('toggle_book_status', "Changed book ID: $id status to $status");
    } else {
        setFlashMessage('Error changing book status.', 'danger');
    }
    redirect('books/list.php');
}

// Get search parameters
$searchTerm = isset($_GET['search']) ? sanitizeInput($conn, $_GET['search']) : '';
$activeOnly = isset($_GET['active_only']) ? (bool)$_GET['active_only'] : false;

// Build the query with filters
$sql = "SELECT * FROM books WHERE 1=1";

if (!empty($searchTerm)) {
    $sql .= " AND (title LIKE '%$searchTerm%' OR author LIKE '%$searchTerm%' OR isbn LIKE '%$searchTerm%')";
}

if ($activeOnly) {
    $sql .= " AND active = 1";
}

$sql .= " ORDER BY title";

$result = executeQuery($conn, $sql);

// Get inventory counts for each book
$bookInventory = [];
$inventorySql = "SELECT book_id, SUM(quantity) AS total_quantity 
                FROM finished_inventory 
                GROUP BY book_id";
$inventoryResult = executeQuery($conn, $inventorySql);

if ($inventoryResult && $inventoryResult->num_rows > 0) {
    while ($row = $inventoryResult->fetch_assoc()) {
        $bookInventory[$row['book_id']] = $row['total_quantity'];
    }
}
?>

<div class="d-flex justify-content-between align-items-center mb-4">
    <h1>Books Catalog</h1>
    <a href="add.php" class="btn btn-primary">
        <i class="fas fa-plus"></i> Add New Book
    </a>
</div>

<!-- Search Form -->
<div class="card mb-4">
    <div class="card-header">
        <i class="fas fa-search"></i> Search Books
    </div>
    <div class="card-body">
        <form method="get" action="" class="row g-3">
            <div class="col-md-8">
                <input type="text" class="form-control" id="search" name="search" value="<?php echo htmlspecialchars($searchTerm); ?>" placeholder="Search by title, author, or ISBN...">
            </div>
            <div class="col-md-2">
                <div class="form-check">
                    <input class="form-check-input" type="checkbox" id="active_only" name="active_only" value="1" <?php echo $activeOnly ? 'checked' : ''; ?>>
                    <label class="form-check-label" for="active_only">Active books only</label>
                </div>
            </div>
            <div class="col-md-2">
                <button type="submit" class="btn btn-primary w-100">Search</button>
            </div>
        </form>
    </div>
</div>

<!-- Books Table -->
<div class="card shadow mb-4">
    <div class="card-header py-3">
        <h6 class="m-0 font-weight-bold text-primary">Books Catalog</h6>
    </div>
    <div class="card-body">
        <div class="table-responsive">
            <table class="table table-bordered" width="100%" cellspacing="0">
                <thead>
                    <tr>
                        <th>ID</th>
                        <th>Title</th>
                        <th>Author</th>
                        <th>ISBN</th>
                        <th>Pages</th>
                        <th>Wholesale Price</th>
                        <th>Retail Price</th>
                        <th>Stock</th>
                        <th>Status</th>
                        <th>Actions</th>
                    </tr>
                </thead>
                <tbody>
                    <?php if ($result && $result->num_rows > 0): ?>
                        <?php while ($row = $result->fetch_assoc()): ?>
                            <tr>
                                <td><?php echo $row['id']; ?></td>
                                <td><?php echo htmlspecialchars($row['title']); ?></td>
                                <td><?php echo htmlspecialchars($row['author']); ?></td>
                                <td><?php echo htmlspecialchars($row['isbn'] ?? 'N/A'); ?></td>
                                <td><?php echo number_format($row['pages_per_book']); ?></td>
                                <td><?php echo formatCurrency($row['wholesale_price']); ?></td>
                                <td><?php echo formatCurrency($row['retail_price']); ?></td>
                                <td>
                                    <?php
                                    $stock = $bookInventory[$row['id']] ?? 0;
                                    echo number_format($stock);
                                    ?>
                                </td>
                                <td>
                                    <span class="badge bg-<?php echo $row['active'] ? 'success' : 'danger'; ?>">
                                        <?php echo $row['active'] ? 'Active' : 'Inactive'; ?>
                                    </span>
                                </td>
                                <td>
                                    <a href="view.php?id=<?php echo $row['id']; ?>" class="btn btn-info btn-sm">
                                        <i class="fas fa-eye"></i>
                                    </a>
                                    <a href="edit.php?id=<?php echo $row['id']; ?>" class="btn btn-primary btn-sm">
                                        <i class="fas fa-edit"></i>
                                    </a>
                                    <a href="list.php?toggle=<?php echo $row['id']; ?>" class="btn btn-warning btn-sm">
                                        <i class="fas fa-<?php echo $row['active'] ? 'ban' : 'check'; ?>"></i>
                                    </a>
                                    <a href="list.php?delete=<?php echo $row['id']; ?>" class="btn btn-danger btn-sm" onclick="return confirm('Are you sure you want to delete this book?');">
                                        <i class="fas fa-trash"></i>
                                    </a>
                                </td>
                            </tr>
                        <?php endwhile; ?>
                    <?php else: ?>
                        <tr>
                            <td colspan="10" class="text-center">No books found</td>
                        </tr>
                    <?php endif; ?>
                </tbody>
            </table>
        </div>
    </div>
</div>

<?php require_once '../includes/footer.php'; ?>