<?php

/**
 * View Book Details Page
 * Displays detailed information about a specific book
 */
require_once '../includes/header.php';

// Check if ID is provided
if (!isset($_GET['id']) || empty($_GET['id'])) {
    setFlashMessage('Book ID is required.', 'danger');
    redirect('books/list.php');
}

$id = (int)$_GET['id'];

// Get book data
$sql = "SELECT * FROM books WHERE id = $id";
$result = executeQuery($conn, $sql);

if (!$result || $result->num_rows === 0) {
    setFlashMessage('Book not found.', 'danger');
    redirect('books/list.php');
}

$book = $result->fetch_assoc();

// Get inventory information
$inventorySql = "SELECT 
                    SUM(quantity) AS total_quantity,
                    AVG(production_cost_per_unit) AS avg_production_cost
                FROM finished_inventory 
                WHERE book_id = $id";
$inventoryResult = executeQuery($conn, $inventorySql);
$inventory = $inventoryResult->fetch_assoc();

// Get production orders
$productionSql = "SELECT * FROM production_orders WHERE book_id = $id ORDER BY order_date DESC LIMIT 5";
$productionResult = executeQuery($conn, $productionSql);

// Get sales history
$salesSql = "SELECT soi.*, so.order_date, c.name AS customer_name, c.customer_type
            FROM sales_order_items soi
            JOIN sales_orders so ON soi.sales_order_id = so.id
            JOIN customers c ON so.customer_id = c.id
            WHERE soi.book_id = $id
            ORDER BY so.order_date DESC
            LIMIT 5";
$salesResult = executeQuery($conn, $salesSql);

// Get inventory batches
$batchesSql = "SELECT fi.*, bj.production_order_id
              FROM finished_inventory fi
              JOIN binding_jobs bj ON fi.binding_job_id = bj.id
              WHERE fi.book_id = $id
              ORDER BY fi.receipt_date DESC";
$batchesResult = executeQuery($conn, $batchesSql);

// Calculate profit margins
$wholesaleMargin = ($book['wholesale_price'] > 0 && $inventory['avg_production_cost'] > 0)
    ? (($book['wholesale_price'] - $inventory['avg_production_cost']) / $book['wholesale_price'] * 100)
    : 0;

$retailMargin = ($book['retail_price'] > 0 && $inventory['avg_production_cost'] > 0)
    ? (($book['retail_price'] - $inventory['avg_production_cost']) / $book['retail_price'] * 100)
    : 0;
?>

<div class="d-flex justify-content-between align-items-center mb-4">
    <h1><?php echo htmlspecialchars($book['title']); ?></h1>
    <div>
        <a href="edit.php?id=<?php echo $id; ?>" class="btn btn-primary me-2">
            <i class="fas fa-edit"></i> Edit Book
        </a>
        <a href="list.php" class="btn btn-secondary">
            <i class="fas fa-arrow-left"></i> Back to List
        </a>
    </div>
</div>

<!-- Book Details -->
<div class="row">
    <div class="col-md-8">
        <div class="card shadow mb-4">
            <div class="card-header py-3">
                <h6 class="m-0 font-weight-bold text-primary">Book Information</h6>
            </div>
            <div class="card-body">
                <div class="row mb-3">
                    <div class="col-md-6">
                        <p><strong>Title:</strong> <?php echo htmlspecialchars($book['title']); ?></p>
                        <p><strong>Author:</strong> <?php echo htmlspecialchars($book['author']); ?></p>
                        <p><strong>ISBN:</strong> <?php echo htmlspecialchars($book['isbn'] ?? 'N/A'); ?></p>
                        <p><strong>Pages per Book:</strong> <?php echo number_format($book['pages_per_book']); ?></p>
                    </div>
                    <div class="col-md-6">
                        <p><strong>Wholesale Price:</strong> <?php echo formatCurrency($book['wholesale_price']); ?></p>
                        <p><strong>Retail Price:</strong> <?php echo formatCurrency($book['retail_price']); ?></p>
                        <p>
                            <strong>Status:</strong>
                            <span class="badge bg-<?php echo $book['active'] ? 'success' : 'danger'; ?>">
                                <?php echo $book['active'] ? 'Active' : 'Inactive'; ?>
                            </span>
                        </p>
                        <p><strong>Created:</strong> <?php echo formatDate($book['created_at']); ?></p>
                    </div>
                </div>

                <div class="row">
                    <div class="col-md-12">
                        <div class="alert alert-<?php echo $book['active'] ? 'info' : 'warning'; ?>">
                            <i class="fas fa-info-circle"></i>
                            <?php if ($book['active']): ?>
                                This book is active and available for production and sales.
                            <?php else: ?>
                                This book is currently inactive and will not appear in production or sales forms.
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <div class="col-md-4">
        <div class="card shadow mb-4">
            <div class="card-header py-3">
                <h6 class="m-0 font-weight-bold text-primary">Inventory Summary</h6>
            </div>
            <div class="card-body">
                <div class="mb-3">
                    <h4 class="small font-weight-bold">Current Stock <span class="float-end"><?php echo number_format($inventory['total_quantity'] ?? 0); ?> books</span></h4>
                    <div class="progress mb-4">
                        <?php
                        $stockPercentage = min(100, ($inventory['total_quantity'] ?? 0) / 100 * 100);
                        $progressClass = ($stockPercentage < 25) ? 'bg-danger' : (($stockPercentage < 50) ? 'bg-warning' : 'bg-success');
                        ?>
                        <div class="progress-bar <?php echo $progressClass; ?>" role="progressbar" style="width: <?php echo $stockPercentage; ?>%"
                            aria-valuenow="<?php echo $stockPercentage; ?>" aria-valuemin="0" aria-valuemax="100"></div>
                    </div>
                </div>

                <div class="mb-3">
                    <h4 class="small font-weight-bold">Avg. Production Cost <span class="float-end"><?php echo formatCurrency($inventory['avg_production_cost'] ?? 0); ?></span></h4>
                </div>

                <div class="mb-3">
                    <h4 class="small font-weight-bold">Wholesale Margin <span class="float-end"><?php echo number_format($wholesaleMargin, 1); ?>%</span></h4>
                    <div class="progress mb-4">
                        <div class="progress-bar bg-info" role="progressbar" style="width: <?php echo $wholesaleMargin; ?>%"
                            aria-valuenow="<?php echo $wholesaleMargin; ?>" aria-valuemin="0" aria-valuemax="100"></div>
                    </div>
                </div>

                <div class="mb-3">
                    <h4 class="small font-weight-bold">Retail Margin <span class="float-end"><?php echo number_format($retailMargin, 1); ?>%</span></h4>
                    <div class="progress mb-4">
                        <div class="progress-bar bg-success" role="progressbar" style="width: <?php echo $retailMargin; ?>%"
                            aria-valuenow="<?php echo $retailMargin; ?>" aria-valuemin="0" aria-valuemax="100"></div>
                    </div>
                </div>

                <div class="text-center mt-4">
                    <a href="../production/orders.php?action=new&book_id=<?php echo $id; ?>" class="btn btn-success btn-sm">
                        <i class="fas fa-plus"></i> New Production Order
                    </a>
                    <a href="../sales/orders.php?action=new&book_id=<?php echo $id; ?>" class="btn btn-primary btn-sm">
                        <i class="fas fa-shopping-cart"></i> New Sales Order
                    </a>
                </div>
            </div>
        </div>
    </div>
</div>

<!-- Production History -->
<div class="card shadow mb-4">
    <div class="card-header py-3">
        <h6 class="m-0 font-weight-bold text-primary">Recent Production Orders</h6>
    </div>
    <div class="card-body">
        <div class="table-responsive">
            <table class="table table-bordered" width="100%" cellspacing="0">
                <thead>
                    <tr>
                        <th>Order ID</th>
                        <th>Date</th>
                        <th>Quantity</th>
                        <th>Status</th>
                        <th>Printed</th>
                        <th>Bound</th>
                        <th>Actions</th>
                    </tr>
                </thead>
                <tbody>
                    <?php if ($productionResult && $productionResult->num_rows > 0): ?>
                        <?php while ($order = $productionResult->fetch_assoc()):
                            // Get printing and binding progress
                            $printingSql = "SELECT COALESCE(SUM(received_quantity), 0) AS printed_qty 
                                           FROM printing_jobs 
                                           WHERE production_order_id = " . $order['id'];
                            $printingProgress = executeQuery($conn, $printingSql)->fetch_assoc();

                            $bindingSql = "SELECT COALESCE(SUM(received_quantity), 0) AS bound_qty 
                                          FROM binding_jobs 
                                          WHERE production_order_id = " . $order['id'];
                            $bindingProgress = executeQuery($conn, $bindingSql)->fetch_assoc();
                        ?>
                            <tr>
                                <td><?php echo $order['id']; ?></td>
                                <td><?php echo formatDate($order['order_date']); ?></td>
                                <td><?php echo number_format($order['quantity']); ?></td>
                                <td>
                                    <span class="badge bg-<?php
                                                            echo ($order['status'] === 'completed') ? 'success' : (($order['status'] === 'pending') ? 'warning' : (($order['status'] === 'cancelled') ? 'danger' : 'info'));
                                                            ?>">
                                        <?php echo ucfirst($order['status']); ?>
                                    </span>
                                </td>
                                <td><?php echo number_format($printingProgress['printed_qty']); ?></td>
                                <td><?php echo number_format($bindingProgress['bound_qty']); ?></td>
                                <td>
                                    <a href="../production/orders.php?id=<?php echo $order['id']; ?>" class="btn btn-info btn-sm">
                                        <i class="fas fa-eye"></i> View
                                    </a>
                                </td>
                            </tr>
                        <?php endwhile; ?>
                    <?php else: ?>
                        <tr>
                            <td colspan="7" class="text-center">No production orders found</td>
                        </tr>
                    <?php endif; ?>
                </tbody>
            </table>
        </div>
        <div class="text-center mt-3">
            <a href="../production/orders.php?book_id=<?php echo $id; ?>" class="btn btn-primary btn-sm">
                View All Production Orders
            </a>
        </div>
    </div>
</div>

<!-- Sales History -->
<div class="card shadow mb-4">
    <div class="card-header py-3">
        <h6 class="m-0 font-weight-bold text-primary">Recent Sales</h6>
    </div>
    <div class="card-body">
        <div class="table-responsive">
            <table class="table table-bordered" width="100%" cellspacing="0">
                <thead>
                    <tr>
                        <th>Order ID</th>
                        <th>Date</th>
                        <th>Customer</th>
                        <th>Type</th>
                        <th>Quantity</th>
                        <th>Unit Price</th>
                        <th>Total</th>
                    </tr>
                </thead>
                <tbody>
                    <?php if ($salesResult && $salesResult->num_rows > 0): ?>
                        <?php while ($sale = $salesResult->fetch_assoc()): ?>
                            <tr>
                                <td><?php echo $sale['sales_order_id']; ?></td>
                                <td><?php echo formatDate($sale['order_date']); ?></td>
                                <td><?php echo htmlspecialchars($sale['customer_name']); ?></td>
                                <td>
                                    <span class="badge bg-<?php echo ($sale['customer_type'] === 'wholesale') ? 'info' : 'success'; ?>">
                                        <?php echo ucfirst($sale['customer_type']); ?>
                                    </span>
                                </td>
                                <td><?php echo number_format($sale['quantity']); ?></td>
                                <td><?php echo formatCurrency($sale['unit_price']); ?></td>
                                <td><?php echo formatCurrency($sale['total_price']); ?></td>
                            </tr>
                        <?php endwhile; ?>
                    <?php else: ?>
                        <tr>
                            <td colspan="7" class="text-center">No sales records found</td>
                        </tr>
                    <?php endif; ?>
                </tbody>
            </table>
        </div>
        <div class="text-center mt-3">
            <a href="../sales/orders.php?book_id=<?php echo $id; ?>" class="btn btn-primary btn-sm">
                View All Sales
            </a>
        </div>
    </div>
</div>

<!-- Inventory Batches -->
<div class="card shadow mb-4">
    <div class="card-header py-3">
        <h6 class="m-0 font-weight-bold text-primary">Inventory Batches</h6>
    </div>
    <div class="card-body">
        <div class="table-responsive">
            <table class="table table-bordered" width="100%" cellspacing="0">
                <thead>
                    <tr>
                        <th>Batch ID</th>
                        <th>Receipt Date</th>
                        <th>Quantity</th>
                        <th>Production Cost/Unit</th>
                        <th>Total Cost</th>
                        <th>Production Order</th>
                    </tr>
                </thead>
                <tbody>
                    <?php if ($batchesResult && $batchesResult->num_rows > 0): ?>
                        <?php while ($batch = $batchesResult->fetch_assoc()): ?>
                            <tr>
                                <td><?php echo $batch['id']; ?></td>
                                <td><?php echo formatDate($batch['receipt_date']); ?></td>
                                <td><?php echo number_format($batch['quantity']); ?></td>
                                <td><?php echo formatCurrency($batch['production_cost_per_unit']); ?></td>
                                <td><?php echo formatCurrency($batch['production_cost_per_unit'] * $batch['quantity']); ?></td>
                                <td>
                                    <a href="../production/orders.php?id=<?php echo $batch['production_order_id']; ?>" class="btn btn-info btn-sm">
                                        #<?php echo $batch['production_order_id']; ?>
                                    </a>
                                </td>
                            </tr>
                        <?php endwhile; ?>
                    <?php else: ?>
                        <tr>
                            <td colspan="6" class="text-center">No inventory batches found</td>
                        </tr>
                    <?php endif; ?>
                </tbody>
            </table>
        </div>
        <div class="text-center mt-3">
            <a href="inventory.php?book_id=<?php echo $id; ?>" class="btn btn-primary btn-sm">
                View Full Inventory
            </a>
        </div>
    </div>
</div>

<?php require_once '../includes/footer.php'; ?>