<?php

/**
 * Change Password Page
 * Allows users to change their account password
 */
require_once 'includes/header.php';

// Get current user info
$userId = $_SESSION['user_id'];

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $currentPassword = $_POST['current_password'];
    $newPassword = $_POST['new_password'];
    $confirmPassword = $_POST['confirm_password'];

    // Validate input
    $errors = [];

    // Get current user password
    $userSql = "SELECT password FROM users WHERE id = $userId";
    $userResult = executeQuery($conn, $userSql);
    $user = $userResult->fetch_assoc();

    // Verify current password
    if (!password_verify($currentPassword, $user['password'])) {
        $errors[] = 'Current password is incorrect.';
    }

    // Check new password length
    if (strlen($newPassword) < 8) {
        $errors[] = 'New password must be at least 8 characters long.';
    }

    // Check if passwords match
    if ($newPassword !== $confirmPassword) {
        $errors[] = 'New password and confirmation do not match.';
    }

    // If no errors, update password
    if (empty($errors)) {
        // Hash the new password
        $hashedPassword = password_hash($newPassword, PASSWORD_DEFAULT);

        $updateSql = "UPDATE users SET password = '$hashedPassword' WHERE id = $userId";

        if (executeQuery($conn, $updateSql)) {
            logActivity('change_password', 'Changed account password');
            setFlashMessage('Password changed successfully.', 'success');
            redirect('profile.php');
        } else {
            $errors[] = 'Error changing password. Please try again.';
        }
    }
}
?>

<div class="d-flex justify-content-between align-items-center mb-4">
    <h1>Change Password</h1>
    <a href="profile.php" class="btn btn-secondary">
        <i class="fas fa-arrow-left"></i> Back to Profile
    </a>
</div>

<?php if (!empty($errors)): ?>
    <div class="alert alert-danger">
        <ul class="mb-0">
            <?php foreach ($errors as $error): ?>
                <li><?php echo $error; ?></li>
            <?php endforeach; ?>
        </ul>
    </div>
<?php endif; ?>

<div class="row">
    <div class="col-md-6">
        <div class="card shadow mb-4">
            <div class="card-header py-3">
                <h6 class="m-0 font-weight-bold text-primary">Change Your Password</h6>
            </div>
            <div class="card-body">
                <form method="post" action="">
                    <div class="mb-3">
                        <label for="current_password" class="form-label">Current Password *</label>
                        <input type="password" class="form-control" id="current_password" name="current_password" required>
                    </div>

                    <div class="mb-3">
                        <label for="new_password" class="form-label">New Password *</label>
                        <input type="password" class="form-control" id="new_password" name="new_password" required>
                        <small class="text-muted">Password must be at least 8 characters long</small>
                    </div>

                    <div class="mb-3">
                        <label for="confirm_password" class="form-label">Confirm New Password *</label>
                        <input type="password" class="form-control" id="confirm_password" name="confirm_password" required>
                    </div>

                    <div class="alert alert-info">
                        <i class="fas fa-info-circle"></i> For a strong password:
                        <ul class="mb-0">
                            <li>Use at least 8 characters</li>
                            <li>Include uppercase and lowercase letters</li>
                            <li>Include numbers and special characters</li>
                            <li>Avoid using easily guessable information</li>
                        </ul>
                    </div>

                    <div class="d-grid gap-2 d-md-flex justify-content-md-end">
                        <a href="profile.php" class="btn btn-secondary me-md-2">Cancel</a>
                        <button type="submit" class="btn btn-primary">Change Password</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <div class="col-md-6">
        <div class="card shadow mb-4">
            <div class="card-header py-3">
                <h6 class="m-0 font-weight-bold text-primary">Password Security Tips</h6>
            </div>
            <div class="card-body">
                <p>Follow these best practices to keep your account secure:</p>

                <ul>
                    <li><strong>Use unique passwords</strong> for different accounts and services.</li>
                    <li><strong>Change your password regularly</strong>, especially if you suspect it might have been compromised.</li>
                    <li><strong>Never share your password</strong> with anyone, including colleagues.</li>
                    <li><strong>Don't use personal information</strong> like your name, birthdate, or common words.</li>
                    <li><strong>Consider using a password manager</strong> to generate and store strong passwords securely.</li>
                    <li><strong>Avoid writing down your password</strong> or storing it in an unsecured location.</li>
                </ul>

                <p class="mb-0">If you believe your account has been compromised, change your password immediately and contact your system administrator.</p>
            </div>
        </div>
    </div>
</div>

<?php require_once 'includes/footer.php'; ?>