<?php

/**
 * Add/Edit Expense Page
 * Allows adding new expenses or editing existing ones
 */
require_once '../includes/header.php';

// Check if this is an edit request
$isEdit = isset($_GET['id']) && !empty($_GET['id']);
$expenseId = $isEdit ? (int)$_GET['id'] : 0;

// Initialize variables
$expenseType = '';
$amount = '';
$paymentDate = date('Y-m-d');
$recipient = '';
$description = '';
$referenceNumber = '';
$paymentMethod = 'cash';

// If editing, get expense data
if ($isEdit) {
    $sql = "SELECT * FROM expenses WHERE id = $expenseId";
    $result = executeQuery($conn, $sql);

    if ($result && $result->num_rows > 0) {
        $expense = $result->fetch_assoc();
        $expenseType = $expense['expense_type'];
        $amount = $expense['amount'];
        $paymentDate = $expense['payment_date'];
        $recipient = $expense['recipient'];
        $description = $expense['description'];
        $referenceNumber = $expense['reference_number'];
        $paymentMethod = $expense['payment_method'];
    } else {
        setFlashMessage('Expense not found.', 'danger');
        redirect('finance/expenses.php');
    }
}

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Sanitize input
    $expenseType = sanitizeInput($conn, $_POST['expense_type']);
    $amount = (float)$_POST['amount'];
    $paymentDate = sanitizeInput($conn, $_POST['payment_date']);
    $recipient = sanitizeInput($conn, $_POST['recipient']);
    $description = sanitizeInput($conn, $_POST['description']);
    $referenceNumber = sanitizeInput($conn, $_POST['reference_number']);
    $paymentMethod = sanitizeInput($conn, $_POST['payment_method']);

    // Validate input
    $errors = [];

    if (empty($expenseType)) {
        $errors[] = 'Expense type is required.';
    }

    if ($amount <= 0) {
        $errors[] = 'Amount must be greater than zero.';
    }

    if (empty($paymentDate)) {
        $errors[] = 'Payment date is required.';
    }

    if (empty($recipient)) {
        $errors[] = 'Recipient is required.';
    }

    if (empty($paymentMethod)) {
        $errors[] = 'Payment method is required.';
    }

    // If no errors, save data
    if (empty($errors)) {
        if ($isEdit) {
            // Update existing expense
            $sql = "UPDATE expenses SET 
                    expense_type = '$expenseType', 
                    amount = $amount, 
                    payment_date = '$paymentDate', 
                    recipient = '$recipient', 
                    description = '$description', 
                    reference_number = '$referenceNumber', 
                    payment_method = '$paymentMethod' 
                    WHERE id = $expenseId";

            $action = 'update_expense';
            $message = 'Expense updated successfully.';
            $logDescription = "Updated expense ID: $expenseId";
        } else {
            // Add new expense
            $sql = "INSERT INTO expenses (
                        expense_type, 
                        amount, 
                        payment_date, 
                        recipient, 
                        description, 
                        reference_number, 
                        payment_method
                    ) VALUES (
                        '$expenseType', 
                        $amount, 
                        '$paymentDate', 
                        '$recipient', 
                        '$description', 
                        '$referenceNumber', 
                        '$paymentMethod'
                    )";

            $action = 'add_expense';
            $message = 'Expense added successfully.';
            $logDescription = "Added new $expenseType expense: $amount to $recipient";
        }

        if (executeQuery($conn, $sql)) {
            logActivity($action, $logDescription);
            setFlashMessage($message, 'success');
            redirect('finance/expenses.php');
        } else {
            $errors[] = 'Error saving expense. Please try again.';
        }
    }
}
?>

<div class="d-flex justify-content-between align-items-center mb-4">
    <h1><?php echo $isEdit ? 'Edit Expense' : 'Add New Expense'; ?></h1>
    <a href="expenses.php" class="btn btn-secondary">
        <i class="fas fa-arrow-left"></i> Back to Expenses
    </a>
</div>

<?php if (!empty($errors)): ?>
    <div class="alert alert-danger">
        <ul class="mb-0">
            <?php foreach ($errors as $error): ?>
                <li><?php echo $error; ?></li>
            <?php endforeach; ?>
        </ul>
    </div>
<?php endif; ?>

<div class="card shadow mb-4">
    <div class="card-header py-3">
        <h6 class="m-0 font-weight-bold text-primary">
            <?php echo $isEdit ? 'Edit Expense Details' : 'Enter Expense Details'; ?>
        </h6>
    </div>
    <div class="card-body">
        <form method="post" action="">
            <div class="row mb-3">
                <div class="col-md-6">
                    <label for="expense_type" class="form-label">Expense Type *</label>
                    <select name="expense_type" id="expense_type" class="form-select" required>
                        <option value="">Select Expense Type</option>
                        <option value="debt" <?php echo ($expenseType === 'debt') ? 'selected' : ''; ?>>Debt Payment</option>
                        <option value="salary" <?php echo ($expenseType === 'salary') ? 'selected' : ''; ?>>Salary Payment</option>
                        <option value="miscellaneous" <?php echo ($expenseType === 'miscellaneous') ? 'selected' : ''; ?>>Miscellaneous</option>
                    </select>
                </div>
                <div class="col-md-6">
                    <label for="amount" class="form-label">Amount *</label>
                    <div class="input-group">
                        <span class="input-group-text">₹</span>
                        <input type="number" class="form-control" id="amount" name="amount" value="<?php echo htmlspecialchars($amount); ?>" min="0.01" step="0.01" required>
                    </div>
                </div>
            </div>

            <div class="row mb-3">
                <div class="col-md-6">
                    <label for="payment_date" class="form-label">Payment Date *</label>
                    <input type="date" class="form-control" id="payment_date" name="payment_date" value="<?php echo htmlspecialchars($paymentDate); ?>" required>
                </div>
                <div class="col-md-6">
                    <label for="recipient" class="form-label">Recipient *</label>
                    <input type="text" class="form-control" id="recipient" name="recipient" value="<?php echo htmlspecialchars($recipient); ?>" required>
                </div>
            </div>

            <div class="row mb-3">
                <div class="col-md-6">
                    <label for="payment_method" class="form-label">Payment Method *</label>
                    <select name="payment_method" id="payment_method" class="form-select" required>
                        <option value="cash" <?php echo ($paymentMethod === 'cash') ? 'selected' : ''; ?>>Cash</option>
                        <option value="check" <?php echo ($paymentMethod === 'check') ? 'selected' : ''; ?>>Check</option>
                        <option value="bank_transfer" <?php echo ($paymentMethod === 'bank_transfer') ? 'selected' : ''; ?>>Bank Transfer</option>
                        <option value="other" <?php echo ($paymentMethod === 'other') ? 'selected' : ''; ?>>Other</option>
                    </select>
                </div>
                <div class="col-md-6">
                    <label for="reference_number" class="form-label">Reference Number</label>
                    <input type="text" class="form-control" id="reference_number" name="reference_number" value="<?php echo htmlspecialchars($referenceNumber); ?>">
                    <small class="text-muted">Check number, transaction ID, etc.</small>
                </div>
            </div>

            <div class="mb-3">
                <label for="description" class="form-label">Description</label>
                <textarea class="form-control" id="description" name="description" rows="3"><?php echo htmlspecialchars($description); ?></textarea>
            </div>

            <div class="d-grid gap-2 d-md-flex justify-content-md-end">
                <button type="reset" class="btn btn-secondary me-md-2">Reset</button>
                <button type="submit" class="btn btn-primary">
                    <?php echo $isEdit ? 'Update Expense' : 'Add Expense'; ?>
                </button>
            </div>
        </form>
    </div>
</div>

<!-- Expense Type Guidelines -->
<div class="card shadow mb-4">
    <div class="card-header py-3">
        <h6 class="m-0 font-weight-bold text-primary">Expense Type Guidelines</h6>
    </div>
    <div class="card-body">
        <div class="row">
            <div class="col-md-4 mb-3">
                <div class="card h-100">
                    <div class="card-header bg-danger text-white">
                        Debt Payments
                    </div>
                    <div class="card-body">
                        <p>Use this category for:</p>
                        <ul>
                            <li>Loan repayments</li>
                            <li>Credit line payments</li>
                            <li>Equipment financing</li>
                            <li>Any other debt-related payments</li>
                        </ul>
                    </div>
                </div>
            </div>
            <div class="col-md-4 mb-3">
                <div class="card h-100">
                    <div class="card-header bg-info text-white">
                        Salary Payments
                    </div>
                    <div class="card-body">
                        <p>Use this category for:</p>
                        <ul>
                            <li>Employee salaries</li>
                            <li>Contractor payments</li>
                            <li>Commissions</li>
                            <li>Bonuses</li>
                            <li>Other compensation</li>
                        </ul>
                    </div>
                </div>
            </div>
            <div class="col-md-4 mb-3">
                <div class="card h-100">
                    <div class="card-header bg-warning text-dark">
                        Miscellaneous
                    </div>
                    <div class="card-body">
                        <p>Use this category for:</p>
                        <ul>
                            <li>Utilities</li>
                            <li>Rent</li>
                            <li>Office supplies</li>
                            <li>Marketing expenses</li>
                            <li>Other operational costs</li>
                        </ul>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<?php require_once '../includes/footer.php'; ?>