<?php

/**
 * Add/Edit Owner Withdrawal Page
 * Allows adding new withdrawals or editing existing ones
 */
require_once '../includes/header.php';

// Check if this is an edit request
$isEdit = isset($_GET['id']) && !empty($_GET['id']);
$withdrawalId = $isEdit ? (int)$_GET['id'] : 0;

// Initialize variables
$amount = '';
$withdrawalDate = date('Y-m-d');
$notes = '';

// Calculate available funds
$revenuesSql = "SELECT SUM(paid_amount) AS total_revenue FROM sales_orders";
$revenuesResult = executeQuery($conn, $revenuesSql);
$totalRevenues = $revenuesResult->fetch_assoc()['total_revenue'] ?? 0;

$expensesSql = "SELECT SUM(amount) AS total_expenses FROM expenses";
$expensesResult = executeQuery($conn, $expensesSql);
$totalExpenses = $expensesResult->fetch_assoc()['total_expenses'] ?? 0;

$withdrawalsSql = "SELECT SUM(amount) AS total_withdrawals FROM owner_withdrawals";
$withdrawalsResult = executeQuery($conn, $withdrawalsSql);
$totalWithdrawals = $withdrawalsResult->fetch_assoc()['total_withdrawals'] ?? 0;

// If editing, exclude the current withdrawal from the calculation
if ($isEdit) {
    $currentWithdrawalSql = "SELECT amount FROM owner_withdrawals WHERE id = $withdrawalId";
    $currentWithdrawalResult = executeQuery($conn, $currentWithdrawalSql);
    $currentWithdrawal = $currentWithdrawalResult->fetch_assoc()['amount'] ?? 0;
    $totalWithdrawals -= $currentWithdrawal;
}

$availableFunds = $totalRevenues - $totalExpenses - $totalWithdrawals;

// If editing, get withdrawal data
if ($isEdit) {
    $sql = "SELECT * FROM owner_withdrawals WHERE id = $withdrawalId";
    $result = executeQuery($conn, $sql);

    if ($result && $result->num_rows > 0) {
        $withdrawal = $result->fetch_assoc();
        $amount = $withdrawal['amount'];
        $withdrawalDate = $withdrawal['withdrawal_date'];
        $notes = $withdrawal['notes'];
    } else {
        setFlashMessage('Withdrawal record not found.', 'danger');
        redirect('finance/withdrawals.php');
    }
}

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Sanitize input
    $amount = (float)$_POST['amount'];
    $withdrawalDate = sanitizeInput($conn, $_POST['withdrawal_date']);
    $notes = sanitizeInput($conn, $_POST['notes']);

    // Validate input
    $errors = [];

    if ($amount <= 0) {
        $errors[] = 'Amount must be greater than zero.';
    }

    if (empty($withdrawalDate)) {
        $errors[] = 'Withdrawal date is required.';
    }

    // Check if amount exceeds available funds (for new withdrawals or increased amounts)
    if (!$isEdit || $amount > $currentWithdrawal) {
        $checkAmount = $isEdit ? $amount - $currentWithdrawal : $amount;

        if ($checkAmount > $availableFunds) {
            $errors[] = 'Withdrawal amount exceeds available funds. Maximum available: ' . formatCurrency($availableFunds + ($isEdit ? $currentWithdrawal : 0));
        }
    }

    // If no errors, save data
    if (empty($errors)) {
        if ($isEdit) {
            // Update existing withdrawal
            $sql = "UPDATE owner_withdrawals SET 
                    amount = $amount, 
                    withdrawal_date = '$withdrawalDate', 
                    notes = '$notes' 
                    WHERE id = $withdrawalId";

            $action = 'update_withdrawal';
            $message = 'Withdrawal record updated successfully.';
            $logDescription = "Updated owner withdrawal ID: $withdrawalId";
        } else {
            // Add new withdrawal
            $sql = "INSERT INTO owner_withdrawals (
                        amount, 
                        withdrawal_date, 
                        notes
                    ) VALUES (
                        $amount, 
                        '$withdrawalDate', 
                        '$notes'
                    )";

            $action = 'add_withdrawal';
            $message = 'Withdrawal recorded successfully.';
            $logDescription = "Added new owner withdrawal: $amount";
        }

        if (executeQuery($conn, $sql)) {
            logActivity($action, $logDescription);
            setFlashMessage($message, 'success');
            redirect('finance/withdrawals.php');
        } else {
            $errors[] = 'Error saving withdrawal record. Please try again.';
        }
    }
}
?>

<div class="d-flex justify-content-between align-items-center mb-4">
    <h1><?php echo $isEdit ? 'Edit Withdrawal' : 'Record Owner Withdrawal'; ?></h1>
    <a href="withdrawals.php" class="btn btn-secondary">
        <i class="fas fa-arrow-left"></i> Back to Withdrawals
    </a>
</div>

<?php if (!empty($errors)): ?>
    <div class="alert alert-danger">
        <ul class="mb-0">
            <?php foreach ($errors as $error): ?>
                <li><?php echo $error; ?></li>
            <?php endforeach; ?>
        </ul>
    </div>
<?php endif; ?>

<!-- Financial Summary Card -->
<div class="card shadow mb-4">
    <div class="card-header py-3">
        <h6 class="m-0 font-weight-bold text-primary">Financial Summary</h6>
    </div>
    <div class="card-body">
        <div class="row">
            <div class="col-md-6">
                <table class="table table-bordered">
                    <tr>
                        <th>Total Revenue</th>
                        <td class="text-success"><?php echo formatCurrency($totalRevenues); ?></td>
                    </tr>
                    <tr>
                        <th>Total Expenses</th>
                        <td class="text-danger"><?php echo formatCurrency($totalExpenses); ?></td>
                    </tr>
                    <tr>
                        <th>Previous Withdrawals</th>
                        <td class="text-warning"><?php echo formatCurrency($totalWithdrawals); ?></td>
                    </tr>
                    <tr class="table-primary">
                        <th>Available Funds</th>
                        <td class="fw-bold">
                            <?php echo formatCurrency($availableFunds + ($isEdit ? $currentWithdrawal : 0)); ?>
                            <?php if ($isEdit): ?>
                                <small class="text-muted">(Including current withdrawal)</small>
                            <?php endif; ?>
                        </td>
                    </tr>
                </table>
            </div>
            <div class="col-md-6">
                <div class="alert <?php echo $availableFunds > 0 ? 'alert-success' : 'alert-danger'; ?>">
                    <h5 class="alert-heading">
                        <i class="fas <?php echo $availableFunds > 0 ? 'fa-check-circle' : 'fa-exclamation-triangle'; ?>"></i>
                        Funds Status
                    </h5>
                    <?php if ($availableFunds > 0 || $isEdit): ?>
                        <p>There are sufficient funds available for withdrawal.</p>
                        <hr>
                        <p class="mb-0">Maximum withdrawal amount: <?php echo formatCurrency($availableFunds + ($isEdit ? $currentWithdrawal : 0)); ?></p>
                    <?php else: ?>
                        <p>There are no funds available for withdrawal at this time.</p>
                        <hr>
                        <p class="mb-0">All profits have been withdrawn or expenses exceed revenue.</p>
                    <?php endif; ?>
                </div>
            </div>
        </div>
    </div>
</div>

<div class="card shadow mb-4">
    <div class="card-header py-3">
        <h6 class="m-0 font-weight-bold text-primary">
            <?php echo $isEdit ? 'Edit Withdrawal Details' : 'Withdrawal Details'; ?>
        </h6>
    </div>
    <div class="card-body">
        <form method="post" action="">
            <div class="row mb-3">
                <div class="col-md-6">
                    <label for="amount" class="form-label">Withdrawal Amount *</label>
                    <div class="input-group">
                        <span class="input-group-text">₹</span>
                        <input type="number" class="form-control" id="amount" name="amount" value="<?php echo htmlspecialchars($amount); ?>" min="0.01" step="0.01" required>
                    </div>
                </div>
                <div class="col-md-6">
                    <label for="withdrawal_date" class="form-label">Withdrawal Date *</label>
                    <input type="date" class="form-control" id="withdrawal_date" name="withdrawal_date" value="<?php echo htmlspecialchars($withdrawalDate); ?>" required>
                </div>
            </div>

            <div class="mb-3">
                <label for="notes" class="form-label">Notes</label>
                <textarea class="form-control" id="notes" name="notes" rows="3"><?php echo htmlspecialchars($notes); ?></textarea>
                <small class="text-muted">Optional: Purpose of withdrawal, reference numbers, etc.</small>
            </div>

            <div class="d-grid gap-2 d-md-flex justify-content-md-end">
                <button type="reset" class="btn btn-secondary me-md-2">Reset</button>
                <button type="submit" class="btn btn-primary">
                    <?php echo $isEdit ? 'Update Withdrawal' : 'Record Withdrawal'; ?>
                </button>
            </div>
        </form>
    </div>
</div>

<!-- Withdrawal Guidelines -->
<div class="card shadow mb-4">
    <div class="card-header py-3">
        <h6 class="m-0 font-weight-bold text-primary">Withdrawal Guidelines</h6>
    </div>
    <div class="card-body">
        <div class="alert alert-info">
            <h5 class="alert-heading"><i class="fas fa-info-circle"></i> About Owner Withdrawals</h5>
            <p>Owner withdrawals represent the profits you take out of the business. According to your business workflow, these withdrawals happen after:</p>
            <ol>
                <li>All debts have been paid</li>
                <li>All salaries have been paid</li>
                <li>All miscellaneous expenses have been covered</li>
            </ol>
            <p class="mb-0">The system calculates available funds by subtracting all expenses and previous withdrawals from the total revenue.</p>
        </div>

        <div class="row">
            <div class="col-md-6">
                <div class="card h-100">
                    <div class="card-header bg-success text-white">
                        Best Practices
                    </div>
                    <div class="card-body">
                        <ul>
                            <li>Maintain a reserve of funds in the business for unexpected expenses</li>
                            <li>Record all withdrawals promptly to maintain accurate financial records</li>
                            <li>Add detailed notes for each withdrawal for better tracking</li>
                            <li>Consider regular, smaller withdrawals rather than infrequent large ones</li>
                            <li>Review financial reports regularly before making withdrawal decisions</li>
                        </ul>
                    </div>
                </div>
            </div>
            <div class="col-md-6">
                <div class="card h-100">
                    <div class="card-header bg-warning text-dark">
                        Important Considerations
                    </div>
                    <div class="card-body">
                        <ul>
                            <li>The system won't allow withdrawals greater than available funds</li>
                            <li>Consider upcoming expenses and material needs before withdrawing</li>
                            <li>Withdrawal amounts may have tax implications</li>
                            <li>Keep personal and business finances separate for cleaner accounting</li>
                            <li>Maintain documentation for all withdrawals for tax purposes</li>
                        </ul>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<?php require_once '../includes/footer.php'; ?>