<?php

/**
 * Expenses Page
 * Manages expenses (debts, salaries, miscellaneous)
 */
require_once '../includes/header.php';

// Handle delete request
if (isset($_GET['delete']) && !empty($_GET['delete'])) {
    $id = (int)$_GET['delete'];

    $deleteSql = "DELETE FROM expenses WHERE id = $id";
    if (executeQuery($conn, $deleteSql)) {
        setFlashMessage('Expense deleted successfully.', 'success');
        logActivity('delete_expense', "Deleted expense ID: $id");
    } else {
        setFlashMessage('Error deleting expense.', 'danger');
    }
    redirect('finance/expenses.php');
}

// Get filter parameters
$expenseType = isset($_GET['type']) ? sanitizeInput($conn, $_GET['type']) : '';
$dateFrom = isset($_GET['date_from']) ? sanitizeInput($conn, $_GET['date_from']) : '';
$dateTo = isset($_GET['date_to']) ? sanitizeInput($conn, $_GET['date_to']) : '';
$searchTerm = isset($_GET['search']) ? sanitizeInput($conn, $_GET['search']) : '';

// Build query with filters
$sql = "SELECT * FROM expenses WHERE 1=1";

if (!empty($expenseType)) {
    $sql .= " AND expense_type = '$expenseType'";
}

if (!empty($dateFrom)) {
    $sql .= " AND payment_date >= '$dateFrom'";
}

if (!empty($dateTo)) {
    $sql .= " AND payment_date <= '$dateTo'";
}

if (!empty($searchTerm)) {
    $sql .= " AND (recipient LIKE '%$searchTerm%' OR description LIKE '%$searchTerm%' OR reference_number LIKE '%$searchTerm%')";
}

$sql .= " ORDER BY payment_date DESC";

$result = executeQuery($conn, $sql);

// Calculate summary statistics
$summarySql = "SELECT 
                expense_type, 
                COUNT(*) as count, 
                SUM(amount) as total_amount 
              FROM expenses 
              WHERE 1=1";

if (!empty($dateFrom)) {
    $summarySql .= " AND payment_date >= '$dateFrom'";
}

if (!empty($dateTo)) {
    $summarySql .= " AND payment_date <= '$dateTo'";
}

$summarySql .= " GROUP BY expense_type";
$summaryResult = executeQuery($conn, $summarySql);

$summary = [
    'debt' => ['count' => 0, 'total' => 0],
    'salary' => ['count' => 0, 'total' => 0],
    'miscellaneous' => ['count' => 0, 'total' => 0]
];

if ($summaryResult && $summaryResult->num_rows > 0) {
    while ($row = $summaryResult->fetch_assoc()) {
        $summary[$row['expense_type']]['count'] = $row['count'];
        $summary[$row['expense_type']]['total'] = $row['total_amount'];
    }
}

$totalExpenses = $summary['debt']['total'] + $summary['salary']['total'] + $summary['miscellaneous']['total'];
?>

<div class="d-flex justify-content-between align-items-center mb-4">
    <h1>Expenses Management</h1>
    <a href="add_expense.php" class="btn btn-primary">
        <i class="fas fa-plus"></i> Add New Expense
    </a>
</div>

<!-- Expense Summary Cards -->
<div class="row mb-4">
    <!-- Debt Expenses -->
    <div class="col-xl-3 col-md-6 mb-4">
        <div class="card border-left-danger shadow h-100 py-2">
            <div class="card-body">
                <div class="row no-gutters align-items-center">
                    <div class="col mr-2">
                        <div class="text-xs font-weight-bold text-danger text-uppercase mb-1">
                            Debt Payments</div>
                        <div class="h5 mb-0 font-weight-bold text-gray-800">
                            <?php echo formatCurrency($summary['debt']['total']); ?>
                        </div>
                        <div class="small mt-2">
                            <?php echo number_format($summary['debt']['count']); ?> payments
                        </div>
                    </div>
                    <div class="col-auto">
                        <i class="fas fa-credit-card fa-2x text-gray-300"></i>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <!-- Salary Expenses -->
    <div class="col-xl-3 col-md-6 mb-4">
        <div class="card border-left-info shadow h-100 py-2">
            <div class="card-body">
                <div class="row no-gutters align-items-center">
                    <div class="col mr-2">
                        <div class="text-xs font-weight-bold text-info text-uppercase mb-1">
                            Salary Payments</div>
                        <div class="h5 mb-0 font-weight-bold text-gray-800">
                            <?php echo formatCurrency($summary['salary']['total']); ?>
                        </div>
                        <div class="small mt-2">
                            <?php echo number_format($summary['salary']['count']); ?> payments
                        </div>
                    </div>
                    <div class="col-auto">
                        <i class="fas fa-users fa-2x text-gray-300"></i>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <!-- Miscellaneous Expenses -->
    <div class="col-xl-3 col-md-6 mb-4">
        <div class="card border-left-warning shadow h-100 py-2">
            <div class="card-body">
                <div class="row no-gutters align-items-center">
                    <div class="col mr-2">
                        <div class="text-xs font-weight-bold text-warning text-uppercase mb-1">
                            Miscellaneous</div>
                        <div class="h5 mb-0 font-weight-bold text-gray-800">
                            <?php echo formatCurrency($summary['miscellaneous']['total']); ?>
                        </div>
                        <div class="small mt-2">
                            <?php echo number_format($summary['miscellaneous']['count']); ?> payments
                        </div>
                    </div>
                    <div class="col-auto">
                        <i class="fas fa-clipboard-list fa-2x text-gray-300"></i>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <!-- Total Expenses -->
    <div class="col-xl-3 col-md-6 mb-4">
        <div class="card border-left-primary shadow h-100 py-2">
            <div class="card-body">
                <div class="row no-gutters align-items-center">
                    <div class="col mr-2">
                        <div class="text-xs font-weight-bold text-primary text-uppercase mb-1">
                            Total Expenses</div>
                        <div class="h5 mb-0 font-weight-bold text-gray-800">
                            <?php echo formatCurrency($totalExpenses); ?>
                        </div>
                        <div class="small mt-2">
                            <?php echo number_format($summary['debt']['count'] + $summary['salary']['count'] + $summary['miscellaneous']['count']); ?> payments
                        </div>
                    </div>
                    <div class="col-auto">
                        <i class="fas fa-money-bill-wave fa-2x text-gray-300"></i>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<!-- Filters -->
<div class="card mb-4">
    <div class="card-header">
        <i class="fas fa-filter"></i> Filter Expenses
    </div>
    <div class="card-body">
        <form method="get" action="" class="row g-3">
            <div class="col-md-3">
                <label for="type" class="form-label">Expense Type</label>
                <select name="type" id="type" class="form-select">
                    <option value="">All Types</option>
                    <option value="debt" <?php echo ($expenseType === 'debt') ? 'selected' : ''; ?>>Debt Payments</option>
                    <option value="salary" <?php echo ($expenseType === 'salary') ? 'selected' : ''; ?>>Salary Payments</option>
                    <option value="miscellaneous" <?php echo ($expenseType === 'miscellaneous') ? 'selected' : ''; ?>>Miscellaneous</option>
                </select>
            </div>
            <div class="col-md-3">
                <label for="date_from" class="form-label">Date From</label>
                <input type="date" class="form-control" id="date_from" name="date_from" value="<?php echo htmlspecialchars($dateFrom); ?>">
            </div>
            <div class="col-md-3">
                <label for="date_to" class="form-label">Date To</label>
                <input type="date" class="form-control" id="date_to" name="date_to" value="<?php echo htmlspecialchars($dateTo); ?>">
            </div>
            <div class="col-md-3">
                <label for="search" class="form-label">Search</label>
                <input type="text" class="form-control" id="search" name="search" value="<?php echo htmlspecialchars($searchTerm); ?>" placeholder="Recipient, description...">
            </div>
            <div class="col-12 d-flex justify-content-end">
                <button type="submit" class="btn btn-primary me-2">Filter</button>
                <a href="expenses.php" class="btn btn-secondary">Reset</a>
            </div>
        </form>
    </div>
</div>

<!-- Expenses Table -->
<div class="card shadow mb-4">
    <div class="card-header py-3">
        <h6 class="m-0 font-weight-bold text-primary">Expenses List</h6>
    </div>
    <div class="card-body">
        <div class="table-responsive">
            <table class="table table-bordered" width="100%" cellspacing="0">
                <thead>
                    <tr>
                        <th>ID</th>
                        <th>Date</th>
                        <th>Type</th>
                        <th>Recipient</th>
                        <th>Amount</th>
                        <th>Payment Method</th>
                        <th>Reference</th>
                        <th>Description</th>
                        <th>Actions</th>
                    </tr>
                </thead>
                <tbody>
                    <?php if ($result && $result->num_rows > 0): ?>
                        <?php while ($row = $result->fetch_assoc()): ?>
                            <tr>
                                <td><?php echo $row['id']; ?></td>
                                <td><?php echo formatDate($row['payment_date']); ?></td>
                                <td>
                                    <span class="badge bg-<?php
                                                            echo ($row['expense_type'] === 'debt') ? 'danger' : (($row['expense_type'] === 'salary') ? 'info' : 'warning');
                                                            ?>">
                                        <?php echo ucfirst($row['expense_type']); ?>
                                    </span>
                                </td>
                                <td><?php echo htmlspecialchars($row['recipient']); ?></td>
                                <td><?php echo formatCurrency($row['amount']); ?></td>
                                <td><?php echo ucfirst(str_replace('_', ' ', $row['payment_method'])); ?></td>
                                <td><?php echo htmlspecialchars($row['reference_number'] ?? 'N/A'); ?></td>
                                <td><?php echo htmlspecialchars($row['description'] ?? ''); ?></td>
                                <td>
                                    <a href="add_expense.php?id=<?php echo $row['id']; ?>" class="btn btn-primary btn-sm">
                                        <i class="fas fa-edit"></i>
                                    </a>
                                    <a href="expenses.php?delete=<?php echo $row['id']; ?>" class="btn btn-danger btn-sm" onclick="return confirm('Are you sure you want to delete this expense?');">
                                        <i class="fas fa-trash"></i>
                                    </a>
                                </td>
                            </tr>
                        <?php endwhile; ?>
                    <?php else: ?>
                        <tr>
                            <td colspan="9" class="text-center">No expenses found</td>
                        </tr>
                    <?php endif; ?>
                </tbody>
            </table>
        </div>
    </div>
</div>

<!-- Expense Distribution Chart -->
<div class="card shadow mb-4">
    <div class="card-header py-3">
        <h6 class="m-0 font-weight-bold text-primary">Expense Distribution</h6>
    </div>
    <div class="card-body">
        <div class="chart-container" style="position: relative; height:300px; width:100%">
            <canvas id="expenseDistributionChart"></canvas>
        </div>
    </div>
</div>

<!-- Chart.js -->
<script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
<script>
    // Expense Distribution Chart
    const ctx = document.getElementById('expenseDistributionChart').getContext('2d');
    const expenseDistributionChart = new Chart(ctx, {
        type: 'pie',
        data: {
            labels: ['Debt Payments', 'Salary Payments', 'Miscellaneous'],
            datasets: [{
                data: [
                    <?php echo $summary['debt']['total']; ?>,
                    <?php echo $summary['salary']['total']; ?>,
                    <?php echo $summary['miscellaneous']['total']; ?>
                ],
                backgroundColor: [
                    'rgba(231, 74, 59, 0.8)',
                    'rgba(54, 185, 204, 0.8)',
                    'rgba(246, 194, 62, 0.8)'
                ],
                borderColor: [
                    'rgba(231, 74, 59, 1)',
                    'rgba(54, 185, 204, 1)',
                    'rgba(246, 194, 62, 1)'
                ],
                borderWidth: 1
            }]
        },
        options: {
            responsive: true,
            maintainAspectRatio: false,
            plugins: {
                legend: {
                    position: 'bottom'
                },
                tooltip: {
                    callbacks: {
                        label: function(context) {
                            let label = context.label || '';
                            let value = context.raw || 0;
                            return label + ': ₹ ' + value.toLocaleString('en-IN', {
                                minimumFractionDigits: 2,
                                maximumFractionDigits: 2
                            });
                        }
                    }
                }
            }
        }
    });
</script>

<?php require_once '../includes/footer.php'; ?>