<?php

/**
 * Owner Withdrawals Page
 * Manages owner withdrawals from business profits
 */
require_once '../includes/header.php';

// Handle delete request
if (isset($_GET['delete']) && !empty($_GET['delete'])) {
    $id = (int)$_GET['delete'];

    $deleteSql = "DELETE FROM owner_withdrawals WHERE id = $id";
    if (executeQuery($conn, $deleteSql)) {
        setFlashMessage('Withdrawal record deleted successfully.', 'success');
        logActivity('delete_withdrawal', "Deleted owner withdrawal ID: $id");
    } else {
        setFlashMessage('Error deleting withdrawal record.', 'danger');
    }
    redirect('finance/withdrawals.php');
}

// Get filter parameters
$yearFilter = isset($_GET['year']) ? (int)$_GET['year'] : date('Y');
$monthFilter = isset($_GET['month']) ? (int)$_GET['month'] : 0;

// Build query with filters
$sql = "SELECT * FROM owner_withdrawals WHERE 1=1";

if ($yearFilter > 0) {
    $sql .= " AND YEAR(withdrawal_date) = $yearFilter";
}

if ($monthFilter > 0) {
    $sql .= " AND MONTH(withdrawal_date) = $monthFilter";
}

$sql .= " ORDER BY withdrawal_date DESC";

$result = executeQuery($conn, $sql);

// Get available years for filter dropdown
$yearsSql = "SELECT DISTINCT YEAR(withdrawal_date) AS year FROM owner_withdrawals ORDER BY year DESC";
$yearsResult = executeQuery($conn, $yearsSql);
$years = [];

if ($yearsResult && $yearsResult->num_rows > 0) {
    while ($yearRow = $yearsResult->fetch_assoc()) {
        $years[] = $yearRow['year'];
    }
}

// If no years in database yet, add current year
if (empty($years)) {
    $years[] = date('Y');
}

// Calculate total withdrawals for the filtered period
$totalSql = "SELECT SUM(amount) AS total FROM owner_withdrawals WHERE 1=1";

if ($yearFilter > 0) {
    $totalSql .= " AND YEAR(withdrawal_date) = $yearFilter";
}

if ($monthFilter > 0) {
    $totalSql .= " AND MONTH(withdrawal_date) = $monthFilter";
}

$totalResult = executeQuery($conn, $totalSql);
$totalWithdrawals = $totalResult->fetch_assoc()['total'] ?? 0;

// Calculate the available funds
$revenuesSql = "SELECT SUM(paid_amount) AS total_revenue FROM sales_orders";
$revenuesResult = executeQuery($conn, $revenuesSql);
$totalRevenues = $revenuesResult->fetch_assoc()['total_revenue'] ?? 0;

$expensesSql = "SELECT SUM(amount) AS total_expenses FROM expenses";
$expensesResult = executeQuery($conn, $expensesSql);
$totalExpenses = $expensesResult->fetch_assoc()['total_expenses'] ?? 0;

$withdrawalsSql = "SELECT SUM(amount) AS total_withdrawals FROM owner_withdrawals";
$withdrawalsResult = executeQuery($conn, $withdrawalsSql);
$allTimeWithdrawals = $withdrawalsResult->fetch_assoc()['total_withdrawals'] ?? 0;

$availableFunds = $totalRevenues - $totalExpenses - $allTimeWithdrawals;

// Get monthly withdrawal data for chart
$monthlySql = "SELECT 
                MONTH(withdrawal_date) AS month, 
                SUM(amount) AS monthly_total 
              FROM owner_withdrawals 
              WHERE YEAR(withdrawal_date) = $yearFilter 
              GROUP BY MONTH(withdrawal_date) 
              ORDER BY MONTH(withdrawal_date)";
$monthlyResult = executeQuery($conn, $monthlySql);

$monthlyData = array_fill(0, 12, 0);  // Initialize with zeros for all 12 months

if ($monthlyResult && $monthlyResult->num_rows > 0) {
    while ($monthRow = $monthlyResult->fetch_assoc()) {
        $monthIndex = (int)$monthRow['month'] - 1;  // Convert 1-based month to 0-based index
        $monthlyData[$monthIndex] = (float)$monthRow['monthly_total'];
    }
}
?>

<div class="d-flex justify-content-between align-items-center mb-4">
    <h1>Owner Withdrawals</h1>
    <div>
        <a href="reports.php" class="btn btn-info me-2">
            <i class="fas fa-chart-bar"></i> Financial Reports
        </a>
        <a href="add_withdrawal.php" class="btn btn-primary">
            <i class="fas fa-plus"></i> New Withdrawal
        </a>
    </div>
</div>

<!-- Financial Summary Cards -->
<div class="row mb-4">
    <!-- Total Revenue -->
    <div class="col-xl-3 col-md-6 mb-4">
        <div class="card border-left-success shadow h-100 py-2">
            <div class="card-body">
                <div class="row no-gutters align-items-center">
                    <div class="col mr-2">
                        <div class="text-xs font-weight-bold text-success text-uppercase mb-1">
                            Total Revenue</div>
                        <div class="h5 mb-0 font-weight-bold text-gray-800">
                            <?php echo formatCurrency($totalRevenues); ?>
                        </div>
                    </div>
                    <div class="col-auto">
                        <i class="fas fa-dollar-sign fa-2x text-gray-300"></i>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <!-- Total Expenses -->
    <div class="col-xl-3 col-md-6 mb-4">
        <div class="card border-left-danger shadow h-100 py-2">
            <div class="card-body">
                <div class="row no-gutters align-items-center">
                    <div class="col mr-2">
                        <div class="text-xs font-weight-bold text-danger text-uppercase mb-1">
                            Total Expenses</div>
                        <div class="h5 mb-0 font-weight-bold text-gray-800">
                            <?php echo formatCurrency($totalExpenses); ?>
                        </div>
                    </div>
                    <div class="col-auto">
                        <i class="fas fa-money-bill-wave fa-2x text-gray-300"></i>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <!-- Total Withdrawals -->
    <div class="col-xl-3 col-md-6 mb-4">
        <div class="card border-left-warning shadow h-100 py-2">
            <div class="card-body">
                <div class="row no-gutters align-items-center">
                    <div class="col mr-2">
                        <div class="text-xs font-weight-bold text-warning text-uppercase mb-1">
                            Total Withdrawals</div>
                        <div class="h5 mb-0 font-weight-bold text-gray-800">
                            <?php echo formatCurrency($allTimeWithdrawals); ?>
                        </div>
                    </div>
                    <div class="col-auto">
                        <i class="fas fa-hand-holding-usd fa-2x text-gray-300"></i>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <!-- Available Funds -->
    <div class="col-xl-3 col-md-6 mb-4">
        <div class="card border-left-info shadow h-100 py-2">
            <div class="card-body">
                <div class="row no-gutters align-items-center">
                    <div class="col mr-2">
                        <div class="text-xs font-weight-bold text-info text-uppercase mb-1">
                            Available Funds</div>
                        <div class="h5 mb-0 font-weight-bold text-gray-800">
                            <?php echo formatCurrency($availableFunds); ?>
                        </div>
                    </div>
                    <div class="col-auto">
                        <i class="fas fa-wallet fa-2x text-gray-300"></i>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<!-- Filters -->
<div class="card mb-4">
    <div class="card-header">
        <i class="fas fa-filter"></i> Filter Withdrawals
    </div>
    <div class="card-body">
        <form method="get" action="" class="row g-3">
            <div class="col-md-3">
                <label for="year" class="form-label">Year</label>
                <select name="year" id="year" class="form-select">
                    <?php foreach ($years as $year): ?>
                        <option value="<?php echo $year; ?>" <?php echo ($yearFilter == $year) ? 'selected' : ''; ?>>
                            <?php echo $year; ?>
                        </option>
                    <?php endforeach; ?>
                </select>
            </div>
            <div class="col-md-3">
                <label for="month" class="form-label">Month</label>
                <select name="month" id="month" class="form-select">
                    <option value="0">All Months</option>
                    <option value="1" <?php echo ($monthFilter == 1) ? 'selected' : ''; ?>>January</option>
                    <option value="2" <?php echo ($monthFilter == 2) ? 'selected' : ''; ?>>February</option>
                    <option value="3" <?php echo ($monthFilter == 3) ? 'selected' : ''; ?>>March</option>
                    <option value="4" <?php echo ($monthFilter == 4) ? 'selected' : ''; ?>>April</option>
                    <option value="5" <?php echo ($monthFilter == 5) ? 'selected' : ''; ?>>May</option>
                    <option value="6" <?php echo ($monthFilter == 6) ? 'selected' : ''; ?>>June</option>
                    <option value="7" <?php echo ($monthFilter == 7) ? 'selected' : ''; ?>>July</option>
                    <option value="8" <?php echo ($monthFilter == 8) ? 'selected' : ''; ?>>August</option>
                    <option value="9" <?php echo ($monthFilter == 9) ? 'selected' : ''; ?>>September</option>
                    <option value="10" <?php echo ($monthFilter == 10) ? 'selected' : ''; ?>>October</option>
                    <option value="11" <?php echo ($monthFilter == 11) ? 'selected' : ''; ?>>November</option>
                    <option value="12" <?php echo ($monthFilter == 12) ? 'selected' : ''; ?>>December</option>
                </select>
            </div>
            <div class="col-md-6 d-flex align-items-end">
                <button type="submit" class="btn btn-primary me-2">Filter</button>
                <a href="withdrawals.php" class="btn btn-secondary">Reset</a>

                <?php if ($availableFunds > 0): ?>
                    <a href="add_withdrawal.php" class="btn btn-success ms-auto">
                        <i class="fas fa-plus"></i> New Withdrawal (<?php echo formatCurrency($availableFunds); ?> Available)
                    </a>
                <?php else: ?>
                    <button class="btn btn-danger ms-auto" disabled>
                        <i class="fas fa-exclamation-triangle"></i> No Funds Available
                    </button>
                <?php endif; ?>
            </div>
        </form>
    </div>
</div>

<!-- Withdrawals Table -->
<div class="card shadow mb-4">
    <div class="card-header py-3 d-flex justify-content-between align-items-center">
        <h6 class="m-0 font-weight-bold text-primary">Withdrawal History</h6>
        <span class="badge bg-primary">Total: <?php echo formatCurrency($totalWithdrawals); ?></span>
    </div>
    <div class="card-body">
        <div class="table-responsive">
            <table class="table table-bordered" width="100%" cellspacing="0">
                <thead>
                    <tr>
                        <th>ID</th>
                        <th>Date</th>
                        <th>Amount</th>
                        <th>Notes</th>
                        <th>Actions</th>
                    </tr>
                </thead>
                <tbody>
                    <?php if ($result && $result->num_rows > 0): ?>
                        <?php while ($row = $result->fetch_assoc()): ?>
                            <tr>
                                <td><?php echo $row['id']; ?></td>
                                <td><?php echo formatDate($row['withdrawal_date']); ?></td>
                                <td><?php echo formatCurrency($row['amount']); ?></td>
                                <td><?php echo htmlspecialchars($row['notes'] ?? ''); ?></td>
                                <td>
                                    <a href="add_withdrawal.php?id=<?php echo $row['id']; ?>" class="btn btn-primary btn-sm">
                                        <i class="fas fa-edit"></i>
                                    </a>
                                    <a href="withdrawals.php?delete=<?php echo $row['id']; ?>" class="btn btn-danger btn-sm" onclick="return confirm('Are you sure you want to delete this withdrawal record?');">
                                        <i class="fas fa-trash"></i>
                                    </a>
                                </td>
                            </tr>
                        <?php endwhile; ?>
                    <?php else: ?>
                        <tr>
                            <td colspan="5" class="text-center">No withdrawal records found</td>
                        </tr>
                    <?php endif; ?>
                </tbody>
            </table>
        </div>
    </div>
</div>

<!-- Monthly Withdrawals Chart -->
<div class="card shadow mb-4">
    <div class="card-header py-3">
        <h6 class="m-0 font-weight-bold text-primary">Monthly Withdrawals for <?php echo $yearFilter; ?></h6>
    </div>
    <div class="card-body">
        <div class="chart-container" style="position: relative; height:400px; width:100%">
            <canvas id="monthlyWithdrawalsChart"></canvas>
        </div>
    </div>
</div>

<!-- Chart.js -->
<script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
<script>
    // Monthly Withdrawals Chart
    const ctx = document.getElementById('monthlyWithdrawalsChart').getContext('2d');
    const monthlyWithdrawalsChart = new Chart(ctx, {
        type: 'bar',
        data: {
            labels: ['Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec'],
            datasets: [{
                label: 'Withdrawals (₹)',
                data: <?php echo json_encode($monthlyData); ?>,
                backgroundColor: 'rgba(78, 115, 223, 0.8)',
                borderColor: 'rgba(78, 115, 223, 1)',
                borderWidth: 1
            }]
        },
        options: {
            responsive: true,
            maintainAspectRatio: false,
            scales: {
                y: {
                    beginAtZero: true,
                    ticks: {
                        callback: function(value) {
                            return '₹' + value.toLocaleString('en-IN');
                        }
                    }
                }
            },
            plugins: {
                tooltip: {
                    callbacks: {
                        label: function(context) {
                            let label = context.dataset.label || '';
                            let value = context.raw || 0;
                            return label + ': ₹' + value.toLocaleString('en-IN', {
                                minimumFractionDigits: 2,
                                maximumFractionDigits: 2
                            });
                        }
                    }
                }
            }
        }
    });
</script>

<?php require_once '../includes/footer.php'; ?>