<?php

/**
 * Header File
 * This file contains the header part of the HTML for all pages
 */
require_once 'includes/config.php';

// Redirect to login page if not logged in
if (!isLoggedIn() && basename($_SERVER['PHP_SELF']) != 'login.php') {
    redirect('login.php');
}

// Get current user info if logged in
$currentUser = null;
if (isLoggedIn()) {
    $currentUser = getUserById($_SESSION['user_id']);
}
?>
<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo APP_NAME; ?></title>
    <!-- Bootstrap CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Font Awesome for icons -->
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css">
    <!-- Custom CSS -->
    <link rel="stylesheet" href="assets/css/style.css">
</head>

<body>
    <!-- Navigation Bar -->
    <?php if (isLoggedIn()): ?>
        <nav class="navbar navbar-expand-lg navbar-dark bg-primary">
            <div class="container-fluid">
                <a class="navbar-brand" href="index.php"><?php echo APP_NAME; ?></a>
                <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarNav" aria-controls="navbarNav" aria-expanded="false" aria-label="Toggle navigation">
                    <span class="navbar-toggler-icon"></span>
                </button>
                <div class="collapse navbar-collapse" id="navbarNav">
                    <ul class="navbar-nav me-auto mb-2 mb-lg-0">
                        <li class="nav-item">
                            <a class="nav-link" href="index.php"><i class="fas fa-home"></i> Dashboard</a>
                        </li>

                        <!-- Raw Materials Menu -->
                        <li class="nav-item dropdown">
                            <a class="nav-link dropdown-toggle" href="#" id="materialsDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">
                                <i class="fas fa-box"></i> Raw Materials
                            </a>
                            <ul class="dropdown-menu" aria-labelledby="materialsDropdown">
                                <li><a class="dropdown-item" href="materials/list.php">View Inventory</a></li>
                                <li><a class="dropdown-item" href="materials/add.php">Add New Material</a></li>
                                <li><a class="dropdown-item" href="materials/allocate.php">Allocate Materials</a></li>
                            </ul>
                        </li>

                        <!-- Books Menu -->
                        <li class="nav-item dropdown">
                            <a class="nav-link dropdown-toggle" href="#" id="booksDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">
                                <i class="fas fa-book"></i> Books
                            </a>
                            <ul class="dropdown-menu" aria-labelledby="booksDropdown">
                                <li><a class="dropdown-item" href="books/list.php">View All Books</a></li>
                                <li><a class="dropdown-item" href="books/add.php">Add New Book</a></li>
                                <li><a class="dropdown-item" href="books/inventory.php">Finished Inventory</a></li>
                            </ul>
                        </li>

                        <!-- Production Menu -->
                        <li class="nav-item dropdown">
                            <a class="nav-link dropdown-toggle" href="#" id="productionDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">
                                <i class="fas fa-industry"></i> Production
                            </a>
                            <ul class="dropdown-menu" aria-labelledby="productionDropdown">
                                <li><a class="dropdown-item" href="production/orders.php">Production Orders</a></li>
                                <li><a class="dropdown-item" href="production/printing.php">Printing Jobs</a></li>
                                <li><a class="dropdown-item" href="production/binding.php">Binding Jobs</a></li>
                            </ul>
                        </li>

                        <!-- Sales Menu -->
                        <li class="nav-item dropdown">
                            <a class="nav-link dropdown-toggle" href="#" id="salesDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">
                                <i class="fas fa-shopping-cart"></i> Sales
                            </a>
                            <ul class="dropdown-menu" aria-labelledby="salesDropdown">
                                <li><a class="dropdown-item" href="sales/customers.php">Customers</a></li>
                                <li><a class="dropdown-item" href="sales/orders.php">Sales Orders</a></li>
                                <li><a class="dropdown-item" href="sales/payments.php">Payments</a></li>
                            </ul>
                        </li>

                        <!-- Finance Menu -->
                        <li class="nav-item dropdown">
                            <a class="nav-link dropdown-toggle" href="#" id="financeDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">
                                <i class="fas fa-money-bill-wave"></i> Finance
                            </a>
                            <ul class="dropdown-menu" aria-labelledby="financeDropdown">
                                <li><a class="dropdown-item" href="finance/expenses.php">Expenses</a></li>
                                <li><a class="dropdown-item" href="finance/withdrawals.php">Owner Withdrawals</a></li>
                                <li><a class="dropdown-item" href="finance/reports.php">Financial Reports</a></li>
                            </ul>
                        </li>

                        <!-- Admin Menu (visible only to admins) -->
                        <?php if (isset($_SESSION['user_role']) && $_SESSION['user_role'] === 'admin'): ?>
                            <li class="nav-item dropdown">
                                <a class="nav-link dropdown-toggle" href="#" id="adminDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">
                                    <i class="fas fa-cog"></i> Admin
                                </a>
                                <ul class="dropdown-menu" aria-labelledby="adminDropdown">
                                    <li><a class="dropdown-item" href="admin/users.php">User Management</a></li>
                                    <li><a class="dropdown-item" href="admin/settings.php">System Settings</a></li>
                                    <li><a class="dropdown-item" href="admin/logs.php">Activity Logs</a></li>
                                </ul>
                            </li>
                        <?php endif; ?>
                    </ul>

                    <!-- User Menu -->
                    <ul class="navbar-nav">
                        <li class="nav-item dropdown">
                            <a class="nav-link dropdown-toggle" href="#" id="userDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">
                                <i class="fas fa-user"></i>
                                <?php echo htmlspecialchars($currentUser['full_name'] ?? 'User'); ?>
                            </a>
                            <ul class="dropdown-menu dropdown-menu-end" aria-labelledby="userDropdown">
                                <li><a class="dropdown-item" href="profile.php">My Profile</a></li>
                                <li><a class="dropdown-item" href="change_password.php">Change Password</a></li>
                                <li>
                                    <hr class="dropdown-divider">
                                </li>
                                <li><a class="dropdown-item" href="logout.php">Logout</a></li>
                            </ul>
                        </li>
                    </ul>
                </div>
            </div>
        </nav>
    <?php endif; ?>

    <!-- Main Content Container -->
    <div class="container mt-4">
        <?php echo displayFlashMessage(); ?>
        <!-- Content will be inserted here -->