<?php

/**
 * Dashboard Page
 * This is the main page after login, showing an overview of the system
 */
require_once 'includes/header.php';

// Get summary data for dashboard
// Raw Materials Summary
$rawMaterialsSql = "SELECT 
                     SUM(CASE WHEN material_type = 'paper' THEN remaining_quantity ELSE 0 END) AS paper_stock,
                     SUM(CASE WHEN material_type = 'cover' THEN remaining_quantity ELSE 0 END) AS cover_stock,
                     SUM(CASE WHEN material_type = 'half_title' THEN remaining_quantity ELSE 0 END) AS half_title_stock
                   FROM raw_materials";
$rawMaterialsResult = executeQuery($conn, $rawMaterialsSql);
$rawMaterials = $rawMaterialsResult->fetch_assoc();

// Production Orders Summary
$productionSql = "SELECT 
                    COUNT(*) AS total_orders,
                    SUM(CASE WHEN status = 'pending' THEN 1 ELSE 0 END) AS pending_orders,
                    SUM(CASE WHEN status = 'printing' THEN 1 ELSE 0 END) AS printing_orders,
                    SUM(CASE WHEN status = 'binding' THEN 1 ELSE 0 END) AS binding_orders,
                    SUM(CASE WHEN status = 'completed' THEN 1 ELSE 0 END) AS completed_orders
                  FROM production_orders";
$productionResult = executeQuery($conn, $productionSql);
$production = $productionResult->fetch_assoc();

// Finished Inventory Summary
$inventorySql = "SELECT 
                   COUNT(DISTINCT book_id) AS unique_books,
                   SUM(quantity) AS total_stock
                 FROM finished_inventory";
$inventoryResult = executeQuery($conn, $inventorySql);
$inventory = $inventoryResult->fetch_assoc();

// Sales Orders Summary
$salesSql = "SELECT 
               COUNT(*) AS total_orders,
               SUM(CASE WHEN payment_status = 'pending' THEN 1 ELSE 0 END) AS pending_payment,
               SUM(CASE WHEN payment_status = 'partial' THEN 1 ELSE 0 END) AS partial_payment,
               SUM(CASE WHEN payment_status = 'paid' THEN 1 ELSE 0 END) AS full_payment,
               SUM(total_amount) AS total_sales,
               SUM(paid_amount) AS total_received
             FROM sales_orders";
$salesResult = executeQuery($conn, $salesSql);
$sales = $salesResult->fetch_assoc();

// Recent Production Orders
$recentProductionSql = "SELECT po.id, po.order_date, po.quantity, po.status, b.title
                        FROM production_orders po
                        JOIN books b ON po.book_id = b.id
                        ORDER BY po.order_date DESC
                        LIMIT 5";
$recentProductionResult = executeQuery($conn, $recentProductionSql);

// Recent Sales Orders
$recentSalesSql = "SELECT so.id, so.order_date, so.total_amount, so.payment_status, c.name AS customer_name
                   FROM sales_orders so
                   JOIN customers c ON so.customer_id = c.id
                   ORDER BY so.order_date DESC
                   LIMIT 5";
$recentSalesResult = executeQuery($conn, $recentSalesSql);

// Low Stock Alerts
$lowStockSql = "SELECT id, material_type, remaining_quantity, batch_number
                FROM raw_materials
                WHERE remaining_quantity < 100
                ORDER BY remaining_quantity ASC
                LIMIT 5";
$lowStockResult = executeQuery($conn, $lowStockSql);
?>

<h1 class="mb-4">Dashboard</h1>

<!-- Stats Cards -->
<div class="row">
    <!-- Raw Materials -->
    <div class="col-xl-3 col-md-6 mb-4">
        <div class="card border-left-primary shadow h-100 py-2">
            <div class="card-body">
                <div class="row no-gutters align-items-center">
                    <div class="col mr-2">
                        <div class="text-xs font-weight-bold text-primary text-uppercase mb-1">
                            Raw Materials</div>
                        <div class="h5 mb-0 font-weight-bold text-gray-800">
                            Paper: <?php echo number_format($rawMaterials['paper_stock'] ?? 0); ?><br>
                            Covers: <?php echo number_format($rawMaterials['cover_stock'] ?? 0); ?><br>
                            Half-Titles: <?php echo number_format($rawMaterials['half_title_stock'] ?? 0); ?>
                        </div>
                    </div>
                    <div class="col-auto">
                        <i class="fas fa-box fa-2x text-gray-300"></i>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <!-- Production -->
    <div class="col-xl-3 col-md-6 mb-4">
        <div class="card border-left-success shadow h-100 py-2">
            <div class="card-body">
                <div class="row no-gutters align-items-center">
                    <div class="col mr-2">
                        <div class="text-xs font-weight-bold text-success text-uppercase mb-1">
                            Production</div>
                        <div class="h5 mb-0 font-weight-bold text-gray-800">
                            Pending: <?php echo number_format($production['pending_orders'] ?? 0); ?><br>
                            In Progress: <?php echo number_format(($production['printing_orders'] ?? 0) + ($production['binding_orders'] ?? 0)); ?><br>
                            Completed: <?php echo number_format($production['completed_orders'] ?? 0); ?>
                        </div>
                    </div>
                    <div class="col-auto">
                        <i class="fas fa-industry fa-2x text-gray-300"></i>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <!-- Inventory -->
    <div class="col-xl-3 col-md-6 mb-4">
        <div class="card border-left-info shadow h-100 py-2">
            <div class="card-body">
                <div class="row no-gutters align-items-center">
                    <div class="col mr-2">
                        <div class="text-xs font-weight-bold text-info text-uppercase mb-1">
                            Finished Books</div>
                        <div class="h5 mb-0 font-weight-bold text-gray-800">
                            Unique Titles: <?php echo number_format($inventory['unique_books'] ?? 0); ?><br>
                            Total Stock: <?php echo number_format($inventory['total_stock'] ?? 0); ?>
                        </div>
                    </div>
                    <div class="col-auto">
                        <i class="fas fa-book fa-2x text-gray-300"></i>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <!-- Sales -->
    <div class="col-xl-3 col-md-6 mb-4">
        <div class="card border-left-warning shadow h-100 py-2">
            <div class="card-body">
                <div class="row no-gutters align-items-center">
                    <div class="col mr-2">
                        <div class="text-xs font-weight-bold text-warning text-uppercase mb-1">
                            Sales</div>
                        <div class="h5 mb-0 font-weight-bold text-gray-800">
                            Total: <?php echo formatCurrency($sales['total_sales'] ?? 0); ?><br>
                            Received: <?php echo formatCurrency($sales['total_received'] ?? 0); ?><br>
                            Outstanding: <?php echo formatCurrency(($sales['total_sales'] ?? 0) - ($sales['total_received'] ?? 0)); ?>
                        </div>
                    </div>
                    <div class="col-auto">
                        <i class="fas fa-shopping-cart fa-2x text-gray-300"></i>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<!-- Recent Activities Row -->
<div class="row">
    <!-- Recent Production Orders -->
    <div class="col-lg-6 mb-4">
        <div class="card shadow mb-4">
            <div class="card-header py-3">
                <h6 class="m-0 font-weight-bold text-primary">Recent Production Orders</h6>
            </div>
            <div class="card-body">
                <div class="table-responsive">
                    <table class="table table-bordered" width="100%" cellspacing="0">
                        <thead>
                            <tr>
                                <th>ID</th>
                                <th>Book</th>
                                <th>Date</th>
                                <th>Quantity</th>
                                <th>Status</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if ($recentProductionResult && $recentProductionResult->num_rows > 0): ?>
                                <?php while ($order = $recentProductionResult->fetch_assoc()): ?>
                                    <tr>
                                        <td><?php echo $order['id']; ?></td>
                                        <td><?php echo htmlspecialchars($order['title']); ?></td>
                                        <td><?php echo formatDate($order['order_date']); ?></td>
                                        <td><?php echo number_format($order['quantity']); ?></td>
                                        <td>
                                            <span class="badge bg-<?php
                                                                    echo ($order['status'] === 'completed') ? 'success' : (($order['status'] === 'pending') ? 'warning' : 'info');
                                                                    ?>">
                                                <?php echo ucfirst($order['status']); ?>
                                            </span>
                                        </td>
                                    </tr>
                                <?php endwhile; ?>
                            <?php else: ?>
                                <tr>
                                    <td colspan="5" class="text-center">No production orders found</td>
                                </tr>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
                <div class="mt-3 text-center">
                    <a href="production/orders.php" class="btn btn-primary btn-sm">View All Orders</a>
                </div>
            </div>
        </div>
    </div>

    <!-- Recent Sales Orders -->
    <div class="col-lg-6 mb-4">
        <div class="card shadow mb-4">
            <div class="card-header py-3">
                <h6 class="m-0 font-weight-bold text-primary">Recent Sales</h6>
            </div>
            <div class="card-body">
                <div class="table-responsive">
                    <table class="table table-bordered" width="100%" cellspacing="0">
                        <thead>
                            <tr>
                                <th>ID</th>
                                <th>Customer</th>
                                <th>Date</th>
                                <th>Amount</th>
                                <th>Payment</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if ($recentSalesResult && $recentSalesResult->num_rows > 0): ?>
                                <?php while ($sale = $recentSalesResult->fetch_assoc()): ?>
                                    <tr>
                                        <td><?php echo $sale['id']; ?></td>
                                        <td><?php echo htmlspecialchars($sale['customer_name']); ?></td>
                                        <td><?php echo formatDate($sale['order_date']); ?></td>
                                        <td><?php echo formatCurrency($sale['total_amount']); ?></td>
                                        <td>
                                            <span class="badge bg-<?php
                                                                    echo ($sale['payment_status'] === 'paid') ? 'success' : (($sale['payment_status'] === 'pending') ? 'danger' : 'warning');
                                                                    ?>">
                                                <?php echo ucfirst($sale['payment_status']); ?>
                                            </span>
                                        </td>
                                    </tr>
                                <?php endwhile; ?>
                            <?php else: ?>
                                <tr>
                                    <td colspan="5" class="text-center">No sales orders found</td>
                                </tr>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
                <div class="mt-3 text-center">
                    <a href="sales/orders.php" class="btn btn-primary btn-sm">View All Sales</a>
                </div>
            </div>
        </div>
    </div>
</div>

<!-- Alerts Row -->
<div class="row">
    <!-- Low Stock Alerts -->
    <div class="col-lg-6 mb-4">
        <div class="card shadow mb-4">
            <div class="card-header py-3">
                <h6 class="m-0 font-weight-bold text-danger">Low Stock Alerts</h6>
            </div>
            <div class="card-body">
                <div class="table-responsive">
                    <table class="table table-bordered" width="100%" cellspacing="0">
                        <thead>
                            <tr>
                                <th>Material Type</th>
                                <th>Batch</th>
                                <th>Remaining</th>
                                <th>Action</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if ($lowStockResult && $lowStockResult->num_rows > 0): ?>
                                <?php while ($stock = $lowStockResult->fetch_assoc()): ?>
                                    <tr>
                                        <td><?php echo ucfirst(str_replace('_', ' ', $stock['material_type'])); ?></td>
                                        <td><?php echo htmlspecialchars($stock['batch_number']); ?></td>
                                        <td>
                                            <span class="text-danger"><?php echo number_format($stock['remaining_quantity']); ?></span>
                                        </td>
                                        <td>
                                            <a href="materials/add.php" class="btn btn-warning btn-sm">Order More</a>
                                        </td>
                                    </tr>
                                <?php endwhile; ?>
                            <?php else: ?>
                                <tr>
                                    <td colspan="4" class="text-center">No low stock alerts</td>
                                </tr>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
                <div class="mt-3 text-center">
                    <a href="materials/list.php" class="btn btn-primary btn-sm">View All Materials</a>
                </div>
            </div>
        </div>
    </div>

    <!-- Quick Actions -->
    <div class="col-lg-6 mb-4">
        <div class="card shadow mb-4">
            <div class="card-header py-3">
                <h6 class="m-0 font-weight-bold text-primary">Quick Actions</h6>
            </div>
            <div class="card-body">
                <div class="row">
                    <div class="col-md-6 mb-3">
                        <a href="materials/add.php" class="btn btn-primary btn-block">
                            <i class="fas fa-plus"></i> Add Raw Material
                        </a>
                    </div>
                    <div class="col-md-6 mb-3">
                        <a href="books/add.php" class="btn btn-primary btn-block">
                            <i class="fas fa-book"></i> Add New Book
                        </a>
                    </div>
                    <div class="col-md-6 mb-3">
                        <a href="production/orders.php?action=new" class="btn btn-primary btn-block">
                            <i class="fas fa-industry"></i> New Production Order
                        </a>
                    </div>
                    <div class="col-md-6 mb-3">
                        <a href="sales/orders.php?action=new" class="btn btn-primary btn-block">
                            <i class="fas fa-shopping-cart"></i> New Sales Order
                        </a>
                    </div>
                    <div class="col-md-6 mb-3">
                        <a href="sales/customers.php?action=new" class="btn btn-primary btn-block">
                            <i class="fas fa-user"></i> Add Customer
                        </a>
                    </div>
                    <div class="col-md-6 mb-3">
                        <a href="finance/reports.php" class="btn btn-primary btn-block">
                            <i class="fas fa-chart-bar"></i> View Reports
                        </a>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<?php require_once 'includes/footer.php'; ?>