<?php

/**
 * Add New Raw Material Page
 * Allows adding new raw materials to the inventory
 */
require_once '../includes/header.php';

// Initialize variables
$materialType = '';
$quantity = '';
$unitPrice = '';
$purchaseDate = date('Y-m-d');
$batchNumber = '';
$supplierName = '';
$notes = '';

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Sanitize input
    $materialType = sanitizeInput($conn, $_POST['material_type']);
    $quantity = (int)$_POST['quantity'];
    $unitPrice = (float)$_POST['unit_price'];
    $purchaseDate = sanitizeInput($conn, $_POST['purchase_date']);
    $batchNumber = sanitizeInput($conn, $_POST['batch_number']);
    $supplierName = sanitizeInput($conn, $_POST['supplier_name']);
    $notes = sanitizeInput($conn, $_POST['notes']);

    // Validate input
    $errors = [];

    if (empty($materialType)) {
        $errors[] = 'Material type is required.';
    }

    if ($quantity <= 0) {
        $errors[] = 'Quantity must be greater than zero.';
    }

    if ($unitPrice <= 0) {
        $errors[] = 'Unit price must be greater than zero.';
    }

    if (empty($purchaseDate)) {
        $errors[] = 'Purchase date is required.';
    }

    if (empty($batchNumber)) {
        $errors[] = 'Batch number is required.';
    }

    // If no errors, insert data
    if (empty($errors)) {
        $sql = "INSERT INTO raw_materials (
                    material_type, 
                    quantity, 
                    unit_price, 
                    purchase_date, 
                    batch_number, 
                    remaining_quantity, 
                    supplier_name, 
                    notes
                ) VALUES (
                    '$materialType', 
                    $quantity, 
                    $unitPrice, 
                    '$purchaseDate', 
                    '$batchNumber', 
                    $quantity, 
                    '$supplierName', 
                    '$notes'
                )";

        if (executeQuery($conn, $sql)) {
            $materialId = $conn->insert_id;

            logActivity('add_material', "Added new $materialType with batch number $batchNumber");

            setFlashMessage('Raw material added successfully.', 'success');
            redirect('materials/list.php');
        } else {
            $errors[] = 'Error adding raw material. Please try again.';
        }
    }
}
?>

<div class="d-flex justify-content-between align-items-center mb-4">
    <h1>Add New Raw Material</h1>
    <a href="list.php" class="btn btn-secondary">
        <i class="fas fa-arrow-left"></i> Back to List
    </a>
</div>

<?php if (!empty($errors)): ?>
    <div class="alert alert-danger">
        <ul class="mb-0">
            <?php foreach ($errors as $error): ?>
                <li><?php echo $error; ?></li>
            <?php endforeach; ?>
        </ul>
    </div>
<?php endif; ?>

<div class="card shadow mb-4">
    <div class="card-header py-3">
        <h6 class="m-0 font-weight-bold text-primary">Material Details</h6>
    </div>
    <div class="card-body">
        <form method="post" action="">
            <div class="row mb-3">
                <div class="col-md-6">
                    <label for="material_type" class="form-label">Material Type *</label>
                    <select name="material_type" id="material_type" class="form-select" required>
                        <option value="">Select Material Type</option>
                        <option value="paper" <?php echo ($materialType === 'paper') ? 'selected' : ''; ?>>Paper</option>
                        <option value="cover" <?php echo ($materialType === 'cover') ? 'selected' : ''; ?>>Cover</option>
                        <option value="half_title" <?php echo ($materialType === 'half_title') ? 'selected' : ''; ?>>Half Title</option>
                    </select>
                </div>
                <div class="col-md-6">
                    <label for="batch_number" class="form-label">Batch Number *</label>
                    <input type="text" class="form-control" id="batch_number" name="batch_number" value="<?php echo htmlspecialchars($batchNumber); ?>" required>
                    <small class="text-muted">Unique identifier for this batch of materials</small>
                </div>
            </div>

            <div class="row mb-3">
                <div class="col-md-6">
                    <label for="quantity" class="form-label">Quantity *</label>
                    <input type="number" class="form-control" id="quantity" name="quantity" value="<?php echo htmlspecialchars($quantity); ?>" min="1" required>
                </div>
                <div class="col-md-6">
                    <label for="unit_price" class="form-label">Unit Price *</label>
                    <div class="input-group">
                        <span class="input-group-text">₹</span>
                        <input type="number" class="form-control" id="unit_price" name="unit_price" value="<?php echo htmlspecialchars($unitPrice); ?>" min="0.01" step="0.01" required>
                    </div>
                </div>
            </div>

            <div class="row mb-3">
                <div class="col-md-6">
                    <label for="purchase_date" class="form-label">Purchase Date *</label>
                    <input type="date" class="form-control" id="purchase_date" name="purchase_date" value="<?php echo htmlspecialchars($purchaseDate); ?>" required>
                </div>
                <div class="col-md-6">
                    <label for="supplier_name" class="form-label">Supplier Name</label>
                    <input type="text" class="form-control" id="supplier_name" name="supplier_name" value="<?php echo htmlspecialchars($supplierName); ?>">
                </div>
            </div>

            <div class="mb-3">
                <label for="notes" class="form-label">Notes</label>
                <textarea class="form-control" id="notes" name="notes" rows="3"><?php echo htmlspecialchars($notes); ?></textarea>
            </div>

            <div class="d-grid gap-2 d-md-flex justify-content-md-end">
                <button type="reset" class="btn btn-secondary me-md-2">Reset</button>
                <button type="submit" class="btn btn-primary">Add Material</button>
            </div>
        </form>
    </div>
</div>

<?php require_once '../includes/footer.php'; ?>