<?php

/**
 * Raw Materials List Page
 * Displays all raw materials in the inventory
 */
require_once '../includes/header.php';

// Handle delete request
if (isset($_GET['delete']) && !empty($_GET['delete'])) {
    $id = (int)$_GET['delete'];

    // Check if the material can be deleted (not allocated to a production order)
    $checkSql = "SELECT COUNT(*) AS count FROM material_allocations WHERE raw_material_id = $id";
    $checkResult = executeQuery($conn, $checkSql);
    $row = $checkResult->fetch_assoc();

    if ($row['count'] > 0) {
        setFlashMessage('Cannot delete material as it is already allocated to production orders.', 'danger');
    } else {
        $deleteSql = "DELETE FROM raw_materials WHERE id = $id";
        if (executeQuery($conn, $deleteSql)) {
            setFlashMessage('Raw material deleted successfully.', 'success');
            logActivity('delete_material', "Deleted raw material ID: $id");
        } else {
            setFlashMessage('Error deleting raw material.', 'danger');
        }
    }
    redirect('materials/list.php');
}

// Get filter parameters
$materialType = isset($_GET['type']) ? sanitizeInput($conn, $_GET['type']) : '';
$batch = isset($_GET['batch']) ? sanitizeInput($conn, $_GET['batch']) : '';
$searchTerm = isset($_GET['search']) ? sanitizeInput($conn, $_GET['search']) : '';

// Build the query with filters
$sql = "SELECT * FROM raw_materials WHERE 1=1";

if (!empty($materialType)) {
    $sql .= " AND material_type = '$materialType'";
}

if (!empty($batch)) {
    $sql .= " AND batch_number = '$batch'";
}

if (!empty($searchTerm)) {
    $sql .= " AND (batch_number LIKE '%$searchTerm%' OR supplier_name LIKE '%$searchTerm%' OR notes LIKE '%$searchTerm%')";
}

$sql .= " ORDER BY purchase_date DESC";

$result = executeQuery($conn, $sql);

// Get list of unique batches for filter dropdown
$batchesSql = "SELECT DISTINCT batch_number FROM raw_materials ORDER BY batch_number";
$batchesResult = executeQuery($conn, $batchesSql);
?>

<div class="d-flex justify-content-between align-items-center mb-4">
    <h1>Raw Materials Inventory</h1>
    <a href="add.php" class="btn btn-primary">
        <i class="fas fa-plus"></i> Add New Material
    </a>
</div>

<!-- Filters -->
<div class="card mb-4">
    <div class="card-header">
        <i class="fas fa-filter"></i> Filter Materials
    </div>
    <div class="card-body">
        <form method="get" action="" class="row g-3">
            <div class="col-md-3">
                <label for="type" class="form-label">Material Type</label>
                <select name="type" id="type" class="form-select">
                    <option value="">All Types</option>
                    <option value="paper" <?php echo ($materialType === 'paper') ? 'selected' : ''; ?>>Paper</option>
                    <option value="cover" <?php echo ($materialType === 'cover') ? 'selected' : ''; ?>>Cover</option>
                    <option value="half_title" <?php echo ($materialType === 'half_title') ? 'selected' : ''; ?>>Half Title</option>
                </select>
            </div>
            <div class="col-md-3">
                <label for="batch" class="form-label">Batch Number</label>
                <select name="batch" id="batch" class="form-select">
                    <option value="">All Batches</option>
                    <?php if ($batchesResult && $batchesResult->num_rows > 0): ?>
                        <?php while ($batchRow = $batchesResult->fetch_assoc()): ?>
                            <option value="<?php echo $batchRow['batch_number']; ?>" <?php echo ($batch === $batchRow['batch_number']) ? 'selected' : ''; ?>>
                                <?php echo $batchRow['batch_number']; ?>
                            </option>
                        <?php endwhile; ?>
                    <?php endif; ?>
                </select>
            </div>
            <div class="col-md-4">
                <label for="search" class="form-label">Search</label>
                <input type="text" class="form-control" id="search" name="search" value="<?php echo htmlspecialchars($searchTerm); ?>" placeholder="Search batch, supplier, notes...">
            </div>
            <div class="col-md-2 d-flex align-items-end">
                <button type="submit" class="btn btn-primary me-2">Filter</button>
                <a href="list.php" class="btn btn-secondary">Reset</a>
            </div>
        </form>
    </div>
</div>

<!-- Materials Table -->
<div class="card shadow mb-4">
    <div class="card-header py-3">
        <h6 class="m-0 font-weight-bold text-primary">Raw Materials Inventory</h6>
    </div>
    <div class="card-body">
        <div class="table-responsive">
            <table class="table table-bordered" width="100%" cellspacing="0">
                <thead>
                    <tr>
                        <th>ID</th>
                        <th>Material Type</th>
                        <th>Batch Number</th>
                        <th>Purchase Date</th>
                        <th>Initial Quantity</th>
                        <th>Remaining</th>
                        <th>Unit Price</th>
                        <th>Supplier</th>
                        <th>Actions</th>
                    </tr>
                </thead>
                <tbody>
                    <?php if ($result && $result->num_rows > 0): ?>
                        <?php while ($row = $result->fetch_assoc()): ?>
                            <tr>
                                <td><?php echo $row['id']; ?></td>
                                <td><?php echo ucfirst(str_replace('_', ' ', $row['material_type'])); ?></td>
                                <td><?php echo htmlspecialchars($row['batch_number']); ?></td>
                                <td><?php echo formatDate($row['purchase_date']); ?></td>
                                <td><?php echo number_format($row['quantity']); ?></td>
                                <td>
                                    <span class="<?php echo ($row['remaining_quantity'] < 100) ? 'text-danger' : ''; ?>">
                                        <?php echo number_format($row['remaining_quantity']); ?>
                                    </span>
                                </td>
                                <td><?php echo formatCurrency($row['unit_price']); ?></td>
                                <td><?php echo htmlspecialchars($row['supplier_name'] ?? 'N/A'); ?></td>
                                <td>
                                    <a href="view.php?id=<?php echo $row['id']; ?>" class="btn btn-info btn-sm">
                                        <i class="fas fa-eye"></i>
                                    </a>
                                    <a href="edit.php?id=<?php echo $row['id']; ?>" class="btn btn-primary btn-sm">
                                        <i class="fas fa-edit"></i>
                                    </a>
                                    <a href="list.php?delete=<?php echo $row['id']; ?>" class="btn btn-danger btn-sm" onclick="return confirm('Are you sure you want to delete this material?');">
                                        <i class="fas fa-trash"></i>
                                    </a>
                                </td>
                            </tr>
                        <?php endwhile; ?>
                    <?php else: ?>
                        <tr>
                            <td colspan="9" class="text-center">No raw materials found</td>
                        </tr>
                    <?php endif; ?>
                </tbody>
            </table>
        </div>
    </div>
</div>

<!-- Material Usage Summary -->
<div class="card shadow mb-4">
    <div class="card-header py-3">
        <h6 class="m-0 font-weight-bold text-primary">Material Usage Summary</h6>
    </div>
    <div class="card-body">
        <div class="row">
            <!-- Paper Usage -->
            <div class="col-md-4 mb-4">
                <div class="card border-left-primary shadow h-100 py-2">
                    <div class="card-body">
                        <div class="row no-gutters align-items-center">
                            <div class="col mr-2">
                                <div class="text-xs font-weight-bold text-primary text-uppercase mb-1">
                                    Paper Stock</div>
                                <?php
                                $paperSql = "SELECT 
                                              SUM(quantity) AS total_purchased,
                                              SUM(remaining_quantity) AS total_remaining
                                            FROM raw_materials 
                                            WHERE material_type = 'paper'";
                                $paperResult = executeQuery($conn, $paperSql);
                                $paper = $paperResult->fetch_assoc();

                                $totalPurchased = $paper['total_purchased'] ?? 0;
                                $totalRemaining = $paper['total_remaining'] ?? 0;
                                $totalUsed = $totalPurchased - $totalRemaining;
                                $usagePercentage = ($totalPurchased > 0) ? ($totalUsed / $totalPurchased * 100) : 0;
                                ?>
                                <div class="h5 mb-0 font-weight-bold text-gray-800">
                                    Total: <?php echo number_format($totalPurchased); ?><br>
                                    Used: <?php echo number_format($totalUsed); ?> (<?php echo number_format($usagePercentage, 1); ?>%)<br>
                                    Remaining: <?php echo number_format($totalRemaining); ?>
                                </div>
                            </div>
                            <div class="col-auto">
                                <i class="fas fa-scroll fa-2x text-gray-300"></i>
                            </div>
                        </div>
                    </div>
                </div>
            </div>

            <!-- Cover Usage -->
            <div class="col-md-4 mb-4">
                <div class="card border-left-success shadow h-100 py-2">
                    <div class="card-body">
                        <div class="row no-gutters align-items-center">
                            <div class="col mr-2">
                                <div class="text-xs font-weight-bold text-success text-uppercase mb-1">
                                    Cover Stock</div>
                                <?php
                                $coverSql = "SELECT 
                                              SUM(quantity) AS total_purchased,
                                              SUM(remaining_quantity) AS total_remaining
                                            FROM raw_materials 
                                            WHERE material_type = 'cover'";
                                $coverResult = executeQuery($conn, $coverSql);
                                $cover = $coverResult->fetch_assoc();

                                $totalPurchased = $cover['total_purchased'] ?? 0;
                                $totalRemaining = $cover['total_remaining'] ?? 0;
                                $totalUsed = $totalPurchased - $totalRemaining;
                                $usagePercentage = ($totalPurchased > 0) ? ($totalUsed / $totalPurchased * 100) : 0;
                                ?>
                                <div class="h5 mb-0 font-weight-bold text-gray-800">
                                    Total: <?php echo number_format($totalPurchased); ?><br>
                                    Used: <?php echo number_format($totalUsed); ?> (<?php echo number_format($usagePercentage, 1); ?>%)<br>
                                    Remaining: <?php echo number_format($totalRemaining); ?>
                                </div>
                            </div>
                            <div class="col-auto">
                                <i class="fas fa-book-open fa-2x text-gray-300"></i>
                            </div>
                        </div>
                    </div>
                </div>
            </div>

            <!-- Half Title Usage -->
            <div class="col-md-4 mb-4">
                <div class="card border-left-info shadow h-100 py-2">
                    <div class="card-body">
                        <div class="row no-gutters align-items-center">
                            <div class="col mr-2">
                                <div class="text-xs font-weight-bold text-info text-uppercase mb-1">
                                    Half Title Stock</div>
                                <?php
                                $titleSql = "SELECT 
                                              SUM(quantity) AS total_purchased,
                                              SUM(remaining_quantity) AS total_remaining
                                            FROM raw_materials 
                                            WHERE material_type = 'half_title'";
                                $titleResult = executeQuery($conn, $titleSql);
                                $title = $titleResult->fetch_assoc();

                                $totalPurchased = $title['total_purchased'] ?? 0;
                                $totalRemaining = $title['total_remaining'] ?? 0;
                                $totalUsed = $totalPurchased - $totalRemaining;
                                $usagePercentage = ($totalPurchased > 0) ? ($totalUsed / $totalPurchased * 100) : 0;
                                ?>
                                <div class="h5 mb-0 font-weight-bold text-gray-800">
                                    Total: <?php echo number_format($totalPurchased); ?><br>
                                    Used: <?php echo number_format($totalUsed); ?> (<?php echo number_format($usagePercentage, 1); ?>%)<br>
                                    Remaining: <?php echo number_format($totalRemaining); ?>
                                </div>
                            </div>
                            <div class="col-auto">
                                <i class="fas fa-file-alt fa-2x text-gray-300"></i>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<?php require_once '../includes/footer.php'; ?>