<?php

/**
 * View Raw Material Details Page
 * Displays detailed information about a specific raw material
 */
require_once '../includes/header.php';

// Check if ID is provided
if (!isset($_GET['id']) || empty($_GET['id'])) {
    setFlashMessage('Material ID is required.', 'danger');
    redirect('materials/list.php');
}

$id = (int)$_GET['id'];

// Get material data
$sql = "SELECT * FROM raw_materials WHERE id = $id";
$result = executeQuery($conn, $sql);

if (!$result || $result->num_rows === 0) {
    setFlashMessage('Material not found.', 'danger');
    redirect('materials/list.php');
}

$material = $result->fetch_assoc();

// Get allocation history
$allocationsSql = "SELECT ma.*, po.order_date, b.title AS book_title
                 FROM material_allocations ma
                 JOIN production_orders po ON ma.production_order_id = po.id
                 JOIN books b ON po.book_id = b.id
                 WHERE ma.raw_material_id = $id
                 ORDER BY ma.allocation_date DESC";
$allocationsResult = executeQuery($conn, $allocationsSql);

// Calculate usage statistics
$totalAllocated = 0;
$allocations = [];

if ($allocationsResult && $allocationsResult->num_rows > 0) {
    while ($row = $allocationsResult->fetch_assoc()) {
        $totalAllocated += $row['quantity_allocated'];
        $allocations[] = $row;
    }
}

$percentUsed = ($material['quantity'] > 0) ? ($totalAllocated / $material['quantity'] * 100) : 0;
$percentRemaining = 100 - $percentUsed;
?>

<div class="d-flex justify-content-between align-items-center mb-4">
    <h1><?php echo ucfirst($material['material_type']); ?> Material Details</h1>
    <div>
        <a href="edit.php?id=<?php echo $id; ?>" class="btn btn-primary me-2">
            <i class="fas fa-edit"></i> Edit Material
        </a>
        <a href="list.php" class="btn btn-secondary">
            <i class="fas fa-arrow-left"></i> Back to List
        </a>
    </div>
</div>

<!-- Material Details -->
<div class="row">
    <div class="col-md-8">
        <div class="card shadow mb-4">
            <div class="card-header py-3">
                <h6 class="m-0 font-weight-bold text-primary">Material Information</h6>
            </div>
            <div class="card-body">
                <div class="row mb-3">
                    <div class="col-md-6">
                        <p><strong>Material Type:</strong> <?php echo ucfirst($material['material_type']); ?></p>
                        <p><strong>Batch Number:</strong> <?php echo htmlspecialchars($material['batch_number']); ?></p>
                        <p><strong>Purchase Date:</strong> <?php echo formatDate($material['purchase_date']); ?></p>
                        <p><strong>Supplier:</strong> <?php echo htmlspecialchars($material['supplier_name'] ?? 'N/A'); ?></p>
                    </div>
                    <div class="col-md-6">
                        <p><strong>Original Quantity:</strong> <?php echo number_format($material['quantity']); ?></p>
                        <p><strong>Remaining Quantity:</strong> <?php echo number_format($material['remaining_quantity']); ?></p>
                        <p><strong>Unit Price:</strong> <?php echo formatCurrency($material['unit_price']); ?></p>
                        <p><strong>Total Cost:</strong> <?php echo formatCurrency($material['quantity'] * $material['unit_price']); ?></p>
                    </div>
                </div>

                <div class="row">
                    <div class="col-md-12">
                        <h6 class="font-weight-bold">Notes:</h6>
                        <p><?php echo !empty($material['notes']) ? htmlspecialchars($material['notes']) : 'No notes available.'; ?></p>
                    </div>
                </div>

                <div class="row mt-3">
                    <div class="col-md-12">
                        <h6 class="font-weight-bold mb-2">Usage Progress:</h6>
                        <div class="progress" style="height: 25px;">
                            <?php if ($percentUsed > 0): ?>
                                <div class="progress-bar bg-success" role="progressbar" style="width: <?php echo $percentUsed; ?>%;"
                                    aria-valuenow="<?php echo $percentUsed; ?>" aria-valuemin="0" aria-valuemax="100">
                                    Used: <?php echo number_format($percentUsed, 1); ?>%
                                </div>
                            <?php endif; ?>

                            <?php if ($percentRemaining > 0): ?>
                                <div class="progress-bar bg-info" role="progressbar" style="width: <?php echo $percentRemaining; ?>%;"
                                    aria-valuenow="<?php echo $percentRemaining; ?>" aria-valuemin="0" aria-valuemax="100">
                                    Remaining: <?php echo number_format($percentRemaining, 1); ?>%
                                </div>
                            <?php endif; ?>
                        </div>
                        <div class="small text-muted mt-1">
                            <?php echo number_format($totalAllocated); ?> units allocated,
                            <?php echo number_format($material['remaining_quantity']); ?> units remaining
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <div class="col-md-4">
        <div class="card shadow mb-4">
            <div class="card-header py-3">
                <h6 class="m-0 font-weight-bold text-primary">Material Summary</h6>
            </div>
            <div class="card-body">
                <div class="chart-container mb-4" style="position: relative; height:200px; width:100%">
                    <canvas id="materialUsageChart"></canvas>
                </div>

                <div class="text-center">
                    <?php if ($material['remaining_quantity'] > 0): ?>
                        <a href="allocate.php" class="btn btn-success btn-sm">
                            <i class="fas fa-boxes"></i> Allocate This Material
                        </a>
                    <?php else: ?>
                        <button class="btn btn-secondary btn-sm" disabled>
                            <i class="fas fa-ban"></i> No Remaining Quantity
                        </button>
                    <?php endif; ?>
                </div>

                <hr>

                <div class="mb-3">
                    <h6 class="font-weight-bold">Material Status:</h6>
                    <?php if ($material['remaining_quantity'] <= 0): ?>
                        <div class="alert alert-danger mb-0">
                            <i class="fas fa-exclamation-circle"></i> Material is fully allocated
                        </div>
                    <?php elseif ($material['remaining_quantity'] < 100): ?>
                        <div class="alert alert-warning mb-0">
                            <i class="fas fa-exclamation-triangle"></i> Low stock (<?php echo number_format($material['remaining_quantity']); ?> units remaining)
                        </div>
                    <?php else: ?>
                        <div class="alert alert-success mb-0">
                            <i class="fas fa-check-circle"></i> Material is in good supply
                        </div>
                    <?php endif; ?>
                </div>
            </div>
        </div>
    </div>
</div>

<!-- Allocation History -->
<div class="card shadow mb-4">
    <div class="card-header py-3">
        <h6 class="m-0 font-weight-bold text-primary">Allocation History</h6>
    </div>
    <div class="card-body">
        <div class="table-responsive">
            <table class="table table-bordered" width="100%" cellspacing="0">
                <thead>
                    <tr>
                        <th>ID</th>
                        <th>Production Order</th>
                        <th>Book</th>
                        <th>Allocation Date</th>
                        <th>Quantity Allocated</th>
                        <th>Cost Value</th>
                    </tr>
                </thead>
                <tbody>
                    <?php if (!empty($allocations)): ?>
                        <?php foreach ($allocations as $allocation): ?>
                            <tr>
                                <td><?php echo $allocation['id']; ?></td>
                                <td>
                                    <a href="../production/orders.php?id=<?php echo $allocation['production_order_id']; ?>">
                                        #<?php echo $allocation['production_order_id']; ?>
                                    </a>
                                </td>
                                <td><?php echo htmlspecialchars($allocation['book_title']); ?></td>
                                <td><?php echo formatDate($allocation['allocation_date']); ?></td>
                                <td><?php echo number_format($allocation['quantity_allocated']); ?></td>
                                <td><?php echo formatCurrency($allocation['quantity_allocated'] * $material['unit_price']); ?></td>
                            </tr>
                        <?php endforeach; ?>
                    <?php else: ?>
                        <tr>
                            <td colspan="6" class="text-center">This material has not been allocated to any production orders yet.</td>
                        </tr>
                    <?php endif; ?>
                </tbody>
            </table>
        </div>
    </div>
</div>

<!-- Batch Information -->
<div class="card shadow mb-4">
    <div class="card-header py-3">
        <h6 class="m-0 font-weight-bold text-primary">Batch Information</h6>
    </div>
    <div class="card-body">
        <div class="row">
            <div class="col-md-6">
                <h6 class="font-weight-bold">Batch Details:</h6>
                <p><strong>Batch Number:</strong> <?php echo htmlspecialchars($material['batch_number']); ?></p>
                <p><strong>Created:</strong> <?php echo formatDate($material['created_at'], 'Y-m-d H:i:s'); ?></p>

                <?php if (!empty($material['supplier_name'])): ?>
                    <h6 class="font-weight-bold mt-4">Supplier Information:</h6>
                    <p><strong>Supplier Name:</strong> <?php echo htmlspecialchars($material['supplier_name']); ?></p>
                <?php endif; ?>
            </div>
            <div class="col-md-6">
                <h6 class="font-weight-bold">Material Value:</h6>
                <p><strong>Unit Price:</strong> <?php echo formatCurrency($material['unit_price']); ?></p>
                <p><strong>Total Purchase Value:</strong> <?php echo formatCurrency($material['quantity'] * $material['unit_price']); ?></p>
                <p><strong>Remaining Value:</strong> <?php echo formatCurrency($material['remaining_quantity'] * $material['unit_price']); ?></p>
                <p><strong>Used Value:</strong> <?php echo formatCurrency(($material['quantity'] - $material['remaining_quantity']) * $material['unit_price']); ?></p>
            </div>
        </div>
    </div>
</div>

<!-- Charts.js Script -->
<script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
<script>
    // Material Usage Chart
    const ctx = document.getElementById('materialUsageChart').getContext('2d');
    const materialUsageChart = new Chart(ctx, {
        type: 'pie',
        data: {
            labels: ['Used', 'Remaining'],
            datasets: [{
                data: [
                    <?php echo ($material['quantity'] - $material['remaining_quantity']); ?>,
                    <?php echo $material['remaining_quantity']; ?>
                ],
                backgroundColor: [
                    'rgba(40, 167, 69, 0.8)',
                    'rgba(23, 162, 184, 0.8)'
                ],
                borderColor: [
                    'rgba(40, 167, 69, 1)',
                    'rgba(23, 162, 184, 1)'
                ],
                borderWidth: 1
            }]
        },
        options: {
            responsive: true,
            maintainAspectRatio: false,
            plugins: {
                legend: {
                    position: 'bottom'
                },
                tooltip: {
                    callbacks: {
                        label: function(context) {
                            const label = context.label || '';
                            const value = context.raw || 0;
                            const total = <?php echo $material['quantity']; ?>;
                            const percentage = ((value / total) * 100).toFixed(1);
                            return `${label}: ${value.toLocaleString()} units (${percentage}%)`;
                        }
                    }
                }
            }
        }
    });
</script>

<?php require_once '../includes/footer.php'; ?>