<?php
/**
 * Binding Jobs Page
 * Manages binding jobs for production orders
 */
require_once '../includes/header.php';

// Check if order_id is provided
$orderId = isset($_GET['order_id']) ? (int)$_GET['order_id'] : 0;
$bindingJobId = isset($_GET['id']) ? (int)$_GET['id'] : 0;

// Get order details if order_id is provided
$order = null;
if ($orderId > 0) {
    $orderSql = "SELECT po.*, b.title AS book_title, b.pages_per_book 
                FROM production_orders po
                JOIN books b ON po.book_id = b.id
                WHERE po.id = $orderId";
    $orderResult = executeQuery($conn, $orderSql);
    
    if ($orderResult && $orderResult->num_rows > 0) {
        $order = $orderResult->fetch_assoc();
    }

// Handle form submission for receiving bound books
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['receive_binding'])) {
    $jobId = (int)$_POST['job_id'];
    $receivedQuantity = (int)$_POST['received_quantity'];
    $receivedDate = sanitizeInput($conn, $_POST['received_date']);
    $paymentAmount = (float)$_POST['payment_amount'];
    $paymentStatus = sanitizeInput($conn, $_POST['payment_status']);
    
    // Validate input
    $errors = [];
    
    if ($jobId <= 0) {
        $errors[] = 'Invalid binding job.';
    }
    
    if ($receivedQuantity <= 0) {
        $errors[] = 'Received quantity must be greater than zero.';
    }
    
    if (empty($receivedDate)) {
        $errors[] = 'Received date is required.';
    }
    
    // Get job details
    $jobDetailsSql = "SELECT * FROM binding_jobs WHERE id = $jobId";
    $jobDetailsResult = executeQuery($conn, $jobDetailsSql);
    $jobDetails = $jobDetailsResult->fetch_assoc();
    
    if ($receivedQuantity > $jobDetails['sent_quantity']) {
        $errors[] = 'Received quantity cannot be greater than sent quantity.';
    }
    
    // If no errors, update the binding job and create finished inventory
    if (empty($errors)) {
        // Start transaction
        $conn->begin_transaction();
        
        try {
            // Update binding job
            $sql = "UPDATE binding_jobs SET 
                    received_quantity = $receivedQuantity, 
                    received_date = '$receivedDate',
                    payment_status = '$paymentStatus',
                    payment_amount = $paymentAmount
                    WHERE id = $jobId";
            
            executeQuery($conn, $sql);
            
            // Get production order and book details
            $orderSql = "SELECT po.*, b.id AS book_id 
                        FROM production_orders po
                        JOIN books b ON po.book_id = b.id
                        WHERE po.id = " . $jobDetails['production_order_id'];
            $orderResult = executeQuery($conn, $orderSql);
            $orderDetails = $orderResult->fetch_assoc();
            
            // Calculate production cost per unit
            // Get material costs
            $materialCostSql = "SELECT ma.raw_material_id, ma.quantity_allocated, rm.unit_price
                               FROM material_allocations ma
                               JOIN raw_materials rm ON ma.raw_material_id = rm.id
                               WHERE ma.production_order_id = " . $jobDetails['production_order_id'];
            $materialCostResult = executeQuery($conn, $materialCostSql);
            $materialCost = 0;
            
            while ($material = $materialCostResult->fetch_assoc()) {
                $materialCost += $material['quantity_allocated'] * $material['unit_price'];
            }
            
            // Get printing costs
            $printingCostSql = "SELECT SUM(total_cost) AS total_printing_cost 
                               FROM printing_jobs 
                               WHERE production_order_id = " . $jobDetails['production_order_id'];
            $printingCostResult = executeQuery($conn, $printingCostSql);
            $printingCost = $printingCostResult->fetch_assoc()['total_printing_cost'] ?? 0;
            
            // Calculate total production cost for this binding job
            $totalProductionCost = $materialCost + $printingCost + $jobDetails['total_cost'];
            
            // Calculate production cost per unit
            $productionCostPerUnit = $totalProductionCost / $orderDetails['quantity'];
            
            // Add to finished inventory
            $inventorySql = "INSERT INTO finished_inventory (
                            book_id,
                            binding_job_id,
                            quantity,
                            production_cost_per_unit,
                            receipt_date,
                            notes
                        ) VALUES (
                            " . $orderDetails['book_id'] . ",
                            $jobId,
                            $receivedQuantity,
                            $productionCostPerUnit,
                            '$receivedDate',
                            'Received from binding job #$jobId'
                        )";
            
            executeQuery($conn, $inventorySql);
            
            // Check if all binding is complete for this order
            $checkBindingSql = "SELECT 
                               (SELECT quantity FROM production_orders WHERE id = " . $jobDetails['production_order_id'] . ") AS total_quantity,
                               (SELECT COALESCE(SUM(received_quantity), 0) FROM binding_jobs WHERE production_order_id = " . $jobDetails['production_order_id'] . ") AS total_bound";
            $checkBindingResult = executeQuery($conn, $checkBindingSql);
            $bindingStatus = $checkBindingResult->fetch_assoc();
            
            // If all books are bound, update production order status to completed
            if ($bindingStatus['total_bound'] >= $bindingStatus['total_quantity']) {
                $updateOrderSql = "UPDATE production_orders SET status = 'completed' WHERE id = " . $jobDetails['production_order_id'];
                executeQuery($conn, $updateOrderSql);
            }
            
            // Commit transaction
            $conn->commit();
            
            logActivity('receive_binding', "Received $receivedQuantity bound books for binding job #$jobId");
            
            setFlashMessage('Bound books received and added to inventory successfully.', 'success');
            redirect('production/binding.php');
        } catch (Exception $e) {
            // Rollback on error
            $conn->rollback();
            $errors[] = 'Error processing binding reception: ' . $e->getMessage();
        }
    }
}

// Get all binding jobs or jobs for a specific order
$jobsSql = "SELECT bj.*, po.order_date AS order_date, b.title AS book_title 
           FROM binding_jobs bj
           JOIN production_orders po ON bj.production_order_id = po.id
           JOIN books b ON po.book_id = b.id";

if ($orderId > 0) {
    $jobsSql .= " WHERE bj.production_order_id = $orderId";
}

$jobsSql .= " ORDER BY bj.sent_date DESC";

$jobsResult = executeQuery($conn, $jobsSql);
?>

<div class="d-flex justify-content-between align-items-center mb-4">
    <h1><?php echo $bindingJobId > 0 ? 'Receive Bound Books' : ($orderId > 0 ? 'New Binding Job' : 'Binding Jobs'); ?></h1>
    <div>
        <?php if ($bindingJobId > 0 || $orderId > 0): ?>
            <a href="binding.php" class="btn btn-secondary me-2">
                <i class="fas fa-arrow-left"></i> Back to Binding Jobs
            </a>
        <?php endif; ?>
        
        <?php if (!$bindingJobId && !$orderId): ?>
            <a href="orders.php" class="btn btn-secondary me-2">
                <i class="fas fa-clipboard-list"></i> Production Orders
            </a>
            <a href="../books/inventory.php" class="btn btn-primary">
                <i class="fas fa-boxes"></i> Finished Inventory
            </a>
        <?php endif; ?>
    </div>
</div>

<?php if (!empty($errors)): ?>
    <div class="alert alert-danger">
        <ul class="mb-0">
            <?php foreach ($errors as $error): ?>
                <li><?php echo $error; ?></li>
            <?php endforeach; ?>
        </ul>
    </div>
<?php endif; ?>

<?php if ($bindingJobId > 0): ?>
<!-- Receive Bound Books Form -->
<div class="card shadow mb-4">
    <div class="card-header py-3">
        <h6 class="m-0 font-weight-bold text-primary">Receive Bound Books</h6>
    </div>
    <div class="card-body">
        <div class="row mb-4">
            <div class="col-md-6">
                <h5>Binding Job Details</h5>
                <p><strong>Job ID:</strong> <?php echo $bindingJob['id']; ?></p>
                <p><strong>Production Order:</strong> #<?php echo $bindingJob['production_order_id']; ?> - <?php echo htmlspecialchars($order['book_title']); ?></p>
                <p><strong>Binder:</strong> <?php echo htmlspecialchars($bindingJob['binder_name']); ?></p>
                <p><strong>Sent Date:</strong> <?php echo formatDate($bindingJob['sent_date']); ?></p>
            </div>
            <div class="col-md-6">
                <h5>Quantity & Costs</h5>
                <p><strong>Sent Quantity:</strong> <?php echo number_format($bindingJob['sent_quantity']); ?></p>
                <p><strong>Cost Per Unit:</strong> <?php echo formatCurrency($bindingJob['cost_per_unit']); ?></p>
                <p><strong>Total Cost:</strong> <?php echo formatCurrency($bindingJob['total_cost']); ?></p>
                <p>
                    <strong>Status:</strong> 
                    <span class="badge bg-<?php echo $bindingJob['received_quantity'] > 0 ? 'success' : 'warning'; ?>">
                        <?php echo $bindingJob['received_quantity'] > 0 ? 'Received' : 'Pending'; ?>
                    </span>
                </p>
            </div>
        </div>
        
        <form method="post" action="">
            <input type="hidden" name="job_id" value="<?php echo $bindingJob['id']; ?>">
            
            <div class="row mb-3">
                <div class="col-md-6">
                    <label for="received_quantity" class="form-label">Received Quantity *</label>
                    <input type="number" class="form-control" id="received_quantity" name="received_quantity" 
                           value="<?php echo $bindingJob['received_quantity'] > 0 ? $bindingJob['received_quantity'] : $bindingJob['sent_quantity']; ?>" 
                           min="1" max="<?php echo $bindingJob['sent_quantity']; ?>" required>
                    <small class="text-muted">Maximum: <?php echo number_format($bindingJob['sent_quantity']); ?></small>
                </div>
                <div class="col-md-6">
                    <label for="received_date" class="form-label">Received Date *</label>
                    <input type="date" class="form-control" id="received_date" name="received_date" 
                           value="<?php echo $bindingJob['received_date'] ? $bindingJob['received_date'] : date('Y-m-d'); ?>" required>
                </div>
            </div>
            
            <div class="row mb-3">
                <div class="col-md-6">
                    <label for="payment_status" class="form-label">Payment Status *</label>
                    <select name="payment_status" id="payment_status" class="form-select" required>
                        <option value="pending" <?php echo $bindingJob['payment_status'] === 'pending' ? 'selected' : ''; ?>>Pending</option>
                        <option value="partial" <?php echo $bindingJob['payment_status'] === 'partial' ? 'selected' : ''; ?>>Partial</option>
                        <option value="paid" <?php echo $bindingJob['payment_status'] === 'paid' ? 'selected' : ''; ?>>Paid</option>
                    </select>
                </div>
                <div class="col-md-6">
                    <label for="payment_amount" class="form-label">Payment Amount</label>
                    <div class="input-group">
                        <span class="input-group-text">₹</span>
                        <input type="number" class="form-control" id="payment_amount" name="payment_amount" 
                               value="<?php echo $bindingJob['payment_amount']; ?>" min="0" step="0.01">
                    </div>
                    <small class="text-muted">Total Cost: <?php echo formatCurrency($bindingJob['total_cost']); ?></small>
                </div>
            </div>
            
            <div class="alert alert-info">
                <i class="fas fa-info-circle"></i> Receiving bound books will add them to the finished inventory. If this completes the production order, its status will be updated to 'completed'.
            </div>
            
            <div class="d-grid gap-2 d-md-flex justify-content-md-end">
                <a href="binding.php" class="btn btn-secondary me-md-2">Cancel</a>
                <button type="submit" name="receive_binding" class="btn btn-primary">Receive Books</button>
            </div>
        </form>
    </div>
</div>

<?php elseif ($orderId > 0): ?>
<!-- New Binding Job Form -->
<div class="card shadow mb-4">
    <div class="card-header py-3">
        <h6 class="m-0 font-weight-bold text-primary">Create New Binding Job</h6>
    </div>
    <div class="card-body">
        <div class="row mb-4">
            <div class="col-md-6">
                <h5>Production Order Details</h5>
                <p><strong>Order ID:</strong> <?php echo $order['id']; ?></p>
                <p><strong>Book:</strong> <?php echo htmlspecialchars($order['book_title']); ?></p>
                <p><strong>Order Date:</strong> <?php echo formatDate($order['order_date']); ?></p>
                <p><strong>Status:</strong> <?php echo ucfirst($order['status']); ?></p>
            </div>
            <div class="col-md-6">
                <h5>Quantity Information</h5>
                <?php
                // Calculate available quantities
                $printingSql = "SELECT COALESCE(SUM(received_quantity), 0) AS total_printed 
                               FROM printing_jobs 
                               WHERE production_order_id = $orderId";
                $printingResult = executeQuery($conn, $printingSql);
                $printing = $printingResult->fetch_assoc();
                
                $bindingSql = "SELECT COALESCE(SUM(sent_quantity), 0) AS total_sent_binding 
                              FROM binding_jobs 
                              WHERE production_order_id = $orderId";
                $bindingResult = executeQuery($conn, $bindingSql);
                $binding = $bindingResult->fetch_assoc();
                
                $availableForBinding = $printing['total_printed'] - $binding['total_sent_binding'];
                ?>
                <p><strong>Total Quantity:</strong> <?php echo number_format($order['quantity']); ?></p>
                <p><strong>Printed Quantity:</strong> <?php echo number_format($printing['total_printed']); ?></p>
                <p><strong>Already Sent for Binding:</strong> <?php echo number_format($binding['total_sent_binding']); ?></p>
                <p><strong>Available for Binding:</strong> <?php echo number_format($availableForBinding); ?></p>
            </div>
        </div>
        
        <?php if ($availableForBinding <= 0): ?>
            <div class="alert alert-warning">
                <i class="fas fa-exclamation-triangle"></i> No printed materials available for binding. Please complete printing jobs first.
            </div>
        <?php else: ?>
            <form method="post" action="">
                <input type="hidden" name="production_order_id" value="<?php echo $order['id']; ?>">
                
                <div class="row mb-3">
                    <div class="col-md-6">
                        <label for="binder_name" class="form-label">Binder Name *</label>
                        <input type="text" class="form-control" id="binder_name" name="binder_name" required>
                    </div>
                    <div class="col-md-6">
                        <label for="sent_quantity" class="form-label">Quantity to Send *</label>
                        <input type="number" class="form-control" id="sent_quantity" name="sent_quantity" 
                               min="1" max="<?php echo $availableForBinding; ?>" value="<?php echo $availableForBinding; ?>" required>
                        <small class="text-muted">Maximum: <?php echo number_format($availableForBinding); ?></small>
                    </div>
                </div>
                
                <div class="row mb-3">
                    <div class="col-md-6">
                        <label for="sent_date" class="form-label">Sent Date *</label>
                        <input type="date" class="form-control" id="sent_date" name="sent_date" value="<?php echo date('Y-m-d'); ?>" required>
                    </div>
                    <div class="col-md-6">
                        <label for="cost_per_unit" class="form-label">Cost Per Unit *</label>
                        <div class="input-group">
                            <span class="input-group-text">₹</span>
                            <input type="number" class="form-control" id="cost_per_unit" name="cost_per_unit" min="0.01" step="0.01" required>
                        </div>
                    </div>
                </div>
                
                <div class="mb-3">
                    <label for="notes" class="form-label">Notes</label>
                    <textarea class="form-control" id="notes" name="notes" rows="3"></textarea>
                </div>
                
                <div class="d-grid gap-2 d-md-flex justify-content-md-end">
                    <a href="orders.php" class="btn btn-secondary me-md-2">Cancel</a>
                    <button type="submit" name="create_job" class="btn btn-primary">Create Binding Job</button>
                </div>
            </form>
        <?php endif; ?>
    </div>
</div>

<?php else: ?>
<!-- Binding Jobs List -->
<div class="card shadow mb-4">
    <div class="card-header py-3">
        <h6 class="m-0 font-weight-bold text-primary">Binding Jobs</h6>
    </div>
    <div class="card-body">
        <div class="table-responsive">
            <table class="table table-bordered" width="100%" cellspacing="0">
                <thead>
                    <tr>
                        <th>ID</th>
                        <th>Production Order</th>
                        <th>Book</th>
                        <th>Binder</th>
                        <th>Sent Date</th>
                        <th>Quantity</th>
                        <th>Status</th>
                        <th>Cost</th>
                        <th>Payment</th>
                        <th>Actions</th>
                    </tr>
                </thead>
                <tbody>
                    <?php if ($jobsResult && $jobsResult->num_rows > 0): ?>
                        <?php while ($job = $jobsResult->fetch_assoc()): ?>
                            <tr>
                                <td><?php echo $job['id']; ?></td>
                                <td><a href="orders.php?id=<?php echo $job['production_order_id']; ?>">#<?php echo $job['production_order_id']; ?></a></td>
                                <td><?php echo htmlspecialchars($job['book_title']); ?></td>
                                <td><?php echo htmlspecialchars($job['binder_name']); ?></td>
                                <td><?php echo formatDate($job['sent_date']); ?></td>
                                <td>
                                    <?php if ($job['received_quantity'] > 0): ?>
                                        <?php echo number_format($job['received_quantity']); ?> / <?php echo number_format($job['sent_quantity']); ?>
                                    <?php else: ?>
                                        <?php echo number_format($job['sent_quantity']); ?>
                                    <?php endif; ?>
                                </td>
                                <td>
                                    <?php if ($job['received_quantity'] > 0): ?>
                                        <span class="badge bg-success">Received</span>
                                    <?php else: ?>
                                        <span class="badge bg-warning">Pending</span>
                                    <?php endif; ?>
                                </td>
                                <td><?php echo formatCurrency($job['total_cost']); ?></td>
                                <td>
                                    <span class="badge bg-<?php 
                                        echo ($job['payment_status'] === 'paid') ? 'success' : 
                                            (($job['payment_status'] === 'partial') ? 'warning' : 'danger'); 
                                    ?>">
                                        <?php echo ucfirst($job['payment_status']); ?>
                                    </span>
                                    <?php if ($job['payment_status'] === 'partial' || $job['payment_status'] === 'paid'): ?>
                                        <br><?php echo formatCurrency($job['payment_amount']); ?>
                                    <?php endif; ?>
                                </td>
                                <td>
                                    <?php if ($job['received_quantity'] <= 0): ?>
                                        <a href="binding.php?id=<?php echo $job['id']; ?>" class="btn btn-primary btn-sm">
                                            <i class="fas fa-check-circle"></i> Receive
                                        </a>
                                    <?php else: ?>
                                        <a href="binding.php?id=<?php echo $job['id']; ?>" class="btn btn-info btn-sm">
                                            <i class="fas fa-edit"></i> Edit
                                        </a>
                                        <a href="../books/inventory.php?binding_job=<?php echo $job['id']; ?>" class="btn btn-success btn-sm">
                                            <i class="fas fa-boxes"></i> Inventory
                                        </a>
                                    <?php endif; ?>
                                </td>
                            </tr>
                        <?php endwhile; ?>
                    <?php else: ?>
                        <tr>
                            <td colspan="10" class="text-center">No binding jobs found</td>
                        </tr>
                    <?php endif; ?>
                </tbody>
            </table>
        </div>
    </div>
</div>
<?php endif; ?>

<?php require_once '../includes/footer.php'; ?> else {
        setFlashMessage('Production order not found.', 'danger');
        redirect('production/orders.php');
    }
}

// Check if printing is done before allowing binding jobs
if ($orderId > 0) {
    $checkPrintingSql = "SELECT COALESCE(SUM(received_quantity), 0) AS total_printed
                         FROM printing_jobs 
                         WHERE production_order_id = $orderId AND received_quantity > 0";
    $checkPrintingResult = executeQuery($conn, $checkPrintingSql);
    $printingCount = $checkPrintingResult->fetch_assoc();
    
    if ($printingCount['total_printed'] <= 0) {
        setFlashMessage('Please complete printing jobs before creating binding jobs.', 'warning');
        redirect('production/printing.php?order_id=' . $orderId);
    }
}

// Get binding job details if id is provided
$bindingJob = null;
if ($bindingJobId > 0) {
    $jobSql = "SELECT * FROM binding_jobs WHERE id = $bindingJobId";
    $jobResult = executeQuery($conn, $jobSql);
    
    if ($jobResult && $jobResult->num_rows > 0) {
        $bindingJob = $jobResult->fetch_assoc();
        $orderId = $bindingJob['production_order_id'];
        
        // Get order details
        $orderSql = "SELECT po.*, b.title AS book_title, b.pages_per_book 
                    FROM production_orders po
                    JOIN books b ON po.book_id = b.id
                    WHERE po.id = $orderId";
        $orderResult = executeQuery($conn, $orderSql);
        $order = $orderResult->fetch_assoc();
    }
}

// Handle form submission for new binding job
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['create_job'])) {
    $productionOrderId = (int)$_POST['production_order_id'];
    $binderName = sanitizeInput($conn, $_POST['binder_name']);
    $sentQuantity = (int)$_POST['sent_quantity'];
    $sentDate = sanitizeInput($conn, $_POST['sent_date']);
    $costPerUnit = (float)$_POST['cost_per_unit'];
    $notes = sanitizeInput($conn, $_POST['notes']);
    
    // Validate input
    $errors = [];
    
    if ($productionOrderId <= 0) {
        $errors[] = 'Invalid production order.';
    }
    
    if (empty($binderName)) {
        $errors[] = 'Binder name is required.';
    }
    
    if ($sentQuantity <= 0) {
        $errors[] = 'Sent quantity must be greater than zero.';
    }
    
    if (empty($sentDate)) {
        $errors[] = 'Sent date is required.';
    }
    
    if ($costPerUnit <= 0) {
        $errors[] = 'Cost per unit must be greater than zero.';
    }
    
    // Check if there's enough printed quantity to bind
    $checkSql = "SELECT 
                 (SELECT COALESCE(SUM(received_quantity), 0) FROM printing_jobs WHERE production_order_id = $productionOrderId) AS total_printed,
                 (SELECT COALESCE(SUM(sent_quantity), 0) FROM binding_jobs WHERE production_order_id = $productionOrderId) AS total_sent_binding";
    $checkResult = executeQuery($conn, $checkSql);
    $quantities = $checkResult->fetch_assoc();
    
    $availableForBinding = $quantities['total_printed'] - $quantities['total_sent_binding'];
    
    if ($sentQuantity > $availableForBinding) {
        $errors[] = 'Sent quantity exceeds available printed quantity. Maximum allowed: ' . $availableForBinding;
    }
    
    // If no errors, create the binding job
    if (empty($errors)) {
        $totalCost = $sentQuantity * $costPerUnit;
        
        $sql = "INSERT INTO binding_jobs (
                    production_order_id, 
                    binder_name, 
                    sent_quantity, 
                    sent_date, 
                    cost_per_unit, 
                    total_cost, 
                    payment_status,
                    notes
                ) VALUES (
                    $productionOrderId, 
                    '$binderName', 
                    $sentQuantity, 
                    '$sentDate', 
                    $costPerUnit, 
                    $totalCost, 
                    'pending',
                    '$notes'
                )";
        
        if (executeQuery($conn, $sql)) {
            $jobId = $conn->insert_id;
            
            // Update production order status to binding if it's not already
            $updateOrderSql = "UPDATE production_orders SET status = 'binding' WHERE id = $productionOrderId AND status != 'completed'";
            executeQuery($conn, $updateOrderSql);
            
            logActivity('create_binding_job', "Created binding job #$jobId for production order #$productionOrderId, quantity: $sentQuantity");
            
            setFlashMessage('Binding job created successfully.', 'success');
            redirect('production/binding.php');
        } else {
            $errors[] = 'Error creating binding job. Please try again.';
        }
    }