<?php

/**
 * Printing Jobs Page
 * Manages printing jobs for production orders
 */
require_once '../includes/header.php';

// Check if order_id is provided
$orderId = isset($_GET['order_id']) ? (int)$_GET['order_id'] : 0;
$printingJobId = isset($_GET['id']) ? (int)$_GET['id'] : 0;

// Get order details if order_id is provided
$order = null;
if ($orderId > 0) {
    $orderSql = "SELECT po.*, b.title AS book_title 
                FROM production_orders po
                JOIN books b ON po.book_id = b.id
                WHERE po.id = $orderId";
    $orderResult = executeQuery($conn, $orderSql);

    if ($orderResult && $orderResult->num_rows > 0) {
        $order = $orderResult->fetch_assoc();
    } else {
        setFlashMessage('Production order not found.', 'danger');
        redirect('production/orders.php');
    }
}

// Check if materials are allocated before allowing printing jobs
if ($orderId > 0) {
    $checkAllocSql = "SELECT COUNT(*) AS count FROM material_allocations WHERE production_order_id = $orderId";
    $checkAllocResult = executeQuery($conn, $checkAllocSql);
    $allocCount = $checkAllocResult->fetch_assoc();

    if ($allocCount['count'] < 3) { // Need at least 3 allocations (paper, cover, half-title)
        setFlashMessage('Please allocate materials to this production order before creating printing jobs.', 'warning');
        redirect('materials/allocate.php?order_id=' . $orderId);
    }
}

// Get printing job details if id is provided
$printingJob = null;
if ($printingJobId > 0) {
    $jobSql = "SELECT * FROM printing_jobs WHERE id = $printingJobId";
    $jobResult = executeQuery($conn, $jobSql);

    if ($jobResult && $jobResult->num_rows > 0) {
        $printingJob = $jobResult->fetch_assoc();
        $orderId = $printingJob['production_order_id'];

        // Get order details
        $orderSql = "SELECT po.*, b.title AS book_title 
                    FROM production_orders po
                    JOIN books b ON po.book_id = b.id
                    WHERE po.id = $orderId";
        $orderResult = executeQuery($conn, $orderSql);
        $order = $orderResult->fetch_assoc();
    }
}

// Handle form submission for new printing job
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['create_job'])) {
    $productionOrderId = (int)$_POST['production_order_id'];
    $printerName = sanitizeInput($conn, $_POST['printer_name']);
    $sentQuantity = (int)$_POST['sent_quantity'];
    $sentDate = sanitizeInput($conn, $_POST['sent_date']);
    $costPerUnit = (float)$_POST['cost_per_unit'];
    $notes = sanitizeInput($conn, $_POST['notes']);

    // Validate input
    $errors = [];

    if ($productionOrderId <= 0) {
        $errors[] = 'Invalid production order.';
    }

    if (empty($printerName)) {
        $errors[] = 'Printer name is required.';
    }

    if ($sentQuantity <= 0) {
        $errors[] = 'Sent quantity must be greater than zero.';
    }

    if (empty($sentDate)) {
        $errors[] = 'Sent date is required.';
    }

    if ($costPerUnit <= 0) {
        $errors[] = 'Cost per unit must be greater than zero.';
    }

    // Check if there's enough remaining quantity in the order
    $checkSql = "SELECT po.quantity, 
                 (po.quantity - COALESCE(SUM(pj.sent_quantity), 0)) AS remaining_quantity
                 FROM production_orders po
                 LEFT JOIN printing_jobs pj ON po.id = pj.production_order_id
                 WHERE po.id = $productionOrderId
                 GROUP BY po.id, po.quantity";
    $checkResult = executeQuery($conn, $checkSql);
    $orderDetails = $checkResult->fetch_assoc();

    if ($sentQuantity > $orderDetails['remaining_quantity']) {
        $errors[] = 'Sent quantity exceeds remaining quantity for this order. Maximum allowed: ' .
            $orderDetails['remaining_quantity'];
    }

    // If no errors, create the printing job
    if (empty($errors)) {
        $totalCost = $sentQuantity * $costPerUnit;

        $sql = "INSERT INTO printing_jobs (
                    production_order_id, 
                    printer_name, 
                    sent_quantity, 
                    sent_date, 
                    cost_per_unit, 
                    total_cost, 
                    payment_status,
                    notes
                ) VALUES (
                    $productionOrderId, 
                    '$printerName', 
                    $sentQuantity, 
                    '$sentDate', 
                    $costPerUnit, 
                    $totalCost, 
                    'pending',
                    '$notes'
                )";

        if (executeQuery($conn, $sql)) {
            $jobId = $conn->insert_id;

            logActivity('create_printing_job', "Created printing job #$jobId for production order #$productionOrderId, quantity: $sentQuantity");

            setFlashMessage('Printing job created successfully.', 'success');
            redirect('production/printing.php');
        } else {
            $errors[] = 'Error creating printing job. Please try again.';
        }
    }
}

// Handle form submission for receiving printed materials
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['receive_printing'])) {
    $jobId = (int)$_POST['job_id'];
    $receivedQuantity = (int)$_POST['received_quantity'];
    $receivedDate = sanitizeInput($conn, $_POST['received_date']);
    $paymentAmount = (float)$_POST['payment_amount'];
    $paymentStatus = sanitizeInput($conn, $_POST['payment_status']);

    // Validate input
    $errors = [];

    if ($jobId <= 0) {
        $errors[] = 'Invalid printing job.';
    }

    if ($receivedQuantity <= 0) {
        $errors[] = 'Received quantity must be greater than zero.';
    }

    if (empty($receivedDate)) {
        $errors[] = 'Received date is required.';
    }

    // Get job details
    $jobDetailsSql = "SELECT * FROM printing_jobs WHERE id = $jobId";
    $jobDetailsResult = executeQuery($conn, $jobDetailsSql);
    $jobDetails = $jobDetailsResult->fetch_assoc();

    if ($receivedQuantity > $jobDetails['sent_quantity']) {
        $errors[] = 'Received quantity cannot be greater than sent quantity.';
    }

    // If no errors, update the printing job
    if (empty($errors)) {
        $sql = "UPDATE printing_jobs SET 
                received_quantity = $receivedQuantity, 
                received_date = '$receivedDate',
                payment_status = '$paymentStatus',
                payment_amount = $paymentAmount
                WHERE id = $jobId";

        if (executeQuery($conn, $sql)) {
            // Get production order details
            $orderDetailsSql = "SELECT * FROM production_orders WHERE id = " . $jobDetails['production_order_id'];
            $orderDetailsResult = executeQuery($conn, $orderDetailsSql);
            $orderDetails = $orderDetailsResult->fetch_assoc();

            // Update production order status if needed
            $updateStatusSql = "UPDATE production_orders SET status = 'binding' 
                               WHERE id = " . $jobDetails['production_order_id'];
            executeQuery($conn, $updateStatusSql);

            logActivity('receive_printing', "Received $receivedQuantity printed materials for printing job #$jobId");

            setFlashMessage('Printed materials received successfully.', 'success');
            redirect('production/printing.php');
        } else {
            $errors[] = 'Error updating printing job. Please try again.';
        }
    }
}

// Get all printing jobs or jobs for a specific order
$jobsSql = "SELECT pj.*, po.order_date AS order_date, b.title AS book_title 
           FROM printing_jobs pj
           JOIN production_orders po ON pj.production_order_id = po.id
           JOIN books b ON po.book_id = b.id";

if ($orderId > 0) {
    $jobsSql .= " WHERE pj.production_order_id = $orderId";
}

$jobsSql .= " ORDER BY pj.sent_date DESC";

$jobsResult = executeQuery($conn, $jobsSql);
?>

<div class="d-flex justify-content-between align-items-center mb-4">
    <h1><?php echo $printingJobId > 0 ? 'Receive Printed Materials' : ($orderId > 0 ? 'New Printing Job' : 'Printing Jobs'); ?></h1>
    <div>
        <?php if ($printingJobId > 0 || $orderId > 0): ?>
            <a href="printing.php" class="btn btn-secondary me-2">
                <i class="fas fa-arrow-left"></i> Back to Printing Jobs
            </a>
        <?php endif; ?>

        <?php if (!$printingJobId && !$orderId): ?>
            <a href="orders.php" class="btn btn-secondary me-2">
                <i class="fas fa-clipboard-list"></i> Production Orders
            </a>
        <?php endif; ?>
    </div>
</div>

<?php if (!empty($errors)): ?>
    <div class="alert alert-danger">
        <ul class="mb-0">
            <?php foreach ($errors as $error): ?>
                <li><?php echo $error; ?></li>
            <?php endforeach; ?>
        </ul>
    </div>
<?php endif; ?>

<?php if ($printingJobId > 0): ?>
    <!-- Receive Printed Materials Form -->
    <div class="card shadow mb-4">
        <div class="card-header py-3">
            <h6 class="m-0 font-weight-bold text-primary">Receive Printed Materials</h6>
        </div>
        <div class="card-body">
            <div class="row mb-4">
                <div class="col-md-6">
                    <h5>Printing Job Details</h5>
                    <p><strong>Job ID:</strong> <?php echo $printingJob['id']; ?></p>
                    <p><strong>Production Order:</strong> #<?php echo $printingJob['production_order_id']; ?> - <?php echo htmlspecialchars($order['book_title']); ?></p>
                    <p><strong>Printer:</strong> <?php echo htmlspecialchars($printingJob['printer_name']); ?></p>
                    <p><strong>Sent Date:</strong> <?php echo formatDate($printingJob['sent_date']); ?></p>
                </div>
                <div class="col-md-6">
                    <h5>Quantity & Costs</h5>
                    <p><strong>Sent Quantity:</strong> <?php echo number_format($printingJob['sent_quantity']); ?></p>
                    <p><strong>Cost Per Unit:</strong> <?php echo formatCurrency($printingJob['cost_per_unit']); ?></p>
                    <p><strong>Total Cost:</strong> <?php echo formatCurrency($printingJob['total_cost']); ?></p>
                    <p>
                        <strong>Status:</strong>
                        <span class="badge bg-<?php echo $printingJob['received_quantity'] > 0 ? 'success' : 'warning'; ?>">
                            <?php echo $printingJob['received_quantity'] > 0 ? 'Received' : 'Pending'; ?>
                        </span>
                    </p>
                </div>
            </div>

            <form method="post" action="">
                <input type="hidden" name="job_id" value="<?php echo $printingJob['id']; ?>">

                <div class="row mb-3">
                    <div class="col-md-6">
                        <label for="received_quantity" class="form-label">Received Quantity *</label>
                        <input type="number" class="form-control" id="received_quantity" name="received_quantity"
                            value="<?php echo $printingJob['received_quantity'] > 0 ? $printingJob['received_quantity'] : $printingJob['sent_quantity']; ?>"
                            min="1" max="<?php echo $printingJob['sent_quantity']; ?>" required>
                        <small class="text-muted">Maximum: <?php echo number_format($printingJob['sent_quantity']); ?></small>
                    </div>
                    <div class="col-md-6">
                        <label for="received_date" class="form-label">Received Date *</label>
                        <input type="date" class="form-control" id="received_date" name="received_date"
                            value="<?php echo $printingJob['received_date'] ? $printingJob['received_date'] : date('Y-m-d'); ?>" required>
                    </div>
                </div>

                <div class="row mb-3">
                    <div class="col-md-6">
                        <label for="payment_status" class="form-label">Payment Status *</label>
                        <select name="payment_status" id="payment_status" class="form-select" required>
                            <option value="pending" <?php echo $printingJob['payment_status'] === 'pending' ? 'selected' : ''; ?>>Pending</option>
                            <option value="partial" <?php echo $printingJob['payment_status'] === 'partial' ? 'selected' : ''; ?>>Partial</option>
                            <option value="paid" <?php echo $printingJob['payment_status'] === 'paid' ? 'selected' : ''; ?>>Paid</option>
                        </select>
                    </div>
                    <div class="col-md-6">
                        <label for="payment_amount" class="form-label">Payment Amount</label>
                        <div class="input-group">
                            <span class="input-group-text">₹</span>
                            <input type="number" class="form-control" id="payment_amount" name="payment_amount"
                                value="<?php echo $printingJob['payment_amount']; ?>" min="0" step="0.01">
                        </div>
                        <small class="text-muted">Total Cost: <?php echo formatCurrency($printingJob['total_cost']); ?></small>
                    </div>
                </div>

                <div class="alert alert-info">
                    <i class="fas fa-info-circle"></i> Receiving printed materials will move the production order to the binding stage.
                </div>

                <div class="d-grid gap-2 d-md-flex justify-content-md-end">
                    <a href="printing.php" class="btn btn-secondary me-md-2">Cancel</a>
                    <button type="submit" name="receive_printing" class="btn btn-primary">Receive Materials</button>
                </div>
            </form>
        </div>
    </div>

<?php elseif ($orderId > 0): ?>
    <!-- New Printing Job Form -->
    <div class="card shadow mb-4">
        <div class="card-header py-3">
            <h6 class="m-0 font-weight-bold text-primary">Create New Printing Job</h6>
        </div>
        <div class="card-body">
            <div class="row mb-4">
                <div class="col-md-6">
                    <h5>Production Order Details</h5>
                    <p><strong>Order ID:</strong> <?php echo $order['id']; ?></p>
                    <p><strong>Book:</strong> <?php echo htmlspecialchars($order['book_title']); ?></p>
                    <p><strong>Order Date:</strong> <?php echo formatDate($order['order_date']); ?></p>
                    <p><strong>Status:</strong> <?php echo ucfirst($order['status']); ?></p>
                </div>
                <div class="col-md-6">
                    <h5>Quantity Information</h5>
                    <?php
                    // Calculate remaining quantity
                    $sentSql = "SELECT COALESCE(SUM(sent_quantity), 0) AS total_sent 
                           FROM printing_jobs 
                           WHERE production_order_id = $orderId";
                    $sentResult = executeQuery($conn, $sentSql);
                    $sent = $sentResult->fetch_assoc();
                    $remainingQuantity = $order['quantity'] - $sent['total_sent'];
                    ?>
                    <p><strong>Total Quantity:</strong> <?php echo number_format($order['quantity']); ?></p>
                    <p><strong>Already Sent for Printing:</strong> <?php echo number_format($sent['total_sent']); ?></p>
                    <p><strong>Remaining Quantity:</strong> <?php echo number_format($remainingQuantity); ?></p>
                </div>
            </div>

            <?php if ($remainingQuantity <= 0): ?>
                <div class="alert alert-warning">
                    <i class="fas fa-exclamation-triangle"></i> All items from this production order have already been sent for printing.
                </div>
            <?php else: ?>
                <form method="post" action="">
                    <input type="hidden" name="production_order_id" value="<?php echo $order['id']; ?>">

                    <div class="row mb-3">
                        <div class="col-md-6">
                            <label for="printer_name" class="form-label">Printer Name *</label>
                            <input type="text" class="form-control" id="printer_name" name="printer_name" required>
                        </div>
                        <div class="col-md-6">
                            <label for="sent_quantity" class="form-label">Quantity to Send *</label>
                            <input type="number" class="form-control" id="sent_quantity" name="sent_quantity"
                                min="1" max="<?php echo $remainingQuantity; ?>" value="<?php echo $remainingQuantity; ?>" required>
                            <small class="text-muted">Maximum: <?php echo number_format($remainingQuantity); ?></small>
                        </div>
                    </div>

                    <div class="row mb-3">
                        <div class="col-md-6">
                            <label for="sent_date" class="form-label">Sent Date *</label>
                            <input type="date" class="form-control" id="sent_date" name="sent_date" value="<?php echo date('Y-m-d'); ?>" required>
                        </div>
                        <div class="col-md-6">
                            <label for="cost_per_unit" class="form-label">Cost Per Unit *</label>
                            <div class="input-group">
                                <span class="input-group-text">₹</span>
                                <input type="number" class="form-control" id="cost_per_unit" name="cost_per_unit" min="0.01" step="0.01" required>
                            </div>
                        </div>
                    </div>

                    <div class="mb-3">
                        <label for="notes" class="form-label">Notes</label>
                        <textarea class="form-control" id="notes" name="notes" rows="3"></textarea>
                    </div>

                    <div class="d-grid gap-2 d-md-flex justify-content-md-end">
                        <a href="orders.php" class="btn btn-secondary me-md-2">Cancel</a>
                        <button type="submit" name="create_job" class="btn btn-primary">Create Printing Job</button>
                    </div>
                </form>
            <?php endif; ?>
        </div>
    </div>

<?php else: ?>
    <!-- Printing Jobs List -->
    <div class="card shadow mb-4">
        <div class="card-header py-3">
            <h6 class="m-0 font-weight-bold text-primary">Printing Jobs</h6>
        </div>
        <div class="card-body">
            <div class="table-responsive">
                <table class="table table-bordered" width="100%" cellspacing="0">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>Production Order</th>
                            <th>Book</th>
                            <th>Printer</th>
                            <th>Sent Date</th>
                            <th>Quantity</th>
                            <th>Status</th>
                            <th>Cost</th>
                            <th>Payment</th>
                            <th>Actions</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if ($jobsResult && $jobsResult->num_rows > 0): ?>
                            <?php while ($job = $jobsResult->fetch_assoc()): ?>
                                <tr>
                                    <td><?php echo $job['id']; ?></td>
                                    <td><a href="orders.php?id=<?php echo $job['production_order_id']; ?>">#<?php echo $job['production_order_id']; ?></a></td>
                                    <td><?php echo htmlspecialchars($job['book_title']); ?></td>
                                    <td><?php echo htmlspecialchars($job['printer_name']); ?></td>
                                    <td><?php echo formatDate($job['sent_date']); ?></td>
                                    <td>
                                        <?php if ($job['received_quantity'] > 0): ?>
                                            <?php echo number_format($job['received_quantity']); ?> / <?php echo number_format($job['sent_quantity']); ?>
                                        <?php else: ?>
                                            <?php echo number_format($job['sent_quantity']); ?>
                                        <?php endif; ?>
                                    </td>
                                    <td>
                                        <?php if ($job['received_quantity'] > 0): ?>
                                            <span class="badge bg-success">Received</span>
                                        <?php else: ?>
                                            <span class="badge bg-warning">Pending</span>
                                        <?php endif; ?>
                                    </td>
                                    <td><?php echo formatCurrency($job['total_cost']); ?></td>
                                    <td>
                                        <span class="badge bg-<?php
                                                                echo ($job['payment_status'] === 'paid') ? 'success' : (($job['payment_status'] === 'partial') ? 'warning' : 'danger');
                                                                ?>">
                                            <?php echo ucfirst($job['payment_status']); ?>
                                        </span>
                                        <?php if ($job['payment_status'] === 'partial' || $job['payment_status'] === 'paid'): ?>
                                            <br><?php echo formatCurrency($job['payment_amount']); ?>
                                        <?php endif; ?>
                                    </td>
                                    <td>
                                        <?php if ($job['received_quantity'] <= 0): ?>
                                            <a href="printing.php?id=<?php echo $job['id']; ?>" class="btn btn-primary btn-sm">
                                                <i class="fas fa-check-circle"></i> Receive
                                            </a>
                                        <?php else: ?>
                                            <a href="printing.php?id=<?php echo $job['id']; ?>" class="btn btn-info btn-sm">
                                                <i class="fas fa-edit"></i> Edit
                                            </a>
                                        <?php endif; ?>
                                    </td>
                                </tr>
                            <?php endwhile; ?>
                        <?php else: ?>
                            <tr>
                                <td colspan="10" class="text-center">No printing jobs found</td>
                            </tr>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
<?php endif; ?>

<?php require_once '../includes/footer.php'; ?>