<?php

/**
 * View Production Order Details Page
 * Displays detailed information about a specific production order
 */
require_once '../includes/header.php';

// Check if ID is provided
if (!isset($_GET['id']) || empty($_GET['id'])) {
    setFlashMessage('Production order ID is required.', 'danger');
    redirect('production/orders.php');
}

$id = (int)$_GET['id'];

// Get production order data
$sql = "SELECT po.*, b.title AS book_title, b.author, b.pages_per_book, b.wholesale_price, b.retail_price
        FROM production_orders po
        JOIN books b ON po.book_id = b.id
        WHERE po.id = $id";
$result = executeQuery($conn, $sql);

if (!$result || $result->num_rows === 0) {
    setFlashMessage('Production order not found.', 'danger');
    redirect('production/orders.php');
}

$order = $result->fetch_assoc();

// Get material allocations
$materialsSql = "SELECT ma.*, rm.material_type, rm.batch_number, rm.unit_price
                FROM material_allocations ma
                JOIN raw_materials rm ON ma.raw_material_id = rm.id
                WHERE ma.production_order_id = $id
                ORDER BY ma.allocation_date";
$materialsResult = executeQuery($conn, $materialsSql);

$materials = [
    'paper' => ['allocated' => false, 'quantity' => 0, 'cost' => 0],
    'cover' => ['allocated' => false, 'quantity' => 0, 'cost' => 0],
    'half_title' => ['allocated' => false, 'quantity' => 0, 'cost' => 0]
];

$totalMaterialCost = 0;

if ($materialsResult && $materialsResult->num_rows > 0) {
    while ($material = $materialsResult->fetch_assoc()) {
        $materialType = $material['material_type'];
        $materials[$materialType]['allocated'] = true;
        $materials[$materialType]['quantity'] += $material['quantity_allocated'];
        $materialCost = $material['quantity_allocated'] * $material['unit_price'];
        $materials[$materialType]['cost'] += $materialCost;
        $totalMaterialCost += $materialCost;
    }
}

// Get printing jobs
$printingSql = "SELECT * FROM printing_jobs WHERE production_order_id = $id ORDER BY sent_date";
$printingResult = executeQuery($conn, $printingSql);

$totalPrintingCost = 0;
$totalPrintingSent = 0;
$totalPrintingReceived = 0;
$printingJobs = [];

if ($printingResult && $printingResult->num_rows > 0) {
    while ($job = $printingResult->fetch_assoc()) {
        $printingJobs[] = $job;
        $totalPrintingCost += $job['total_cost'];
        $totalPrintingSent += $job['sent_quantity'];
        $totalPrintingReceived += $job['received_quantity'];
    }
}

$printingProgress = ($order['quantity'] > 0) ? ($totalPrintingReceived / $order['quantity'] * 100) : 0;

// Get binding jobs
$bindingSql = "SELECT * FROM binding_jobs WHERE production_order_id = $id ORDER BY sent_date";
$bindingResult = executeQuery($conn, $bindingSql);

$totalBindingCost = 0;
$totalBindingSent = 0;
$totalBindingReceived = 0;
$bindingJobs = [];

if ($bindingResult && $bindingResult->num_rows > 0) {
    while ($job = $bindingResult->fetch_assoc()) {
        $bindingJobs[] = $job;
        $totalBindingCost += $job['total_cost'];
        $totalBindingSent += $job['sent_quantity'];
        $totalBindingReceived += $job['received_quantity'];
    }
}

$bindingProgress = ($order['quantity'] > 0) ? ($totalBindingReceived / $order['quantity'] * 100) : 0;

// Get finished inventory
$inventorySql = "SELECT fi.*, bj.id AS binding_job_id
                FROM finished_inventory fi
                JOIN binding_jobs bj ON fi.binding_job_id = bj.id
                WHERE bj.production_order_id = $id
                ORDER BY fi.receipt_date";
$inventoryResult = executeQuery($conn, $inventorySql);

$totalInventory = 0;
$inventory = [];

if ($inventoryResult && $inventoryResult->num_rows > 0) {
    while ($item = $inventoryResult->fetch_assoc()) {
        $inventory[] = $item;
        $totalInventory += $item['quantity'];
    }
}

$inventoryProgress = ($order['quantity'] > 0) ? ($totalInventory / $order['quantity'] * 100) : 0;

// Calculate production costs
$totalProductionCost = $totalMaterialCost + $totalPrintingCost + $totalBindingCost;
$costPerUnit = ($totalBindingReceived > 0) ? ($totalProductionCost / $totalBindingReceived) : 0;
?>

<div class="d-flex justify-content-between align-items-center mb-4">
    <h1>Production Order #<?php echo $id; ?></h1>
    <div>
        <?php if ($order['status'] !== 'cancelled' && $order['status'] !== 'completed'): ?>
            <div class="btn-group me-2">
                <?php if (!empty($materials['paper']['allocated'])): ?>
                    <a href="../production/printing.php?order_id=<?php echo $id; ?>" class="btn btn-warning">
                        <i class="fas fa-print"></i> Add Printing Job
                    </a>
                <?php else: ?>
                    <a href="../materials/allocate.php?order_id=<?php echo $id; ?>" class="btn btn-primary">
                        <i class="fas fa-boxes"></i> Allocate Materials
                    </a>
                <?php endif; ?>

                <?php if ($totalPrintingReceived > 0): ?>
                    <a href="../production/binding.php?order_id=<?php echo $id; ?>" class="btn btn-success">
                        <i class="fas fa-book-open"></i> Add Binding Job
                    </a>
                <?php endif; ?>
            </div>
        <?php endif; ?>

        <a href="orders.php" class="btn btn-secondary">
            <i class="fas fa-arrow-left"></i> Back to Orders
        </a>
    </div>
</div>

<!-- Basic Order Information -->
<div class="row">
    <div class="col-md-8">
        <div class="card shadow mb-4">
            <div class="card-header py-3">
                <h6 class="m-0 font-weight-bold text-primary">Order Information</h6>
            </div>
            <div class="card-body">
                <div class="row mb-3">
                    <div class="col-md-6">
                        <p><strong>Book:</strong> <?php echo htmlspecialchars($order['book_title']); ?></p>
                        <p><strong>Author:</strong> <?php echo htmlspecialchars($order['author']); ?></p>
                        <p><strong>Pages per Book:</strong> <?php echo number_format($order['pages_per_book']); ?></p>
                        <p>
                            <strong>Status:</strong>
                            <span class="badge bg-<?php
                                                    echo ($order['status'] === 'completed') ? 'success' : (($order['status'] === 'pending') ? 'warning' : (($order['status'] === 'cancelled') ? 'danger' : 'info'));
                                                    ?>">
                                <?php echo ucfirst($order['status']); ?>
                            </span>
                        </p>
                    </div>
                    <div class="col-md-6">
                        <p><strong>Order Date:</strong> <?php echo formatDate($order['order_date']); ?></p>
                        <p><strong>Quantity:</strong> <?php echo number_format($order['quantity']); ?> books</p>
                        <p><strong>Wholesale Price:</strong> <?php echo formatCurrency($order['wholesale_price']); ?></p>
                        <p><strong>Retail Price:</strong> <?php echo formatCurrency($order['retail_price']); ?></p>
                    </div>
                </div>

                <div class="row">
                    <div class="col-md-12">
                        <h6 class="font-weight-bold">Notes:</h6>
                        <p><?php echo !empty($order['notes']) ? htmlspecialchars($order['notes']) : 'No notes available.'; ?></p>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <div class="col-md-4">
        <div class="card shadow mb-4">
            <div class="card-header py-3">
                <h6 class="m-0 font-weight-bold text-primary">Production Progress</h6>
            </div>
            <div class="card-body">
                <h6 class="font-weight-bold">Materials:</h6>
                <div class="progress mb-2" style="height: 20px;">
                    <div class="progress-bar <?php echo empty($materials['paper']['allocated']) ? 'bg-danger' : 'bg-success'; ?>"
                        role="progressbar" style="width: 100%" aria-valuenow="100" aria-valuemin="0" aria-valuemax="100">
                        <?php echo empty($materials['paper']['allocated']) ? 'Not Allocated' : 'Allocated'; ?>
                    </div>
                </div>

                <h6 class="font-weight-bold mt-3">Printing:</h6>
                <div class="progress mb-2" style="height: 20px;">
                    <div class="progress-bar bg-warning" role="progressbar" style="width: <?php echo $printingProgress; ?>%"
                        aria-valuenow="<?php echo $printingProgress; ?>" aria-valuemin="0" aria-valuemax="100">
                        <?php echo number_format($printingProgress, 1); ?>%
                    </div>
                </div>
                <div class="small text-muted mb-3">
                    <?php echo number_format($totalPrintingReceived); ?> of <?php echo number_format($order['quantity']); ?> printed
                </div>

                <h6 class="font-weight-bold">Binding:</h6>
                <div class="progress mb-2" style="height: 20px;">
                    <div class="progress-bar bg-info" role="progressbar" style="width: <?php echo $bindingProgress; ?>%"
                        aria-valuenow="<?php echo $bindingProgress; ?>" aria-valuemin="0" aria-valuemax="100">
                        <?php echo number_format($bindingProgress, 1); ?>%
                    </div>
                </div>
                <div class="small text-muted mb-3">
                    <?php echo number_format($totalBindingReceived); ?> of <?php echo number_format($order['quantity']); ?> bound
                </div>

                <h6 class="font-weight-bold">Finished Inventory:</h6>
                <div class="progress mb-2" style="height: 20px;">
                    <div class="progress-bar bg-success" role="progressbar" style="width: <?php echo $inventoryProgress; ?>%"
                        aria-valuenow="<?php echo $inventoryProgress; ?>" aria-valuemin="0" aria-valuemax="100">
                        <?php echo number_format($inventoryProgress, 1); ?>%
                    </div>
                </div>
                <div class="small text-muted">
                    <?php echo number_format($totalInventory); ?> of <?php echo number_format($order['quantity']); ?> in inventory
                </div>
            </div>
        </div>
    </div>
</div>

<!-- Cost Summary -->
<div class="card shadow mb-4">
    <div class="card-header py-3">
        <h6 class="m-0 font-weight-bold text-primary">Production Cost Summary</h6>
    </div>
    <div class="card-body">
        <div class="row">
            <div class="col-md-8">
                <table class="table table-bordered">
                    <tr class="table-secondary">
                        <th colspan="2">Materials Cost</th>
                    </tr>
                    <tr>
                        <td>Paper</td>
                        <td class="text-end"><?php echo formatCurrency($materials['paper']['cost']); ?></td>
                    </tr>
                    <tr>
                        <td>Cover</td>
                        <td class="text-end"><?php echo formatCurrency($materials['cover']['cost']); ?></td>
                    </tr>
                    <tr>
                        <td>Half Title</td>
                        <td class="text-end"><?php echo formatCurrency($materials['half_title']['cost']); ?></td>
                    </tr>
                    <tr>
                        <th>Subtotal - Materials</th>
                        <th class="text-end"><?php echo formatCurrency($totalMaterialCost); ?></th>
                    </tr>
                    <tr class="table-secondary">
                        <th colspan="2">Processing Cost</th>
                    </tr>
                    <tr>
                        <td>Printing</td>
                        <td class="text-end"><?php echo formatCurrency($totalPrintingCost); ?></td>
                    </tr>
                    <tr>
                        <td>Binding</td>
                        <td class="text-end"><?php echo formatCurrency($totalBindingCost); ?></td>
                    </tr>
                    <tr>
                        <th>Subtotal - Processing</th>
                        <th class="text-end"><?php echo formatCurrency($totalPrintingCost + $totalBindingCost); ?></th>
                    </tr>
                    <tr class="table-primary">
                        <th>Total Production Cost</th>
                        <th class="text-end"><?php echo formatCurrency($totalProductionCost); ?></th>
                    </tr>
                    <tr>
                        <td>Cost Per Book</td>
                        <td class="text-end"><?php echo formatCurrency($costPerUnit); ?></td>
                    </tr>
                </table>
            </div>
            <div class="col-md-4">
                <div class="card h-100">
                    <div class="card-header">
                        <h6 class="m-0 font-weight-bold">Cost Breakdown</h6>
                    </div>
                    <div class="card-body">
                        <div class="chart-container" style="position: relative; height:300px; width:100%">
                            <canvas id="costBreakdownChart"></canvas>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<!-- Material Allocations -->
<div class="card shadow mb-4">
    <div class="card-header py-3">
        <h6 class="m-0 font-weight-bold text-primary">Material Allocations</h6>
    </div>
    <div class="card-body">
        <?php if ($materialsResult && $materialsResult->num_rows > 0): ?>
            <div class="table-responsive">
                <table class="table table-bordered" width="100%" cellspacing="0">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>Material Type</th>
                            <th>Batch Number</th>
                            <th>Allocation Date</th>
                            <th>Quantity</th>
                            <th>Unit Price</th>
                            <th>Total Cost</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php
                        // Reset result pointer
                        $materialsResult->data_seek(0);
                        while ($material = $materialsResult->fetch_assoc()):
                        ?>
                            <tr>
                                <td><?php echo $material['id']; ?></td>
                                <td><?php echo ucfirst($material['material_type']); ?></td>
                                <td>
                                    <a href="../materials/view.php?id=<?php echo $material['raw_material_id']; ?>">
                                        <?php echo htmlspecialchars($material['batch_number']); ?>
                                    </a>
                                </td>
                                <td><?php echo formatDate($material['allocation_date']); ?></td>
                                <td><?php echo number_format($material['quantity_allocated']); ?></td>
                                <td><?php echo formatCurrency($material['unit_price']); ?></td>
                                <td><?php echo formatCurrency($material['quantity_allocated'] * $material['unit_price']); ?></td>
                            </tr>
                        <?php endwhile; ?>
                    </tbody>
                </table>
            </div>
        <?php else: ?>
            <div class="alert alert-warning">
                <i class="fas fa-exclamation-triangle"></i> No materials have been allocated to this production order yet.
                <?php if ($order['status'] !== 'cancelled' && $order['status'] !== 'completed'): ?>
                    <a href="../materials/allocate.php?order_id=<?php echo $id; ?>" class="btn btn-primary btn-sm ms-3">
                        Allocate Materials
                    </a>
                <?php endif; ?>
            </div>
        <?php endif; ?>
    </div>
</div>

<!-- Printing Jobs -->
<div class="card shadow mb-4">
    <div class="card-header py-3 d-flex justify-content-between align-items-center">
        <h6 class="m-0 font-weight-bold text-primary">Printing Jobs</h6>
        <?php if (!empty($printingJobs)): ?>
            <span class="badge bg-warning"><?php echo formatCurrency($totalPrintingCost); ?> Total</span>
        <?php endif; ?>
    </div>
    <div class="card-body">
        <?php if (!empty($printingJobs)): ?>
            <div class="table-responsive">
                <table class="table table-bordered" width="100%" cellspacing="0">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>Printer</th>
                            <th>Sent Date</th>
                            <th>Sent Quantity</th>
                            <th>Received Quantity</th>
                            <th>Cost Per Unit</th>
                            <th>Total Cost</th>
                            <th>Status</th>
                            <th>Actions</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($printingJobs as $job): ?>
                            <tr>
                                <td><?php echo $job['id']; ?></td>
                                <td><?php echo htmlspecialchars($job['printer_name']); ?></td>
                                <td><?php echo formatDate($job['sent_date']); ?></td>
                                <td><?php echo number_format($job['sent_quantity']); ?></td>
                                <td>
                                    <?php if ($job['received_quantity'] > 0): ?>
                                        <?php echo number_format($job['received_quantity']); ?>
                                        <small class="text-muted d-block">
                                            <?php echo formatDate($job['received_date']); ?>
                                        </small>
                                    <?php else: ?>
                                        <span class="badge bg-warning">Pending</span>
                                    <?php endif; ?>
                                </td>
                                <td><?php echo formatCurrency($job['cost_per_unit']); ?></td>
                                <td><?php echo formatCurrency($job['total_cost']); ?></td>
                                <td>
                                    <span class="badge bg-<?php
                                                            echo ($job['payment_status'] === 'paid') ? 'success' : (($job['payment_status'] === 'partial') ? 'warning' : 'danger');
                                                            ?>">
                                        <?php echo ucfirst($job['payment_status']); ?>
                                    </span>
                                    <?php if ($job['payment_status'] === 'partial' || $job['payment_status'] === 'paid'): ?>
                                        <small class="d-block"><?php echo formatCurrency($job['payment_amount']); ?></small>
                                    <?php endif; ?>
                                </td>
                                <td>
                                    <?php if ($job['received_quantity'] <= 0): ?>
                                        <a href="../production/printing.php?id=<?php echo $job['id']; ?>" class="btn btn-primary btn-sm">
                                            <i class="fas fa-check-circle"></i> Receive
                                        </a>
                                    <?php else: ?>
                                        <a href="../production/printing.php?id=<?php echo $job['id']; ?>" class="btn btn-info btn-sm">
                                            <i class="fas fa-eye"></i> View
                                        </a>
                                    <?php endif; ?>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>
        <?php else: ?>
            <div class="alert alert-warning">
                <i class="fas fa-exclamation-triangle"></i> No printing jobs have been created for this production order yet.
                <?php if ($order['status'] !== 'cancelled' && $order['status'] !== 'completed' && !empty($materials['paper']['allocated'])): ?>
                    <a href="../production/printing.php?order_id=<?php echo $id; ?>" class="btn btn-primary btn-sm ms-3">
                        Add Printing Job
                    </a>
                <?php endif; ?>
            </div>
        <?php endif; ?>
    </div>
</div>

<!-- Binding Jobs -->
<div class="card shadow mb-4">
    <div class="card-header py-3 d-flex justify-content-between align-items-center">
        <h6 class="m-0 font-weight-bold text-primary">Binding Jobs</h6>
        <?php if (!empty($bindingJobs)): ?>
            <span class="badge bg-info"><?php echo formatCurrency($totalBindingCost); ?> Total</span>
        <?php endif; ?>
    </div>
    <div class="card-body">
        <?php if (!empty($bindingJobs)): ?>
            <div class="table-responsive">
                <table class="table table-bordered" width="100%" cellspacing="0">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>Binder</th>
                            <th>Sent Date</th>
                            <th>Sent Quantity</th>
                            <th>Received Quantity</th>
                            <th>Cost Per Unit</th>
                            <th>Total Cost</th>
                            <th>Status</th>
                            <th>Actions</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($bindingJobs as $job): ?>
                            <tr>
                                <td><?php echo $job['id']; ?></td>
                                <td><?php echo htmlspecialchars($job['binder_name']); ?></td>
                                <td><?php echo formatDate($job['sent_date']); ?></td>
                                <td><?php echo number_format($job['sent_quantity']); ?></td>
                                <td>
                                    <?php if ($job['received_quantity'] > 0): ?>
                                        <?php echo number_format($job['received_quantity']); ?>
                                        <small class="text-muted d-block">
                                            <?php echo formatDate($job['received_date']); ?>
                                        </small>
                                    <?php else: ?>
                                        <span class="badge bg-warning">Pending</span>
                                    <?php endif; ?>
                                </td>
                                <td><?php echo formatCurrency($job['cost_per_unit']); ?></td>
                                <td><?php echo formatCurrency($job['total_cost']); ?></td>
                                <td>
                                    <span class="badge bg-<?php
                                                            echo ($job['payment_status'] === 'paid') ? 'success' : (($job['payment_status'] === 'partial') ? 'warning' : 'danger');
                                                            ?>">
                                        <?php echo ucfirst($job['payment_status']); ?>
                                    </span>
                                    <?php if ($job['payment_status'] === 'partial' || $job['payment_status'] === 'paid'): ?>
                                        <small class="d-block"><?php echo formatCurrency($job['payment_amount']); ?></small>
                                    <?php endif; ?>
                                </td>
                                <td>
                                    <?php if ($job['received_quantity'] <= 0): ?>
                                        <a href="../production/binding.php?id=<?php echo $job['id']; ?>" class="btn btn-primary btn-sm">
                                            <i class="fas fa-check-circle"></i> Receive
                                        </a>
                                    <?php else: ?>
                                        <a href="../production/binding.php?id=<?php echo $job['id']; ?>" class="btn btn-info btn-sm">
                                            <i class="fas fa-eye"></i> View
                                        </a>
                                    <?php endif; ?>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>
        <?php else: ?>
            <div class="alert alert-warning">
                <i class="fas fa-exclamation-triangle"></i> No binding jobs have been created for this production order yet.
                <?php if ($order['status'] !== 'cancelled' && $order['status'] !== 'completed' && $totalPrintingReceived > 0): ?>
                    <a href="../production/binding.php?order_id=<?php echo $id; ?>" class="btn btn-primary btn-sm ms-3">
                        Add Binding Job
                    </a>
                <?php endif; ?>
            </div>
        <?php endif; ?>
    </div>
</div>

<!-- Finished Inventory -->
<div class="card shadow mb-4">
    <div class="card-header py-3">
        <h6 class="m-0 font-weight-bold text-primary">Finished Inventory</h6>
    </div>
    <div class="card-body">
        <?php if (!empty($inventory)): ?>
            <div class="table-responsive">
                <table class="table table-bordered" width="100%" cellspacing="0">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>Receipt Date</th>
                            <th>Quantity</th>
                            <th>Production Cost/Unit</th>
                            <th>Total Cost</th>
                            <th>Binding Job</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($inventory as $item): ?>
                            <tr>
                                <td><?php echo $item['id']; ?></td>
                                <td><?php echo formatDate($item['receipt_date']); ?></td>
                                <td><?php echo number_format($item['quantity']); ?></td>
                                <td><?php echo formatCurrency($item['production_cost_per_unit']); ?></td>
                                <td><?php echo formatCurrency($item['production_cost_per_unit'] * $item['quantity']); ?></td>
                                <td>
                                    <a href="../production/binding.php?id=<?php echo $item['binding_job_id']; ?>" class="btn btn-info btn-sm">
                                        #<?php echo $item['binding_job_id']; ?>
                                    </a>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>

            <div class="alert alert-info mt-3">
                <i class="fas fa-info-circle"></i> These books are now in finished inventory and available for sale.
                <a href="../books/inventory.php?book_id=<?php echo $order['book_id']; ?>" class="btn btn-primary btn-sm ms-3">
                    View Complete Inventory
                </a>
            </div>
        <?php else: ?>
            <div class="alert alert-warning">
                <i class="fas fa-exclamation-triangle"></i> No finished books from this production order are in inventory yet.
            </div>
        <?php endif; ?>
    </div>
</div>

<!-- Charts.js Script -->
<script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
<script>
    // Cost Breakdown Chart
    const ctx = document.getElementById('costBreakdownChart').getContext('2d');
    const costBreakdownChart = new Chart(ctx, {
        type: 'pie',
        data: {
            labels: ['Paper', 'Cover', 'Half Title', 'Printing', 'Binding'],
            datasets: [{
                data: [
                    <?php echo $materials['paper']['cost']; ?>,
                    <?php echo $materials['cover']['cost']; ?>,
                    <?php echo $materials['half_title']['cost']; ?>,
                    <?php echo $totalPrintingCost; ?>,
                    <?php echo $totalBindingCost; ?>
                ],
                backgroundColor: [
                    'rgba(255, 99, 132, 0.8)',
                    'rgba(54, 162, 235, 0.8)',
                    'rgba(255, 206, 86, 0.8)',
                    'rgba(75, 192, 192, 0.8)',
                    'rgba(153, 102, 255, 0.8)'
                ],
                borderWidth: 1
            }]
        },
        options: {
            responsive: true,
            maintainAspectRatio: false,
            plugins: {
                legend: {
                    position: 'bottom'
                },
                tooltip: {
                    callbacks: {
                        label: function(context) {
                            const label = context.label || '';
                            const value = context.raw || 0;
                            const total = <?php echo $totalProductionCost > 0 ? $totalProductionCost : 1; ?>;
                            const percentage = ((value / total) * 100).toFixed(1);
                            return `${label}: ${formatCurrency(value)} (${percentage}%)`;
                        }
                    }
                }
            }
        }
    });

    // Helper function to format currency
    function formatCurrency(amount) {
        return '₹ ' + amount.toLocaleString('en-IN', {
            minimumFractionDigits: 2,
            maximumFractionDigits: 2
        });
    }
</script>

<?php require_once '../includes/footer.php'; ?>