<?php

/**
 * User Profile Page
 * Allows users to view and update their profile information
 */
require_once 'includes/header.php';

// Get current user info
$userId = $_SESSION['user_id'];
$userSql = "SELECT * FROM users WHERE id = $userId";
$userResult = executeQuery($conn, $userSql);
$user = $userResult->fetch_assoc();

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $fullName = sanitizeInput($conn, $_POST['full_name']);
    $email = sanitizeInput($conn, $_POST['email']);

    // Validate input
    $errors = [];

    if (empty($fullName)) {
        $errors[] = 'Full name is required.';
    }

    if (empty($email)) {
        $errors[] = 'Email is required.';
    } elseif (!filter_var($email, FILTER_VALIDATE_EMAIL)) {
        $errors[] = 'Please enter a valid email address.';
    }

    // Check if email is already in use by another user
    $checkSql = "SELECT COUNT(*) AS count FROM users WHERE email = '$email' AND id != $userId";
    $checkResult = executeQuery($conn, $checkSql);
    $check = $checkResult->fetch_assoc();

    if ($check['count'] > 0) {
        $errors[] = 'This email is already in use by another user.';
    }

    // If no errors, update user profile
    if (empty($errors)) {
        $updateSql = "UPDATE users SET 
                     full_name = '$fullName', 
                     email = '$email' 
                     WHERE id = $userId";

        if (executeQuery($conn, $updateSql)) {
            // Update session variable
            $_SESSION['user_name'] = $fullName;

            logActivity('update_profile', 'Updated profile information');
            setFlashMessage('Profile updated successfully.', 'success');
            redirect('profile.php');
        } else {
            $errors[] = 'Error updating profile. Please try again.';
        }
    }
}
?>

<div class="d-flex justify-content-between align-items-center mb-4">
    <h1>My Profile</h1>
    <a href="change_password.php" class="btn btn-warning">
        <i class="fas fa-key"></i> Change Password
    </a>
</div>

<?php if (!empty($errors)): ?>
    <div class="alert alert-danger">
        <ul class="mb-0">
            <?php foreach ($errors as $error): ?>
                <li><?php echo $error; ?></li>
            <?php endforeach; ?>
        </ul>
    </div>
<?php endif; ?>

<div class="row">
    <div class="col-md-6">
        <div class="card shadow mb-4">
            <div class="card-header py-3">
                <h6 class="m-0 font-weight-bold text-primary">Personal Information</h6>
            </div>
            <div class="card-body">
                <form method="post" action="">
                    <div class="mb-3">
                        <label for="username" class="form-label">Username</label>
                        <input type="text" class="form-control" id="username" value="<?php echo htmlspecialchars($user['username']); ?>" disabled>
                        <small class="text-muted">Username cannot be changed</small>
                    </div>

                    <div class="mb-3">
                        <label for="full_name" class="form-label">Full Name *</label>
                        <input type="text" class="form-control" id="full_name" name="full_name" value="<?php echo htmlspecialchars($user['full_name']); ?>" required>
                    </div>

                    <div class="mb-3">
                        <label for="email" class="form-label">Email Address *</label>
                        <input type="email" class="form-control" id="email" name="email" value="<?php echo htmlspecialchars($user['email']); ?>" required>
                    </div>

                    <div class="mb-3">
                        <label for="role" class="form-label">Role</label>
                        <input type="text" class="form-control" id="role" value="<?php echo ucfirst($user['role']); ?>" disabled>
                        <small class="text-muted">Role can only be changed by an administrator</small>
                    </div>

                    <div class="mb-3">
                        <label for="last_login" class="form-label">Last Login</label>
                        <input type="text" class="form-control" id="last_login" value="<?php echo $user['last_login'] ? formatDate($user['last_login'], 'Y-m-d H:i:s') : 'N/A'; ?>" disabled>
                    </div>

                    <div class="d-grid gap-2 d-md-flex justify-content-md-end">
                        <button type="submit" class="btn btn-primary">Update Profile</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <div class="col-md-6">
        <div class="card shadow mb-4">
            <div class="card-header py-3">
                <h6 class="m-0 font-weight-bold text-primary">Account Security</h6>
            </div>
            <div class="card-body">
                <p>Your account security is important. Here are some tips to keep your account secure:</p>

                <ul>
                    <li>Use a strong, unique password that includes letters, numbers, and special characters.</li>
                    <li>Never share your login credentials with others.</li>
                    <li>Change your password regularly.</li>
                    <li>Log out when you're done using the system, especially on shared computers.</li>
                </ul>

                <div class="d-grid gap-2">
                    <a href="change_password.php" class="btn btn-warning">
                        <i class="fas fa-key"></i> Change Password
                    </a>
                </div>
            </div>
        </div>

        <div class="card shadow mb-4">
            <div class="card-header py-3">
                <h6 class="m-0 font-weight-bold text-primary">Recent Activity</h6>
            </div>
            <div class="card-body">
                <?php
                // Get recent activity logs for this user
                $logsSql = "SELECT * FROM activity_log WHERE user_id = $userId ORDER BY created_at DESC LIMIT 5";
                $logsResult = executeQuery($conn, $logsSql);
                ?>

                <?php if ($logsResult && $logsResult->num_rows > 0): ?>
                    <ul class="list-group">
                        <?php while ($log = $logsResult->fetch_assoc()): ?>
                            <li class="list-group-item">
                                <small class="text-muted"><?php echo formatDate($log['created_at'], 'Y-m-d H:i:s'); ?></small><br>
                                <strong><?php echo ucfirst(str_replace('_', ' ', $log['action'])); ?></strong>
                                <?php if (!empty($log['description'])): ?>
                                    <p class="mb-0"><?php echo htmlspecialchars($log['description']); ?></p>
                                <?php endif; ?>
                            </li>
                        <?php endwhile; ?>
                    </ul>
                <?php else: ?>
                    <p class="text-muted">No recent activity found.</p>
                <?php endif; ?>
            </div>
        </div>
    </div>
</div>

<?php require_once 'includes/footer.php'; ?>