<?php

/**
 * Add New Customer Page
 * Allows adding new customers to the system
 */
require_once '../includes/header.php';

// Initialize variables
$name = '';
$contactPerson = '';
$phone = '';
$email = '';
$address = '';
$customerType = '';
$notes = '';

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Sanitize input
    $name = sanitizeInput($conn, $_POST['name']);
    $contactPerson = sanitizeInput($conn, $_POST['contact_person']);
    $phone = sanitizeInput($conn, $_POST['phone']);
    $email = sanitizeInput($conn, $_POST['email']);
    $address = sanitizeInput($conn, $_POST['address']);
    $customerType = sanitizeInput($conn, $_POST['customer_type']);
    $notes = sanitizeInput($conn, $_POST['notes']);

    // Validate input
    $errors = [];

    if (empty($name)) {
        $errors[] = 'Customer name is required.';
    }

    if (empty($customerType)) {
        $errors[] = 'Customer type is required.';
    }

    if (!empty($email) && !filter_var($email, FILTER_VALIDATE_EMAIL)) {
        $errors[] = 'Please enter a valid email address.';
    }

    // If no errors, insert data
    if (empty($errors)) {
        $sql = "INSERT INTO customers (
                    name, 
                    contact_person, 
                    phone, 
                    email, 
                    address, 
                    customer_type, 
                    notes
                ) VALUES (
                    '$name', 
                    " . (!empty($contactPerson) ? "'$contactPerson'" : "NULL") . ", 
                    " . (!empty($phone) ? "'$phone'" : "NULL") . ", 
                    " . (!empty($email) ? "'$email'" : "NULL") . ", 
                    " . (!empty($address) ? "'$address'" : "NULL") . ", 
                    '$customerType', 
                    " . (!empty($notes) ? "'$notes'" : "NULL") . "
                )";

        if (executeQuery($conn, $sql)) {
            $customerId = $conn->insert_id;

            logActivity('add_customer', "Added new $customerType customer: $name");

            // Check if there's a redirect to add order
            if (isset($_POST['add_order']) && $_POST['add_order'] === '1') {
                setFlashMessage('Customer added successfully. You can now create an order for this customer.', 'success');
                redirect('sales/add_order.php?customer_id=' . $customerId);
            } else {
                setFlashMessage('Customer added successfully.', 'success');
                redirect('sales/customers.php');
            }
        } else {
            $errors[] = 'Error adding customer. Please try again.';
        }
    }
}
?>

<div class="d-flex justify-content-between align-items-center mb-4">
    <h1>Add New Customer</h1>
    <a href="customers.php" class="btn btn-secondary">
        <i class="fas fa-arrow-left"></i> Back to Customers
    </a>
</div>

<?php if (!empty($errors)): ?>
    <div class="alert alert-danger">
        <ul class="mb-0">
            <?php foreach ($errors as $error): ?>
                <li><?php echo $error; ?></li>
            <?php endforeach; ?>
        </ul>
    </div>
<?php endif; ?>

<div class="card shadow mb-4">
    <div class="card-header py-3">
        <h6 class="m-0 font-weight-bold text-primary">Customer Details</h6>
    </div>
    <div class="card-body">
        <form method="post" action="">
            <div class="row mb-3">
                <div class="col-md-6">
                    <label for="name" class="form-label">Customer Name *</label>
                    <input type="text" class="form-control" id="name" name="name" value="<?php echo htmlspecialchars($name); ?>" required>
                    <small class="text-muted">Company name or individual's full name</small>
                </div>
                <div class="col-md-6">
                    <label for="customer_type" class="form-label">Customer Type *</label>
                    <select name="customer_type" id="customer_type" class="form-select" required>
                        <option value="">Select Customer Type</option>
                        <option value="wholesale" <?php echo ($customerType === 'wholesale') ? 'selected' : ''; ?>>Wholesale</option>
                        <option value="retail" <?php echo ($customerType === 'retail') ? 'selected' : ''; ?>>Retail</option>
                    </select>
                    <small class="text-muted">Determines pricing for sales</small>
                </div>
            </div>

            <div class="row mb-3">
                <div class="col-md-6">
                    <label for="contact_person" class="form-label">Contact Person</label>
                    <input type="text" class="form-control" id="contact_person" name="contact_person" value="<?php echo htmlspecialchars($contactPerson); ?>">
                    <small class="text-muted">Primary contact person for wholesale customers</small>
                </div>
                <div class="col-md-6">
                    <label for="phone" class="form-label">Phone Number</label>
                    <input type="text" class="form-control" id="phone" name="phone" value="<?php echo htmlspecialchars($phone); ?>">
                </div>
            </div>

            <div class="row mb-3">
                <div class="col-md-6">
                    <label for="email" class="form-label">Email Address</label>
                    <input type="email" class="form-control" id="email" name="email" value="<?php echo htmlspecialchars($email); ?>">
                </div>
                <div class="col-md-6">
                    <label for="address" class="form-label">Address</label>
                    <textarea class="form-control" id="address" name="address" rows="2"><?php echo htmlspecialchars($address); ?></textarea>
                </div>
            </div>

            <div class="mb-3">
                <label for="notes" class="form-label">Notes</label>
                <textarea class="form-control" id="notes" name="notes" rows="3"><?php echo htmlspecialchars($notes); ?></textarea>
                <small class="text-muted">Any additional information about this customer</small>
            </div>

            <div class="form-check mb-3">
                <input class="form-check-input" type="checkbox" id="add_order" name="add_order" value="1">
                <label class="form-check-label" for="add_order">
                    Create a sales order for this customer after adding
                </label>
            </div>

            <div class="d-grid gap-2 d-md-flex justify-content-md-end">
                <button type="reset" class="btn btn-secondary me-md-2">Reset</button>
                <button type="submit" class="btn btn-primary">Add Customer</button>
            </div>
        </form>
    </div>
</div>

<!-- Customer Type Information -->
<div class="card shadow mb-4">
    <div class="card-header py-3">
        <h6 class="m-0 font-weight-bold text-primary">Customer Type Information</h6>
    </div>
    <div class="card-body">
        <div class="row">
            <div class="col-md-6">
                <div class="card h-100">
                    <div class="card-header bg-info text-white">
                        Wholesale Customers
                    </div>
                    <div class="card-body">
                        <p>Wholesale customers are typically businesses that purchase books in bulk for resale. They receive:</p>
                        <ul>
                            <li>Lower price per book</li>
                            <li>Minimum order quantities may apply</li>
                            <li>May have special payment terms</li>
                            <li>Business-to-business relationship</li>
                        </ul>
                        <p class="mb-0">When creating sales orders for wholesale customers, the system will automatically apply wholesale pricing.</p>
                    </div>
                </div>
            </div>
            <div class="col-md-6">
                <div class="card h-100">
                    <div class="card-header bg-success text-white">
                        Retail Customers
                    </div>
                    <div class="card-body">
                        <p>Retail customers are typically individuals or small organizations purchasing for their own use. They receive:</p>
                        <ul>
                            <li>Standard retail pricing</li>
                            <li>No minimum order quantities</li>
                            <li>Standard payment terms</li>
                            <li>Business-to-consumer relationship</li>
                        </ul>
                        <p class="mb-0">When creating sales orders for retail customers, the system will automatically apply retail pricing.</p>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<?php require_once '../includes/footer.php'; ?>