<?php

/**
 * Add New Sales Order Page
 * Allows creating new sales orders
 */
require_once '../includes/header.php';

// Get customer ID if provided
$customerId = isset($_GET['customer_id']) ? (int)$_GET['customer_id'] : 0;
$bookId = isset($_GET['book_id']) ? (int)$_GET['book_id'] : 0;

// Get customer data if ID is provided
$customerData = null;
if ($customerId > 0) {
    $customerSql = "SELECT * FROM customers WHERE id = $customerId";
    $customerResult = executeQuery($conn, $customerSql);

    if ($customerResult && $customerResult->num_rows > 0) {
        $customerData = $customerResult->fetch_assoc();
    }
}

// Get active books
$booksSql = "SELECT id, title, author, wholesale_price, retail_price FROM books WHERE active = 1 ORDER BY title";
$booksResult = executeQuery($conn, $booksSql);
$books = [];

if ($booksResult && $booksResult->num_rows > 0) {
    while ($book = $booksResult->fetch_assoc()) {
        $books[$book['id']] = $book;
    }
}

// Get all customers for dropdown
$customersSql = "SELECT id, name, customer_type, address, phone FROM customers ORDER BY name";
$customersResult = executeQuery($conn, $customersSql);
$customers = [];

if ($customersResult && $customersResult->num_rows > 0) {
    while ($customer = $customersResult->fetch_assoc()) {
        $customers[$customer['id']] = $customer;
    }
}

// Get finished inventory quantities for each book
$inventorySql = "SELECT book_id, SUM(quantity) AS available_quantity FROM finished_inventory GROUP BY book_id";
$inventoryResult = executeQuery($conn, $inventorySql);
$inventory = [];

if ($inventoryResult && $inventoryResult->num_rows > 0) {
    while ($item = $inventoryResult->fetch_assoc()) {
        $inventory[$item['book_id']] = $item['available_quantity'];
    }
}

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Start transaction
    $conn->begin_transaction();

    try {
        // Sanitize input
        $orderCustomerId = (int)$_POST['customer_id'];
        $orderDate = sanitizeInput($conn, $_POST['order_date']);
        $notes = sanitizeInput($conn, $_POST['notes']);

        // Get customer type (wholesale or retail)
        $customerTypeSql = "SELECT customer_type FROM customers WHERE id = $orderCustomerId";
        $customerTypeResult = executeQuery($conn, $customerTypeSql);
        $customerType = $customerTypeResult->fetch_assoc()['customer_type'];

        // Process order items
        $orderItems = [];
        $totalAmount = 0;

        foreach ($_POST['book_id'] as $key => $id) {
            $bookId = (int)$id;
            $quantity = (int)$_POST['quantity'][$key];

            if ($bookId > 0 && $quantity > 0) {
                // Get book data and apply correct price based on customer type
                $bookSql = "SELECT title, wholesale_price, retail_price FROM books WHERE id = $bookId";
                $bookResult = executeQuery($conn, $bookSql);
                $book = $bookResult->fetch_assoc();

                $unitPrice = ($customerType === 'wholesale') ? $book['wholesale_price'] : $book['retail_price'];
                $totalPrice = $unitPrice * $quantity;

                $orderItems[] = [
                    'book_id' => $bookId,
                    'quantity' => $quantity,
                    'unit_price' => $unitPrice,
                    'total_price' => $totalPrice
                ];

                $totalAmount += $totalPrice;

                // Check inventory
                $availableQuantity = $inventory[$bookId] ?? 0;
                if ($quantity > $availableQuantity) {
                    throw new Exception("Insufficient inventory for book: " . $book['title'] . ". Available: " . $availableQuantity);
                }
            }
        }

        if (empty($orderItems)) {
            throw new Exception("Please add at least one book to the order.");
        }

        // Create sales order
        $orderSql = "INSERT INTO sales_orders (
                        customer_id, 
                        order_date, 
                        total_amount, 
                        paid_amount, 
                        payment_status, 
                        notes
                    ) VALUES (
                        $orderCustomerId, 
                        '$orderDate', 
                        $totalAmount, 
                        0, 
                        'pending', 
                        " . (!empty($notes) ? "'$notes'" : "NULL") . "
                    )";

        executeQuery($conn, $orderSql);
        $orderId = $conn->insert_id;

        // Add order items
        foreach ($orderItems as $item) {
            $itemSql = "INSERT INTO sales_order_items (
                            sales_order_id, 
                            book_id, 
                            quantity, 
                            unit_price, 
                            total_price
                        ) VALUES (
                            $orderId, 
                            " . $item['book_id'] . ", 
                            " . $item['quantity'] . ", 
                            " . $item['unit_price'] . ", 
                            " . $item['total_price'] . "
                        )";

            executeQuery($conn, $itemSql);

            // Update inventory
            $updateInventorySql = "UPDATE finished_inventory 
                                 SET quantity = quantity - " . $item['quantity'] . " 
                                 WHERE book_id = " . $item['book_id'] . " 
                                 ORDER BY id ASC 
                                 LIMIT 1";
            executeQuery($conn, $updateInventorySql);
        }

        // Commit transaction
        $conn->commit();

        logActivity('add_order', "Created sales order #$orderId for customer #$orderCustomerId, total: $totalAmount");

        // Check if payment should be added immediately
        if (isset($_POST['add_payment']) && $_POST['add_payment'] === '1') {
            setFlashMessage('Sales order created successfully. You can now add a payment.', 'success');
            redirect('sales/payments.php?order_id=' . $orderId);
        } else {
            setFlashMessage('Sales order created successfully.', 'success');
            redirect('sales/orders.php');
        }
    } catch (Exception $e) {
        // Rollback on error
        $conn->rollback();
        $error = $e->getMessage();
    }
}
?>

<div class="d-flex justify-content-between align-items-center mb-4">
    <h1>Create New Sales Order</h1>
    <a href="orders.php" class="btn btn-secondary">
        <i class="fas fa-arrow-left"></i> Back to Orders
    </a>
</div>

<?php if (isset($error)): ?>
    <div class="alert alert-danger">
        <i class="fas fa-exclamation-circle"></i> <?php echo $error; ?>
    </div>
<?php endif; ?>

<?php if (empty($books)): ?>
    <div class="alert alert-warning">
        <i class="fas fa-exclamation-triangle"></i> There are no active books in the catalog. Please add books before creating sales orders.
        <a href="../books/add.php" class="btn btn-primary btn-sm ms-3">Add Book</a>
    </div>
<?php elseif (empty($customers)): ?>
    <div class="alert alert-warning">
        <i class="fas fa-exclamation-triangle"></i> There are no customers in the system. Please add a customer before creating sales orders.
        <a href="add_customer.php" class="btn btn-primary btn-sm ms-3">Add Customer</a>
    </div>
<?php else: ?>

    <form method="post" action="" id="orderForm">
        <div class="row">
            <!-- Order Information -->
            <div class="col-md-4">
                <div class="card shadow mb-4">
                    <div class="card-header py-3">
                        <h6 class="m-0 font-weight-bold text-primary">Order Information</h6>
                    </div>
                    <div class="card-body">
                        <div class="mb-3">
                            <label for="customer_id" class="form-label">Customer *</label>
                            <select name="customer_id" id="customer_id" class="form-select" required onchange="updateCustomerInfo()">
                                <option value="">Select Customer</option>
                                <?php foreach ($customers as $id => $customer): ?>
                                    <option value="<?php echo $id; ?>"
                                        data-type="<?php echo $customer['customer_type']; ?>"
                                        data-address="<?php echo htmlspecialchars($customer['address'] ?? ''); ?>"
                                        data-phone="<?php echo htmlspecialchars($customer['phone'] ?? ''); ?>"
                                        <?php echo ($customerId == $id) ? 'selected' : ''; ?>>
                                        <?php echo htmlspecialchars($customer['name']); ?>
                                        (<?php echo ucfirst($customer['customer_type']); ?>)
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="mb-3">
                            <label for="order_date" class="form-label">Order Date *</label>
                            <input type="date" class="form-control" id="order_date" name="order_date" value="<?php echo date('Y-m-d'); ?>" required>
                        </div>

                        <div class="mb-3">
                            <label for="notes" class="form-label">Notes</label>
                            <textarea class="form-control" id="notes" name="notes" rows="3"></textarea>
                        </div>

                        <div class="form-check mb-3">
                            <input class="form-check-input" type="checkbox" id="add_payment" name="add_payment" value="1">
                            <label class="form-check-label" for="add_payment">
                                Add payment after creating order
                            </label>
                        </div>
                    </div>
                </div>

                <!-- Customer Information -->
                <div class="card shadow mb-4">
                    <div class="card-header py-3">
                        <h6 class="m-0 font-weight-bold text-primary">Customer Information</h6>
                    </div>
                    <div class="card-body">
                        <div id="customerInfo">
                            <?php if ($customerData): ?>
                                <p><strong>Name:</strong> <?php echo htmlspecialchars($customerData['name']); ?></p>
                                <p><strong>Type:</strong> <?php echo ucfirst($customerData['customer_type']); ?></p>
                                <?php if (!empty($customerData['phone'])): ?>
                                    <p><strong>Phone:</strong> <?php echo htmlspecialchars($customerData['phone']); ?></p>
                                <?php endif; ?>
                                <?php if (!empty($customerData['address'])): ?>
                                    <p><strong>Address:</strong> <?php echo htmlspecialchars($customerData['address']); ?></p>
                                <?php endif; ?>
                                <div class="alert alert-info">
                                    <i class="fas fa-info-circle"></i>
                                    <?php echo ucfirst($customerData['customer_type']); ?> pricing will be applied.
                                </div>
                            <?php else: ?>
                                <p class="text-muted">Select a customer to see details</p>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
            </div>

            <!-- Order Items -->
            <div class="col-md-8">
                <div class="card shadow mb-4">
                    <div class="card-header py-3 d-flex justify-content-between align-items-center">
                        <h6 class="m-0 font-weight-bold text-primary">Order Items</h6>
                        <button type="button" class="btn btn-success btn-sm" onclick="addItem()">
                            <i class="fas fa-plus"></i> Add Book
                        </button>
                    </div>
                    <div class="card-body">
                        <div class="table-responsive">
                            <table class="table table-bordered">
                                <thead>
                                    <tr>
                                        <th>Book</th>
                                        <th width="100">Quantity</th>
                                        <th width="150">Unit Price</th>
                                        <th width="150">Total</th>
                                        <th width="50">Action</th>
                                    </tr>
                                </thead>
                                <tbody id="orderItems">
                                    <tr id="itemRow0" class="item-row">
                                        <td>
                                            <select name="book_id[]" class="form-select book-select" required onchange="updatePrice(this)">
                                                <option value="">Select Book</option>
                                                <?php foreach ($books as $id => $book):
                                                    $availableQty = $inventory[$id] ?? 0;
                                                    $isDisabled = $availableQty <= 0;
                                                ?>
                                                    <option value="<?php echo $id; ?>"
                                                        data-wholesale-price="<?php echo $book['wholesale_price']; ?>"
                                                        data-retail-price="<?php echo $book['retail_price']; ?>"
                                                        data-available="<?php echo $availableQty; ?>"
                                                        <?php echo ($bookId == $id) ? 'selected' : ''; ?>
                                                        <?php echo $isDisabled ? 'disabled' : ''; ?>>
                                                        <?php echo htmlspecialchars($book['title']); ?>
                                                        <?php echo $isDisabled ? '(Out of Stock)' : '(Available: ' . $availableQty . ')'; ?>
                                                    </option>
                                                <?php endforeach; ?>
                                            </select>
                                        </td>
                                        <td>
                                            <input type="number" name="quantity[]" class="form-control item-quantity" value="1" min="1" required onchange="updateRowTotal(this)">
                                        </td>
                                        <td>
                                            <div class="input-group">
                                                <span class="input-group-text">₹</span>
                                                <input type="number" name="unit_price[]" class="form-control item-price" step="0.01" readonly>
                                            </div>
                                        </td>
                                        <td>
                                            <div class="input-group">
                                                <span class="input-group-text">₹</span>
                                                <input type="text" class="form-control item-total" readonly>
                                            </div>
                                        </td>
                                        <td>
                                            <button type="button" class="btn btn-danger btn-sm" onclick="removeItem(this)">
                                                <i class="fas fa-trash"></i>
                                            </button>
                                        </td>
                                    </tr>
                                </tbody>
                                <tfoot>
                                    <tr>
                                        <th colspan="3" class="text-end">Grand Total:</th>
                                        <th colspan="2">
                                            <div class="input-group">
                                                <span class="input-group-text">₹</span>
                                                <input type="text" id="grandTotal" class="form-control" readonly>
                                                <input type="hidden" name="total_amount" id="totalAmount">
                                            </div>
                                        </th>
                                    </tr>
                                </tfoot>
                            </table>
                        </div>

                        <div class="d-grid gap-2 d-md-flex justify-content-md-end mt-3">
                            <button type="reset" class="btn btn-secondary me-md-2">Reset</button>
                            <button type="submit" class="btn btn-primary">Create Order</button>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </form>

    <script>
        let itemCount = 1; // Start with 1 since we already have item 0

        /**
         * Update customer information when customer is selected
         */
        function updateCustomerInfo() {
            const customerSelect = document.getElementById('customer_id');
            const customerInfo = document.getElementById('customerInfo');

            if (customerSelect.value === '') {
                customerInfo.innerHTML = '<p class="text-muted">Select a customer to see details</p>';
                return;
            }

            const selectedOption = customerSelect.options[customerSelect.selectedIndex];
            const customerType = selectedOption.getAttribute('data-type');
            const customerAddress = selectedOption.getAttribute('data-address');
            const customerPhone = selectedOption.getAttribute('data-phone');
            const customerName = selectedOption.text.split(' (')[0];

            let html = `
            <p><strong>Name:</strong> ${customerName}</p>
            <p><strong>Type:</strong> ${customerType.charAt(0).toUpperCase() + customerType.slice(1)}</p>
        `;

            if (customerPhone) {
                html += `<p><strong>Phone:</strong> ${customerPhone}</p>`;
            }

            if (customerAddress) {
                html += `<p><strong>Address:</strong> ${customerAddress}</p>`;
            }

            html += `
            <div class="alert alert-info">
                <i class="fas fa-info-circle"></i> 
                ${customerType.charAt(0).toUpperCase() + customerType.slice(1)} pricing will be applied.
            </div>
        `;

            customerInfo.innerHTML = html;

            // Update all prices based on customer type
            const bookSelects = document.querySelectorAll('.book-select');
            bookSelects.forEach(select => {
                updatePrice(select);
            });
        }

        /**
         * Update the price based on book selection and customer type
         */
        function updatePrice(select) {
            const row = select.closest('tr');
            const priceInput = row.querySelector('.item-price');
            const quantityInput = row.querySelector('.item-quantity');

            if (select.value === '') {
                priceInput.value = '';
                updateRowTotal(quantityInput);
                return;
            }

            const selectedOption = select.options[select.selectedIndex];
            const customerSelect = document.getElementById('customer_id');

            if (customerSelect.value === '') {
                alert('Please select a customer first.');
                select.value = '';
                return;
            }

            const customerType = customerSelect.options[customerSelect.selectedIndex].getAttribute('data-type');
            const wholesalePrice = selectedOption.getAttribute('data-wholesale-price');
            const retailPrice = selectedOption.getAttribute('data-retail-price');

            priceInput.value = (customerType === 'wholesale') ? wholesalePrice : retailPrice;

            // Check available quantity
            const availableQty = parseInt(selectedOption.getAttribute('data-available'));
            quantityInput.max = availableQty;

            // If quantity exceeds available, adjust it
            if (parseInt(quantityInput.value) > availableQty) {
                quantityInput.value = availableQty;
            }

            updateRowTotal(quantityInput);
        }

        /**
         * Update the total for a row
         */
        function updateRowTotal(input) {
            const row = input.closest('tr');
            const quantity = parseFloat(row.querySelector('.item-quantity').value) || 0;
            const price = parseFloat(row.querySelector('.item-price').value) || 0;
            const totalInput = row.querySelector('.item-total');

            const total = quantity * price;
            totalInput.value = total.toFixed(2);

            updateGrandTotal();
        }

        /**
         * Update the grand total
         */
        function updateGrandTotal() {
            let grandTotal = 0;
            const totalInputs = document.querySelectorAll('.item-total');

            totalInputs.forEach(input => {
                grandTotal += parseFloat(input.value) || 0;
            });

            document.getElementById('grandTotal').value = grandTotal.toFixed(2);
            document.getElementById('totalAmount').value = grandTotal.toFixed(2);
        }

        /**
         * Add a new item row
         */
        function addItem() {
            const itemsContainer = document.getElementById('orderItems');
            const template = document.getElementById('itemRow0').cloneNode(true);

            template.id = 'itemRow' + itemCount;

            // Clear values
            const selects = template.querySelectorAll('select');
            const inputs = template.querySelectorAll('input');

            selects.forEach(select => {
                select.value = '';
            });

            inputs.forEach(input => {
                if (input.type !== 'hidden' && !input.classList.contains('item-quantity')) {
                    input.value = '';
                }
            });

            // Reset quantity to 1
            const quantityInput = template.querySelector('.item-quantity');
            quantityInput.value = 1;

            // Add event listeners
            template.querySelector('.book-select').onchange = function() {
                updatePrice(this);
            };
            template.querySelector('.item-quantity').onchange = function() {
                updateRowTotal(this);
            };

            itemsContainer.appendChild(template);
            itemCount++;
        }

        /**
         * Remove an item row
         */
        function removeItem(button) {
            const row = button.closest('tr');

            // Don't remove if it's the only row
            if (document.querySelectorAll('.item-row').length === 1) {
                alert('At least one item is required.');
                return;
            }

            row.remove();
            updateGrandTotal();
        }

        // Initialize on page load
        document.addEventListener('DOMContentLoaded', function() {
            const customerSelect = document.getElementById('customer_id');
            if (customerSelect.value !== '') {
                updateCustomerInfo();
            }

            const bookSelects = document.querySelectorAll('.book-select');
            bookSelects.forEach(select => {
                if (select.value !== '') {
                    updatePrice(select);
                }
            });
        });
    </script>

<?php endif; ?>

<?php require_once '../includes/footer.php'; ?>