<?php

/**
 * Customers Page
 * Manages customers for sales
 */
require_once '../includes/header.php';

// Handle delete request
if (isset($_GET['delete']) && !empty($_GET['delete'])) {
    $id = (int)$_GET['delete'];

    // Check if customer can be deleted (not used in sales)
    $checkSql = "SELECT COUNT(*) AS count FROM sales_orders WHERE customer_id = $id";
    $checkResult = executeQuery($conn, $checkSql);
    $row = $checkResult->fetch_assoc();

    if ($row['count'] > 0) {
        setFlashMessage('Cannot delete customer as they have associated sales orders.', 'danger');
    } else {
        $deleteSql = "DELETE FROM customers WHERE id = $id";
        if (executeQuery($conn, $deleteSql)) {
            setFlashMessage('Customer deleted successfully.', 'success');
            logActivity('delete_customer', "Deleted customer ID: $id");
        } else {
            setFlashMessage('Error deleting customer.', 'danger');
        }
    }
    redirect('sales/customers.php');
}

// Get filter parameters
$customerType = isset($_GET['type']) ? sanitizeInput($conn, $_GET['type']) : '';
$searchTerm = isset($_GET['search']) ? sanitizeInput($conn, $_GET['search']) : '';

// Build query with filters
$sql = "SELECT * FROM customers WHERE 1=1";

if (!empty($customerType)) {
    $sql .= " AND customer_type = '$customerType'";
}

if (!empty($searchTerm)) {
    $sql .= " AND (name LIKE '%$searchTerm%' OR contact_person LIKE '%$searchTerm%' OR phone LIKE '%$searchTerm%' OR email LIKE '%$searchTerm%' OR address LIKE '%$searchTerm%')";
}

$sql .= " ORDER BY name";

$result = executeQuery($conn, $sql);

// Get customer type counts
$countSql = "SELECT customer_type, COUNT(*) AS count FROM customers GROUP BY customer_type";
$countResult = executeQuery($conn, $countSql);
$typeCounts = [
    'wholesale' => 0,
    'retail' => 0
];

if ($countResult && $countResult->num_rows > 0) {
    while ($count = $countResult->fetch_assoc()) {
        $typeCounts[$count['customer_type']] = $count['count'];
    }
}
$totalCustomers = $typeCounts['wholesale'] + $typeCounts['retail'];

// Get sales statistics
$salesSql = "SELECT 
             c.id, 
             c.customer_type,
             COUNT(so.id) AS order_count, 
             SUM(so.total_amount) AS total_sales, 
             SUM(so.paid_amount) AS total_paid,
             MAX(so.order_date) AS last_order_date
             FROM customers c
             LEFT JOIN sales_orders so ON c.id = so.customer_id
             GROUP BY c.id, c.customer_type";
$salesResult = executeQuery($conn, $salesSql);
$salesStats = [];

if ($salesResult && $salesResult->num_rows > 0) {
    while ($stat = $salesResult->fetch_assoc()) {
        $salesStats[$stat['id']] = $stat;
    }
}
?>

<div class="d-flex justify-content-between align-items-center mb-4">
    <h1>Customers Management</h1>
    <a href="add_customer.php" class="btn btn-primary">
        <i class="fas fa-user-plus"></i> Add New Customer
    </a>
</div>

<!-- Customer Stats Cards -->
<div class="row mb-4">
    <!-- Total Customers -->
    <div class="col-xl-4 col-md-6 mb-4">
        <div class="card border-left-primary shadow h-100 py-2">
            <div class="card-body">
                <div class="row no-gutters align-items-center">
                    <div class="col mr-2">
                        <div class="text-xs font-weight-bold text-primary text-uppercase mb-1">
                            Total Customers</div>
                        <div class="h5 mb-0 font-weight-bold text-gray-800">
                            <?php echo number_format($totalCustomers); ?>
                        </div>
                    </div>
                    <div class="col-auto">
                        <i class="fas fa-users fa-2x text-gray-300"></i>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <!-- Wholesale Customers -->
    <div class="col-xl-4 col-md-6 mb-4">
        <div class="card border-left-info shadow h-100 py-2">
            <div class="card-body">
                <div class="row no-gutters align-items-center">
                    <div class="col mr-2">
                        <div class="text-xs font-weight-bold text-info text-uppercase mb-1">
                            Wholesale Customers</div>
                        <div class="h5 mb-0 font-weight-bold text-gray-800">
                            <?php echo number_format($typeCounts['wholesale']); ?>
                        </div>
                    </div>
                    <div class="col-auto">
                        <i class="fas fa-warehouse fa-2x text-gray-300"></i>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <!-- Retail Customers -->
    <div class="col-xl-4 col-md-6 mb-4">
        <div class="card border-left-success shadow h-100 py-2">
            <div class="card-body">
                <div class="row no-gutters align-items-center">
                    <div class="col mr-2">
                        <div class="text-xs font-weight-bold text-success text-uppercase mb-1">
                            Retail Customers</div>
                        <div class="h5 mb-0 font-weight-bold text-gray-800">
                            <?php echo number_format($typeCounts['retail']); ?>
                        </div>
                    </div>
                    <div class="col-auto">
                        <i class="fas fa-user fa-2x text-gray-300"></i>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<!-- Filters -->
<div class="card mb-4">
    <div class="card-header">
        <i class="fas fa-filter"></i> Filter Customers
    </div>
    <div class="card-body">
        <form method="get" action="" class="row g-3">
            <div class="col-md-4">
                <label for="type" class="form-label">Customer Type</label>
                <select name="type" id="type" class="form-select">
                    <option value="">All Types</option>
                    <option value="wholesale" <?php echo ($customerType === 'wholesale') ? 'selected' : ''; ?>>Wholesale</option>
                    <option value="retail" <?php echo ($customerType === 'retail') ? 'selected' : ''; ?>>Retail</option>
                </select>
            </div>
            <div class="col-md-6">
                <label for="search" class="form-label">Search</label>
                <input type="text" class="form-control" id="search" name="search" value="<?php echo htmlspecialchars($searchTerm); ?>" placeholder="Search name, contact, phone, email...">
            </div>
            <div class="col-md-2 d-flex align-items-end">
                <div class="d-grid gap-2 w-100">
                    <button type="submit" class="btn btn-primary">Filter</button>
                    <a href="customers.php" class="btn btn-secondary">Reset</a>
                </div>
            </div>
        </form>
    </div>
</div>

<!-- Customers Table -->
<div class="card shadow mb-4">
    <div class="card-header py-3">
        <h6 class="m-0 font-weight-bold text-primary">Customers List</h6>
    </div>
    <div class="card-body">
        <div class="table-responsive">
            <table class="table table-bordered" width="100%" cellspacing="0">
                <thead>
                    <tr>
                        <th>ID</th>
                        <th>Name</th>
                        <th>Contact Person</th>
                        <th>Phone</th>
                        <th>Email</th>
                        <th>Type</th>
                        <th>Orders</th>
                        <th>Total Sales</th>
                        <th>Actions</th>
                    </tr>
                </thead>
                <tbody>
                    <?php if ($result && $result->num_rows > 0): ?>
                        <?php while ($row = $result->fetch_assoc()):
                            $stats = $salesStats[$row['id']] ?? [
                                'order_count' => 0,
                                'total_sales' => 0,
                                'total_paid' => 0,
                                'last_order_date' => null
                            ];
                        ?>
                            <tr>
                                <td><?php echo $row['id']; ?></td>
                                <td><?php echo htmlspecialchars($row['name']); ?></td>
                                <td><?php echo htmlspecialchars($row['contact_person'] ?? 'N/A'); ?></td>
                                <td><?php echo htmlspecialchars($row['phone'] ?? 'N/A'); ?></td>
                                <td><?php echo htmlspecialchars($row['email'] ?? 'N/A'); ?></td>
                                <td>
                                    <span class="badge bg-<?php echo ($row['customer_type'] === 'wholesale') ? 'info' : 'success'; ?>">
                                        <?php echo ucfirst($row['customer_type']); ?>
                                    </span>
                                </td>
                                <td>
                                    <?php if ($stats['order_count'] > 0): ?>
                                        <?php echo number_format($stats['order_count']); ?>
                                        <small class="text-muted d-block">
                                            Last: <?php echo formatDate($stats['last_order_date']); ?>
                                        </small>
                                    <?php else: ?>
                                        <span class="badge bg-secondary">No Orders</span>
                                    <?php endif; ?>
                                </td>
                                <td>
                                    <?php if ($stats['total_sales'] > 0): ?>
                                        <?php echo formatCurrency($stats['total_sales']); ?>
                                        <?php if ($stats['total_paid'] < $stats['total_sales']): ?>
                                            <span class="badge bg-warning">
                                                <?php echo formatCurrency($stats['total_sales'] - $stats['total_paid']); ?> Unpaid
                                            </span>
                                        <?php endif; ?>
                                    <?php else: ?>
                                        ₹ 0.00
                                    <?php endif; ?>
                                </td>
                                <td>
                                    <div class="btn-group">
                                        <a href="edit_customer.php?id=<?php echo $row['id']; ?>" class="btn btn-primary btn-sm">
                                            <i class="fas fa-edit"></i>
                                        </a>
                                        <a href="orders.php?customer_id=<?php echo $row['id']; ?>" class="btn btn-info btn-sm">
                                            <i class="fas fa-shopping-cart"></i>
                                        </a>
                                        <a href="add_order.php?customer_id=<?php echo $row['id']; ?>" class="btn btn-success btn-sm">
                                            <i class="fas fa-plus"></i>
                                        </a>
                                        <a href="customers.php?delete=<?php echo $row['id']; ?>" class="btn btn-danger btn-sm" onclick="return confirm('Are you sure you want to delete this customer?');">
                                            <i class="fas fa-trash"></i>
                                        </a>
                                    </div>
                                </td>
                            </tr>
                        <?php endwhile; ?>
                    <?php else: ?>
                        <tr>
                            <td colspan="9" class="text-center">No customers found</td>
                        </tr>
                    <?php endif; ?>
                </tbody>
            </table>
        </div>
    </div>
</div>

<?php require_once '../includes/footer.php'; ?>