<?php

/**
 * Edit Customer Page
 * Allows editing existing customer information
 */
require_once '../includes/header.php';

// Check if ID is provided
if (!isset($_GET['id']) || empty($_GET['id'])) {
    setFlashMessage('Customer ID is required.', 'danger');
    redirect('sales/customers.php');
}

$id = (int)$_GET['id'];

// Get customer data
$sql = "SELECT * FROM customers WHERE id = $id";
$result = executeQuery($conn, $sql);

if (!$result || $result->num_rows === 0) {
    setFlashMessage('Customer not found.', 'danger');
    redirect('sales/customers.php');
}

$customer = $result->fetch_assoc();

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Sanitize input
    $name = sanitizeInput($conn, $_POST['name']);
    $contactPerson = sanitizeInput($conn, $_POST['contact_person']);
    $phone = sanitizeInput($conn, $_POST['phone']);
    $email = sanitizeInput($conn, $_POST['email']);
    $address = sanitizeInput($conn, $_POST['address']);
    $customerType = sanitizeInput($conn, $_POST['customer_type']);
    $notes = sanitizeInput($conn, $_POST['notes']);

    // Validate input
    $errors = [];

    if (empty($name)) {
        $errors[] = 'Customer name is required.';
    }

    if (empty($customerType)) {
        $errors[] = 'Customer type is required.';
    }

    if (!empty($email) && !filter_var($email, FILTER_VALIDATE_EMAIL)) {
        $errors[] = 'Please enter a valid email address.';
    }

    // If no errors, update data
    if (empty($errors)) {
        $sql = "UPDATE customers SET 
                name = '$name', 
                contact_person = " . (!empty($contactPerson) ? "'$contactPerson'" : "NULL") . ", 
                phone = " . (!empty($phone) ? "'$phone'" : "NULL") . ", 
                email = " . (!empty($email) ? "'$email'" : "NULL") . ", 
                address = " . (!empty($address) ? "'$address'" : "NULL") . ", 
                customer_type = '$customerType', 
                notes = " . (!empty($notes) ? "'$notes'" : "NULL") . "
                WHERE id = $id";

        if (executeQuery($conn, $sql)) {
            logActivity('edit_customer', "Updated customer ID: $id, Name: $name");

            setFlashMessage('Customer updated successfully.', 'success');
            redirect('sales/customers.php');
        } else {
            $errors[] = 'Error updating customer. Please try again.';
        }
    }
}

// Get customer's sales history
$salesSql = "SELECT 
             so.id,
             so.order_date,
             so.total_amount,
             so.paid_amount,
             so.payment_status,
             COUNT(soi.id) AS item_count
             FROM sales_orders so
             LEFT JOIN sales_order_items soi ON so.id = soi.sales_order_id
             WHERE so.customer_id = $id
             GROUP BY so.id
             ORDER BY so.order_date DESC
             LIMIT 5";
$salesResult = executeQuery($conn, $salesSql);
?>

<div class="d-flex justify-content-between align-items-center mb-4">
    <h1>Edit Customer</h1>
    <div>
        <a href="add_order.php?customer_id=<?php echo $id; ?>" class="btn btn-success me-2">
            <i class="fas fa-plus"></i> New Order
        </a>
        <a href="customers.php" class="btn btn-secondary">
            <i class="fas fa-arrow-left"></i> Back to Customers
        </a>
    </div>
</div>

<?php if (!empty($errors)): ?>
    <div class="alert alert-danger">
        <ul class="mb-0">
            <?php foreach ($errors as $error): ?>
                <li><?php echo $error; ?></li>
            <?php endforeach; ?>
        </ul>
    </div>
<?php endif; ?>

<div class="row">
    <div class="col-md-8">
        <div class="card shadow mb-4">
            <div class="card-header py-3">
                <h6 class="m-0 font-weight-bold text-primary">Customer Details</h6>
            </div>
            <div class="card-body">
                <form method="post" action="">
                    <div class="row mb-3">
                        <div class="col-md-6">
                            <label for="name" class="form-label">Customer Name *</label>
                            <input type="text" class="form-control" id="name" name="name" value="<?php echo htmlspecialchars($customer['name']); ?>" required>
                        </div>
                        <div class="col-md-6">
                            <label for="customer_type" class="form-label">Customer Type *</label>
                            <select name="customer_type" id="customer_type" class="form-select" required>
                                <option value="">Select Customer Type</option>
                                <option value="wholesale" <?php echo ($customer['customer_type'] === 'wholesale') ? 'selected' : ''; ?>>Wholesale</option>
                                <option value="retail" <?php echo ($customer['customer_type'] === 'retail') ? 'selected' : ''; ?>>Retail</option>
                            </select>
                            <small class="text-muted">Determines pricing for sales</small>
                        </div>
                    </div>

                    <div class="row mb-3">
                        <div class="col-md-6">
                            <label for="contact_person" class="form-label">Contact Person</label>
                            <input type="text" class="form-control" id="contact_person" name="contact_person" value="<?php echo htmlspecialchars($customer['contact_person'] ?? ''); ?>">
                        </div>
                        <div class="col-md-6">
                            <label for="phone" class="form-label">Phone Number</label>
                            <input type="text" class="form-control" id="phone" name="phone" value="<?php echo htmlspecialchars($customer['phone'] ?? ''); ?>">
                        </div>
                    </div>

                    <div class="row mb-3">
                        <div class="col-md-6">
                            <label for="email" class="form-label">Email Address</label>
                            <input type="email" class="form-control" id="email" name="email" value="<?php echo htmlspecialchars($customer['email'] ?? ''); ?>">
                        </div>
                        <div class="col-md-6">
                            <label for="address" class="form-label">Address</label>
                            <textarea class="form-control" id="address" name="address" rows="2"><?php echo htmlspecialchars($customer['address'] ?? ''); ?></textarea>
                        </div>
                    </div>

                    <div class="mb-3">
                        <label for="notes" class="form-label">Notes</label>
                        <textarea class="form-control" id="notes" name="notes" rows="3"><?php echo htmlspecialchars($customer['notes'] ?? ''); ?></textarea>
                    </div>

                    <div class="d-grid gap-2 d-md-flex justify-content-md-end">
                        <a href="customers.php" class="btn btn-secondary me-md-2">Cancel</a>
                        <button type="submit" class="btn btn-primary">Update Customer</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <div class="col-md-4">
        <div class="card shadow mb-4">
            <div class="card-header py-3">
                <h6 class="m-0 font-weight-bold text-primary">Customer Summary</h6>
            </div>
            <div class="card-body">
                <div class="mb-3">
                    <span class="badge bg-<?php echo ($customer['customer_type'] === 'wholesale') ? 'info' : 'success'; ?> d-block p-2 mb-2">
                        <?php echo ucfirst($customer['customer_type']); ?> Customer
                    </span>
                </div>

                <?php
                // Get summary stats
                $statsSql = "SELECT 
                             COUNT(id) AS order_count, 
                             SUM(total_amount) AS total_sales, 
                             SUM(paid_amount) AS total_paid,
                             MAX(order_date) AS last_order_date
                             FROM sales_orders 
                             WHERE customer_id = $id";
                $statsResult = executeQuery($conn, $statsSql);
                $stats = $statsResult->fetch_assoc();

                $orderCount = $stats['order_count'] ?? 0;
                $totalSales = $stats['total_sales'] ?? 0;
                $totalPaid = $stats['total_paid'] ?? 0;
                $lastOrderDate = $stats['last_order_date'] ?? null;
                $outstanding = $totalSales - $totalPaid;
                ?>

                <div class="mb-3">
                    <p><strong>Total Orders:</strong> <?php echo number_format($orderCount); ?></p>
                    <p><strong>Total Sales:</strong> <?php echo formatCurrency($totalSales); ?></p>
                    <p><strong>Amount Paid:</strong> <?php echo formatCurrency($totalPaid); ?></p>
                    <p><strong>Outstanding:</strong> <?php echo formatCurrency($outstanding); ?></p>

                    <?php if ($lastOrderDate): ?>
                        <p><strong>Last Order:</strong> <?php echo formatDate($lastOrderDate); ?></p>
                    <?php endif; ?>
                </div>

                <div class="d-grid gap-2">
                    <a href="orders.php?customer_id=<?php echo $id; ?>" class="btn btn-info btn-sm">
                        <i class="fas fa-history"></i> View All Orders
                    </a>
                    <a href="add_order.php?customer_id=<?php echo $id; ?>" class="btn btn-success btn-sm">
                        <i class="fas fa-plus"></i> Create New Order
                    </a>
                </div>
            </div>
        </div>
    </div>
</div>

<!-- Recent Orders -->
<?php if ($salesResult && $salesResult->num_rows > 0): ?>
    <div class="card shadow mb-4">
        <div class="card-header py-3">
            <h6 class="m-0 font-weight-bold text-primary">Recent Orders</h6>
        </div>
        <div class="card-body">
            <div class="table-responsive">
                <table class="table table-bordered" width="100%" cellspacing="0">
                    <thead>
                        <tr>
                            <th>Order ID</th>
                            <th>Date</th>
                            <th>Items</th>
                            <th>Total Amount</th>
                            <th>Amount Paid</th>
                            <th>Status</th>
                            <th>Actions</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php while ($order = $salesResult->fetch_assoc()): ?>
                            <tr>
                                <td><?php echo $order['id']; ?></td>
                                <td><?php echo formatDate($order['order_date']); ?></td>
                                <td><?php echo number_format($order['item_count']); ?></td>
                                <td><?php echo formatCurrency($order['total_amount']); ?></td>
                                <td><?php echo formatCurrency($order['paid_amount']); ?></td>
                                <td>
                                    <span class="badge bg-<?php
                                                            echo ($order['payment_status'] === 'paid') ? 'success' : (($order['payment_status'] === 'partial') ? 'warning' : 'danger');
                                                            ?>">
                                        <?php echo ucfirst($order['payment_status']); ?>
                                    </span>
                                </td>
                                <td>
                                    <a href="edit_order.php?id=<?php echo $order['id']; ?>" class="btn btn-primary btn-sm">
                                        <i class="fas fa-edit"></i>
                                    </a>
                                    <?php if ($order['payment_status'] !== 'paid'): ?>
                                        <a href="payments.php?order_id=<?php echo $order['id']; ?>" class="btn btn-success btn-sm">
                                            <i class="fas fa-money-bill-wave"></i>
                                        </a>
                                    <?php endif; ?>
                                </td>
                            </tr>
                        <?php endwhile; ?>
                    </tbody>
                </table>
            </div>
            <div class="text-center mt-3">
                <a href="orders.php?customer_id=<?php echo $id; ?>" class="btn btn-primary">View All Orders</a>
            </div>
        </div>
    </div>
<?php endif; ?>

<?php require_once '../includes/footer.php'; ?>