<?php

/**
 * Edit Sales Order Page
 * Allows viewing and editing existing sales orders
 */
require_once '../includes/header.php';

// Check if ID is provided
if (!isset($_GET['id']) || empty($_GET['id'])) {
    setFlashMessage('Sales order ID is required.', 'danger');
    redirect('sales/orders.php');
}

$id = (int)$_GET['id'];

// Get order data
$sql = "SELECT so.*, c.name AS customer_name, c.customer_type, c.contact_person, c.phone, c.address
        FROM sales_orders so
        JOIN customers c ON so.customer_id = c.id
        WHERE so.id = $id";
$result = executeQuery($conn, $sql);

if (!$result || $result->num_rows === 0) {
    setFlashMessage('Sales order not found.', 'danger');
    redirect('sales/orders.php');
}

$order = $result->fetch_assoc();

// Get order items
$itemsSql = "SELECT soi.*, b.title, b.author
            FROM sales_order_items soi
            JOIN books b ON soi.book_id = b.id
            WHERE soi.sales_order_id = $id";
$itemsResult = executeQuery($conn, $itemsSql);
$orderItems = [];

if ($itemsResult && $itemsResult->num_rows > 0) {
    while ($item = $itemsResult->fetch_assoc()) {
        $orderItems[] = $item;
    }
}

// Get payments
$paymentsSql = "SELECT * FROM payments WHERE sales_order_id = $id ORDER BY payment_date";
$paymentsResult = executeQuery($conn, $paymentsSql);
$payments = [];

if ($paymentsResult && $paymentsResult->num_rows > 0) {
    while ($payment = $paymentsResult->fetch_assoc()) {
        $payments[] = $payment;
    }
}

$totalPaid = array_sum(array_column($payments, 'amount'));
$outstanding = $order['total_amount'] - $totalPaid;

// Handle notes update
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['update_notes'])) {
    $notes = sanitizeInput($conn, $_POST['notes']);

    $updateSql = "UPDATE sales_orders SET notes = '$notes' WHERE id = $id";

    if (executeQuery($conn, $updateSql)) {
        setFlashMessage('Order notes updated successfully.', 'success');
        logActivity('update_order_notes', "Updated notes for sales order #$id");

        // Update the order data
        $order['notes'] = $notes;
    } else {
        setFlashMessage('Error updating order notes.', 'danger');
    }
}
?>

<div class="d-flex justify-content-between align-items-center mb-4">
    <h1>Sales Order #<?php echo $id; ?></h1>
    <div>
        <?php if ($order['payment_status'] !== 'paid'): ?>
            <a href="payments.php?order_id=<?php echo $id; ?>" class="btn btn-success me-2">
                <i class="fas fa-money-bill-wave"></i> Add Payment
            </a>
        <?php endif; ?>
        <a href="orders.php" class="btn btn-secondary">
            <i class="fas fa-arrow-left"></i> Back to Orders
        </a>
    </div>
</div>

<div class="row">
    <div class="col-md-8">
        <!-- Order Details -->
        <div class="card shadow mb-4">
            <div class="card-header py-3 d-flex justify-content-between align-items-center">
                <h6 class="m-0 font-weight-bold text-primary">Order Details</h6>
                <span class="badge bg-<?php
                                        echo ($order['payment_status'] === 'paid') ? 'success' : (($order['payment_status'] === 'partial') ? 'warning' : 'danger');
                                        ?>">
                    <?php echo ucfirst($order['payment_status']); ?>
                </span>
            </div>
            <div class="card-body">
                <div class="row mb-3">
                    <div class="col-md-6">
                        <p><strong>Order ID:</strong> <?php echo $id; ?></p>
                        <p><strong>Order Date:</strong> <?php echo formatDate($order['order_date']); ?></p>
                        <p><strong>Customer:</strong> <?php echo htmlspecialchars($order['customer_name']); ?></p>
                        <p><strong>Customer Type:</strong> <?php echo ucfirst($order['customer_type']); ?></p>
                    </div>
                    <div class="col-md-6">
                        <p><strong>Total Amount:</strong> <?php echo formatCurrency($order['total_amount']); ?></p>
                        <p><strong>Paid Amount:</strong> <?php echo formatCurrency($order['paid_amount']); ?></p>
                        <p><strong>Outstanding:</strong> <?php echo formatCurrency($outstanding); ?></p>
                        <p><strong>Created:</strong> <?php echo formatDate($order['created_at'], 'Y-m-d H:i:s'); ?></p>
                    </div>
                </div>

                <!-- Notes Form -->
                <form method="post" action="">
                    <div class="mb-3">
                        <label for="notes" class="form-label"><strong>Notes:</strong></label>
                        <textarea class="form-control" id="notes" name="notes" rows="3"><?php echo htmlspecialchars($order['notes'] ?? ''); ?></textarea>
                    </div>
                    <div class="d-grid gap-2 d-md-flex justify-content-md-end">
                        <button type="submit" name="update_notes" class="btn btn-primary btn-sm">Update Notes</button>
                    </div>
                </form>
            </div>
        </div>

        <!-- Order Items -->
        <div class="card shadow mb-4">
            <div class="card-header py-3">
                <h6 class="m-0 font-weight-bold text-primary">Order Items</h6>
            </div>
            <div class="card-body">
                <div class="table-responsive">
                    <table class="table table-bordered">
                        <thead>
                            <tr>
                                <th>Book</th>
                                <th>Author</th>
                                <th>Quantity</th>
                                <th>Unit Price</th>
                                <th>Total</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($orderItems as $item): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($item['title']); ?></td>
                                    <td><?php echo htmlspecialchars($item['author']); ?></td>
                                    <td><?php echo number_format($item['quantity']); ?></td>
                                    <td><?php echo formatCurrency($item['unit_price']); ?></td>
                                    <td><?php echo formatCurrency($item['total_price']); ?></td>
                                </tr>
                            <?php endforeach; ?>
                        </tbody>
                        <tfoot>
                            <tr>
                                <th colspan="4" class="text-end">Grand Total:</th>
                                <th><?php echo formatCurrency($order['total_amount']); ?></th>
                            </tr>
                        </tfoot>
                    </table>
                </div>
            </div>
        </div>

        <!-- Payments -->
        <div class="card shadow mb-4">
            <div class="card-header py-3 d-flex justify-content-between align-items-center">
                <h6 class="m-0 font-weight-bold text-primary">Payment History</h6>
                <?php if ($order['payment_status'] !== 'paid'): ?>
                    <a href="payments.php?order_id=<?php echo $id; ?>" class="btn btn-success btn-sm">
                        <i class="fas fa-plus"></i> Add Payment
                    </a>
                <?php endif; ?>
            </div>
            <div class="card-body">
                <?php if (!empty($payments)): ?>
                    <div class="table-responsive">
                        <table class="table table-bordered">
                            <thead>
                                <tr>
                                    <th>ID</th>
                                    <th>Date</th>
                                    <th>Amount</th>
                                    <th>Method</th>
                                    <th>Reference</th>
                                    <th>Notes</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($payments as $payment): ?>
                                    <tr>
                                        <td><?php echo $payment['id']; ?></td>
                                        <td><?php echo formatDate($payment['payment_date']); ?></td>
                                        <td><?php echo formatCurrency($payment['amount']); ?></td>
                                        <td><?php echo ucfirst(str_replace('_', ' ', $payment['payment_method'])); ?></td>
                                        <td><?php echo htmlspecialchars($payment['reference_number'] ?? 'N/A'); ?></td>
                                        <td><?php echo htmlspecialchars($payment['notes'] ?? ''); ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                            <tfoot>
                                <tr>
                                    <th colspan="2" class="text-end">Total Paid:</th>
                                    <th><?php echo formatCurrency($totalPaid); ?></th>
                                    <th colspan="3" class="text-end">
                                        Outstanding: <?php echo formatCurrency($outstanding); ?>
                                    </th>
                                </tr>
                            </tfoot>
                        </table>
                    </div>
                <?php else: ?>
                    <div class="alert alert-info">
                        <i class="fas fa-info-circle"></i> No payments have been recorded for this order yet.
                        <?php if ($order['payment_status'] !== 'paid'): ?>
                            <a href="payments.php?order_id=<?php echo $id; ?>" class="btn btn-success btn-sm ms-3">
                                Add Payment
                            </a>
                        <?php endif; ?>
                    </div>
                <?php endif; ?>
            </div>
        </div>
    </div>

    <div class="col-md-4">
        <!-- Payment Status -->
        <div class="card shadow mb-4">
            <div class="card-header py-3">
                <h6 class="m-0 font-weight-bold text-primary">Payment Status</h6>
            </div>
            <div class="card-body">
                <div class="chart-container mb-4" style="position: relative; height:180px; width:100%">
                    <canvas id="paymentChart"></canvas>
                </div>

                <div class="d-grid gap-2">
                    <?php if ($order['payment_status'] !== 'paid'): ?>
                        <a href="payments.php?order_id=<?php echo $id; ?>" class="btn btn-success">
                            <i class="fas fa-money-bill-wave"></i> Add Payment
                        </a>
                    <?php else: ?>
                        <button class="btn btn-success" disabled>
                            <i class="fas fa-check-circle"></i> Fully Paid
                        </button>
                    <?php endif; ?>
                </div>
            </div>
        </div>

        <!-- Customer Information -->
        <div class="card shadow mb-4">
            <div class="card-header py-3">
                <h6 class="m-0 font-weight-bold text-primary">Customer Information</h6>
            </div>
            <div class="card-body">
                <p><strong>Name:</strong> <?php echo htmlspecialchars($order['customer_name']); ?></p>
                <p><strong>Type:</strong> <?php echo ucfirst($order['customer_type']); ?></p>

                <?php if (!empty($order['contact_person'])): ?>
                    <p><strong>Contact Person:</strong> <?php echo htmlspecialchars($order['contact_person']); ?></p>
                <?php endif; ?>

                <?php if (!empty($order['phone'])): ?>
                    <p><strong>Phone:</strong> <?php echo htmlspecialchars($order['phone']); ?></p>
                <?php endif; ?>

                <?php if (!empty($order['address'])): ?>
                    <p><strong>Address:</strong> <?php echo htmlspecialchars($order['address']); ?></p>
                <?php endif; ?>

                <div class="d-grid gap-2 mt-3">
                    <a href="edit_customer.php?id=<?php echo $order['customer_id']; ?>" class="btn btn-info btn-sm">
                        <i class="fas fa-user"></i> View Customer
                    </a>
                </div>
            </div>
        </div>

        <!-- Actions -->
        <div class="card shadow mb-4">
            <div class="card-header py-3">
                <h6 class="m-0 font-weight-bold text-primary">Actions</h6>
            </div>
            <div class="card-body">
                <div class="d-grid gap-2">
                    <button class="btn btn-primary btn-sm" onclick="printOrder()">
                        <i class="fas fa-print"></i> Print Order
                    </button>

                    <?php if ($order['payment_status'] === 'pending'): ?>
                        <a href="orders.php?delete=<?php echo $id; ?>" class="btn btn-danger btn-sm" onclick="return confirm('Are you sure you want to delete this order?');">
                            <i class="fas fa-trash"></i> Delete Order
                        </a>
                    <?php endif; ?>

                    <a href="add_order.php?customer_id=<?php echo $order['customer_id']; ?>" class="btn btn-success btn-sm">
                        <i class="fas fa-plus"></i> New Order for This Customer
                    </a>
                </div>
            </div>
        </div>
    </div>
</div>

<!-- Printable Order Section (hidden) -->
<div id="printSection" style="display: none;">
    <div style="padding: 20px;">
        <div style="text-align: center; margin-bottom: 20px;">
            <h2>Darul Kitab</h2>
            <h3>Sales Order</h3>
        </div>

        <div style="margin-bottom: 20px;">
            <div style="float: left; width: 50%;">
                <p><strong>Order #:</strong> <?php echo $id; ?></p>
                <p><strong>Date:</strong> <?php echo formatDate($order['order_date']); ?></p>
                <p><strong>Customer:</strong> <?php echo htmlspecialchars($order['customer_name']); ?></p>
                <p><strong>Customer Type:</strong> <?php echo ucfirst($order['customer_type']); ?></p>

                <?php if (!empty($order['contact_person'])): ?>
                    <p><strong>Contact Person:</strong> <?php echo htmlspecialchars($order['contact_person']); ?></p>
                <?php endif; ?>

                <?php if (!empty($order['phone'])): ?>
                    <p><strong>Phone:</strong> <?php echo htmlspecialchars($order['phone']); ?></p>
                <?php endif; ?>
            </div>

            <div style="float: right; width: 50%; text-align: right;">
                <p><strong>Status:</strong> <?php echo ucfirst($order['payment_status']); ?></p>
                <p><strong>Total Amount:</strong> <?php echo formatCurrency($order['total_amount']); ?></p>
                <p><strong>Paid Amount:</strong> <?php echo formatCurrency($order['paid_amount']); ?></p>
                <p><strong>Outstanding:</strong> <?php echo formatCurrency($outstanding); ?></p>
            </div>
            <div style="clear: both;"></div>
        </div>

        <table style="width: 100%; border-collapse: collapse; margin-bottom: 20px;">
            <thead>
                <tr style="background-color: #f2f2f2;">
                    <th style="border: 1px solid #ddd; padding: 8px; text-align: left;">Book</th>
                    <th style="border: 1px solid #ddd; padding: 8px; text-align: left;">Author</th>
                    <th style="border: 1px solid #ddd; padding: 8px; text-align: right;">Quantity</th>
                    <th style="border: 1px solid #ddd; padding: 8px; text-align: right;">Unit Price</th>
                    <th style="border: 1px solid #ddd; padding: 8px; text-align: right;">Total</th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($orderItems as $item): ?>
                    <tr>
                        <td style="border: 1px solid #ddd; padding: 8px;"><?php echo htmlspecialchars($item['title']); ?></td>
                        <td style="border: 1px solid #ddd; padding: 8px;"><?php echo htmlspecialchars($item['author']); ?></td>
                        <td style="border: 1px solid #ddd; padding: 8px; text-align: right;"><?php echo number_format($item['quantity']); ?></td>
                        <td style="border: 1px solid #ddd; padding: 8px; text-align: right;"><?php echo formatCurrency($item['unit_price']); ?></td>
                        <td style="border: 1px solid #ddd; padding: 8px; text-align: right;"><?php echo formatCurrency($item['total_price']); ?></td>
                    </tr>
                <?php endforeach; ?>
            </tbody>
            <tfoot>
                <tr style="background-color: #f2f2f2;">
                    <th colspan="4" style="border: 1px solid #ddd; padding: 8px; text-align: right;">Grand Total:</th>
                    <th style="border: 1px solid #ddd; padding: 8px; text-align: right;"><?php echo formatCurrency($order['total_amount']); ?></th>
                </tr>
            </tfoot>
        </table>

        <?php if (!empty($payments)): ?>
            <h4>Payment History</h4>
            <table style="width: 100%; border-collapse: collapse; margin-bottom: 20px;">
                <thead>
                    <tr style="background-color: #f2f2f2;">
                        <th style="border: 1px solid #ddd; padding: 8px; text-align: left;">Date</th>
                        <th style="border: 1px solid #ddd; padding: 8px; text-align: right;">Amount</th>
                        <th style="border: 1px solid #ddd; padding: 8px; text-align: left;">Method</th>
                        <th style="border: 1px solid #ddd; padding: 8px; text-align: left;">Reference</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($payments as $payment): ?>
                        <tr>
                            <td style="border: 1px solid #ddd; padding: 8px;"><?php echo formatDate($payment['payment_date']); ?></td>
                            <td style="border: 1px solid #ddd; padding: 8px; text-align: right;"><?php echo formatCurrency($payment['amount']); ?></td>
                            <td style="border: 1px solid #ddd; padding: 8px;"><?php echo ucfirst(str_replace('_', ' ', $payment['payment_method'])); ?></td>
                            <td style="border: 1px solid #ddd; padding: 8px;"><?php echo htmlspecialchars($payment['reference_number'] ?? 'N/A'); ?></td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
                <tfoot>
                    <tr style="background-color: #f2f2f2;">
                        <th style="border: 1px solid #ddd; padding: 8px; text-align: right;">Total Paid:</th>
                        <th style="border: 1px solid #ddd; padding: 8px; text-align: right;"><?php echo formatCurrency($totalPaid); ?></th>
                        <th colspan="2" style="border: 1px solid #ddd; padding: 8px; text-align: right;">
                            Outstanding: <?php echo formatCurrency($outstanding); ?>
                        </th>
                    </tr>
                </tfoot>
            </table>
        <?php endif; ?>

        <?php if (!empty($order['notes'])): ?>
            <div style="margin-top: 20px;">
                <h4>Notes:</h4>
                <p><?php echo nl2br(htmlspecialchars($order['notes'])); ?></p>
            </div>
        <?php endif; ?>

        <div style="margin-top: 40px; text-align: center; font-size: 12px;">
            <p>This is a computer-generated document. No signature required.</p>
            <p>Thank you for your business!</p>
        </div>
    </div>
</div>

<!-- Charts.js Script -->
<script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
<script>
    // Payment Chart
    const ctx = document.getElementById('paymentChart').getContext('2d');
    const paymentChart = new Chart(ctx, {
        type: 'doughnut',
        data: {
            labels: ['Paid', 'Outstanding'],
            datasets: [{
                data: [
                    <?php echo $order['paid_amount']; ?>,
                    <?php echo $outstanding; ?>
                ],
                backgroundColor: [
                    'rgba(40, 167, 69, 0.8)',
                    'rgba(231, 74, 59, 0.8)'
                ],
                borderColor: [
                    'rgba(40, 167, 69, 1)',
                    'rgba(231, 74, 59, 1)'
                ],
                borderWidth: 1
            }]
        },
        options: {
            responsive: true,
            maintainAspectRatio: false,
            plugins: {
                legend: {
                    position: 'bottom'
                },
                tooltip: {
                    callbacks: {
                        label: function(context) {
                            const label = context.label || '';
                            const value = context.raw || 0;
                            const total = <?php echo $order['total_amount']; ?>;
                            const percentage = ((value / total) * 100).toFixed(1);
                            return `${label}: ₹${value.toLocaleString('en-IN', { minimumFractionDigits: 2, maximumFractionDigits: 2 })} (${percentage}%)`;
                        }
                    }
                }
            }
        }
    });

    // Print Order Function
    function printOrder() {
        const printContent = document.getElementById('printSection').innerHTML;
        const originalContent = document.body.innerHTML;

        document.body.innerHTML = printContent;
        window.print();
        document.body.innerHTML = originalContent;

        // Reinitialize chart after printing
        const ctx = document.getElementById('paymentChart').getContext('2d');
        const paymentChart = new Chart(ctx, {
            type: 'doughnut',
            data: {
                labels: ['Paid', 'Outstanding'],
                datasets: [{
                    data: [
                        <?php echo $order['paid_amount']; ?>,
                        <?php echo $outstanding; ?>
                    ],
                    backgroundColor: [
                        'rgba(40, 167, 69, 0.8)',
                        'rgba(231, 74, 59, 0.8)'
                    ],
                    borderColor: [
                        'rgba(40, 167, 69, 1)',
                        'rgba(231, 74, 59, 1)'
                    ],
                    borderWidth: 1
                }]
            },
            options: {
                responsive: true,
                maintainAspectRatio: false,
                plugins: {
                    legend: {
                        position: 'bottom'
                    },
                    tooltip: {
                        callbacks: {
                            label: function(context) {
                                const label = context.label || '';
                                const value = context.raw || 0;
                                const total = <?php echo $order['total_amount']; ?>;
                                const percentage = ((value / total) * 100).toFixed(1);
                                return `${label}: ₹${value.toLocaleString('en-IN', { minimumFractionDigits: 2, maximumFractionDigits: 2 })} (${percentage}%)`;
                            }
                        }
                    }
                }
            }
        });
    }
</script>

<?php require_once '../includes/footer.php'; ?>