<?php

/**
 * Sales Orders Page
 * Manages sales orders
 */
require_once '../includes/header.php';

// Check if there's a new order action
$isNewOrder = isset($_GET['action']) && $_GET['action'] === 'new';
if ($isNewOrder) {
    redirect('sales/add_order.php');
}

// Handle delete request
if (isset($_GET['delete']) && !empty($_GET['delete'])) {
    $id = (int)$_GET['delete'];

    // Check if order is already paid
    $checkSql = "SELECT payment_status FROM sales_orders WHERE id = $id";
    $checkResult = executeQuery($conn, $checkSql);
    $order = $checkResult->fetch_assoc();

    if ($order && $order['payment_status'] === 'paid') {
        setFlashMessage('Cannot delete a fully paid order.', 'danger');
    } else {
        // Start transaction
        $conn->begin_transaction();

        try {
            // Delete order items first
            $deleteItemsSql = "DELETE FROM sales_order_items WHERE sales_order_id = $id";
            executeQuery($conn, $deleteItemsSql);

            // Delete payments
            $deletePaymentsSql = "DELETE FROM payments WHERE sales_order_id = $id";
            executeQuery($conn, $deletePaymentsSql);

            // Delete order
            $deleteOrderSql = "DELETE FROM sales_orders WHERE id = $id";
            executeQuery($conn, $deleteOrderSql);

            // Commit transaction
            $conn->commit();

            setFlashMessage('Sales order deleted successfully.', 'success');
            logActivity('delete_order', "Deleted sales order ID: $id");
        } catch (Exception $e) {
            // Rollback on error
            $conn->rollback();
            setFlashMessage('Error deleting sales order: ' . $e->getMessage(), 'danger');
        }
    }
    redirect('sales/orders.php');
}

// Get filter parameters
$customerId = isset($_GET['customer_id']) ? (int)$_GET['customer_id'] : 0;
$status = isset($_GET['status']) ? sanitizeInput($conn, $_GET['status']) : '';
$dateFrom = isset($_GET['date_from']) ? sanitizeInput($conn, $_GET['date_from']) : '';
$dateTo = isset($_GET['date_to']) ? sanitizeInput($conn, $_GET['date_to']) : '';

// Build query with filters
$sql = "SELECT so.*, c.name AS customer_name, c.customer_type
        FROM sales_orders so
        JOIN customers c ON so.customer_id = c.id
        WHERE 1=1";

if ($customerId > 0) {
    $sql .= " AND so.customer_id = $customerId";
}

if (!empty($status)) {
    $sql .= " AND so.payment_status = '$status'";
}

if (!empty($dateFrom)) {
    $sql .= " AND so.order_date >= '$dateFrom'";
}

if (!empty($dateTo)) {
    $sql .= " AND so.order_date <= '$dateTo'";
}

$sql .= " ORDER BY so.order_date DESC";

$result = executeQuery($conn, $sql);

// Get customer list for filter dropdown
$customersSql = "SELECT id, name, customer_type FROM customers ORDER BY name";
$customersResult = executeQuery($conn, $customersSql);
$customers = [];

if ($customersResult && $customersResult->num_rows > 0) {
    while ($customer = $customersResult->fetch_assoc()) {
        $customers[$customer['id']] = $customer;
    }
}

// Get order statistics
$statsSql = "SELECT 
              COUNT(*) AS total_orders,
              SUM(total_amount) AS total_sales,
              SUM(paid_amount) AS total_paid,
              SUM(total_amount - paid_amount) AS total_outstanding,
              SUM(CASE WHEN payment_status = 'pending' THEN 1 ELSE 0 END) AS pending_count,
              SUM(CASE WHEN payment_status = 'partial' THEN 1 ELSE 0 END) AS partial_count,
              SUM(CASE WHEN payment_status = 'paid' THEN 1 ELSE 0 END) AS paid_count
            FROM sales_orders";
$statsResult = executeQuery($conn, $statsSql);
$stats = $statsResult->fetch_assoc();
?>

<div class="d-flex justify-content-between align-items-center mb-4">
    <h1><?php echo $customerId > 0 ? 'Customer Orders' : 'Sales Orders'; ?></h1>
    <a href="add_order.php" class="btn btn-primary">
        <i class="fas fa-plus"></i> New Sales Order
    </a>
</div>

<!-- Order Stats Cards -->
<div class="row mb-4">
    <!-- Total Orders -->
    <div class="col-xl-3 col-md-6 mb-4">
        <div class="card border-left-primary shadow h-100 py-2">
            <div class="card-body">
                <div class="row no-gutters align-items-center">
                    <div class="col mr-2">
                        <div class="text-xs font-weight-bold text-primary text-uppercase mb-1">
                            Total Orders</div>
                        <div class="h5 mb-0 font-weight-bold text-gray-800">
                            <?php echo number_format($stats['total_orders']); ?>
                        </div>
                    </div>
                    <div class="col-auto">
                        <i class="fas fa-shopping-cart fa-2x text-gray-300"></i>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <!-- Total Sales -->
    <div class="col-xl-3 col-md-6 mb-4">
        <div class="card border-left-success shadow h-100 py-2">
            <div class="card-body">
                <div class="row no-gutters align-items-center">
                    <div class="col mr-2">
                        <div class="text-xs font-weight-bold text-success text-uppercase mb-1">
                            Total Sales</div>
                        <div class="h5 mb-0 font-weight-bold text-gray-800">
                            <?php echo formatCurrency($stats['total_sales']); ?>
                        </div>
                    </div>
                    <div class="col-auto">
                        <i class="fas fa-dollar-sign fa-2x text-gray-300"></i>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <!-- Amount Received -->
    <div class="col-xl-3 col-md-6 mb-4">
        <div class="card border-left-info shadow h-100 py-2">
            <div class="card-body">
                <div class="row no-gutters align-items-center">
                    <div class="col mr-2">
                        <div class="text-xs font-weight-bold text-info text-uppercase mb-1">
                            Amount Received</div>
                        <div class="h5 mb-0 font-weight-bold text-gray-800">
                            <?php echo formatCurrency($stats['total_paid']); ?>
                        </div>
                    </div>
                    <div class="col-auto">
                        <i class="fas fa-money-bill-wave fa-2x text-gray-300"></i>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <!-- Outstanding Amount -->
    <div class="col-xl-3 col-md-6 mb-4">
        <div class="card border-left-warning shadow h-100 py-2">
            <div class="card-body">
                <div class="row no-gutters align-items-center">
                    <div class="col mr-2">
                        <div class="text-xs font-weight-bold text-warning text-uppercase mb-1">
                            Outstanding Amount</div>
                        <div class="h5 mb-0 font-weight-bold text-gray-800">
                            <?php echo formatCurrency($stats['total_outstanding']); ?>
                        </div>
                    </div>
                    <div class="col-auto">
                        <i class="fas fa-clock fa-2x text-gray-300"></i>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<!-- Filters -->
<div class="card mb-4">
    <div class="card-header">
        <i class="fas fa-filter"></i> Filter Orders
    </div>
    <div class="card-body">
        <form method="get" action="" class="row g-3">
            <div class="col-md-3">
                <label for="customer_id" class="form-label">Customer</label>
                <select name="customer_id" id="customer_id" class="form-select">
                    <option value="">All Customers</option>
                    <?php foreach ($customers as $id => $customer): ?>
                        <option value="<?php echo $id; ?>" <?php echo ($customerId == $id) ? 'selected' : ''; ?>>
                            <?php echo htmlspecialchars($customer['name']); ?>
                            (<?php echo ucfirst($customer['customer_type']); ?>)
                        </option>
                    <?php endforeach; ?>
                </select>
            </div>
            <div class="col-md-3">
                <label for="status" class="form-label">Payment Status</label>
                <select name="status" id="status" class="form-select">
                    <option value="">All Statuses</option>
                    <option value="pending" <?php echo ($status === 'pending') ? 'selected' : ''; ?>>Pending</option>
                    <option value="partial" <?php echo ($status === 'partial') ? 'selected' : ''; ?>>Partial</option>
                    <option value="paid" <?php echo ($status === 'paid') ? 'selected' : ''; ?>>Paid</option>
                </select>
            </div>
            <div class="col-md-2">
                <label for="date_from" class="form-label">Date From</label>
                <input type="date" class="form-control" id="date_from" name="date_from" value="<?php echo htmlspecialchars($dateFrom); ?>">
            </div>
            <div class="col-md-2">
                <label for="date_to" class="form-label">Date To</label>
                <input type="date" class="form-control" id="date_to" name="date_to" value="<?php echo htmlspecialchars($dateTo); ?>">
            </div>
            <div class="col-md-2 d-flex align-items-end">
                <div class="d-grid gap-2 w-100">
                    <button type="submit" class="btn btn-primary">Filter</button>
                    <a href="orders.php" class="btn btn-secondary">Reset</a>
                </div>
            </div>
        </form>
    </div>
</div>

<!-- Payment Status Summary -->
<div class="card shadow mb-4">
    <div class="card-header py-3">
        <h6 class="m-0 font-weight-bold text-primary">Payment Status</h6>
    </div>
    <div class="card-body">
        <div class="row">
            <div class="col-md-8">
                <div class="chart-container" style="position: relative; height:200px; width:100%">
                    <canvas id="paymentStatusChart"></canvas>
                </div>
            </div>
            <div class="col-md-4">
                <div class="table-responsive">
                    <table class="table table-bordered">
                        <tr>
                            <th>Status</th>
                            <th>Count</th>
                            <th>Percentage</th>
                        </tr>
                        <tr>
                            <td>
                                <span class="badge bg-danger">Pending</span>
                            </td>
                            <td><?php echo number_format($stats['pending_count']); ?></td>
                            <td><?php echo number_format(($stats['total_orders'] > 0) ? ($stats['pending_count'] / $stats['total_orders'] * 100) : 0, 1); ?>%</td>
                        </tr>
                        <tr>
                            <td>
                                <span class="badge bg-warning">Partial</span>
                            </td>
                            <td><?php echo number_format($stats['partial_count']); ?></td>
                            <td><?php echo number_format(($stats['total_orders'] > 0) ? ($stats['partial_count'] / $stats['total_orders'] * 100) : 0, 1); ?>%</td>
                        </tr>
                        <tr>
                            <td>
                                <span class="badge bg-success">Paid</span>
                            </td>
                            <td><?php echo number_format($stats['paid_count']); ?></td>
                            <td><?php echo number_format(($stats['total_orders'] > 0) ? ($stats['paid_count'] / $stats['total_orders'] * 100) : 0, 1); ?>%</td>
                        </tr>
                    </table>
                </div>
            </div>
        </div>
    </div>
</div>

<!-- Orders Table -->
<div class="card shadow mb-4">
    <div class="card-header py-3 d-flex justify-content-between align-items-center">
        <h6 class="m-0 font-weight-bold text-primary">Sales Orders</h6>
        <?php if ($customerId > 0 && isset($customers[$customerId])): ?>
            <h6 class="m-0">Customer: <?php echo htmlspecialchars($customers[$customerId]['name']); ?></h6>
        <?php endif; ?>
    </div>
    <div class="card-body">
        <div class="table-responsive">
            <table class="table table-bordered" width="100%" cellspacing="0">
                <thead>
                    <tr>
                        <th>ID</th>
                        <th>Date</th>
                        <th>Customer</th>
                        <th>Type</th>
                        <th>Total Amount</th>
                        <th>Paid Amount</th>
                        <th>Outstanding</th>
                        <th>Status</th>
                        <th>Actions</th>
                    </tr>
                </thead>
                <tbody>
                    <?php if ($result && $result->num_rows > 0): ?>
                        <?php while ($row = $result->fetch_assoc()):
                            $outstanding = $row['total_amount'] - $row['paid_amount'];
                        ?>
                            <tr>
                                <td><?php echo $row['id']; ?></td>
                                <td><?php echo formatDate($row['order_date']); ?></td>
                                <td>
                                    <a href="edit_customer.php?id=<?php echo $row['customer_id']; ?>">
                                        <?php echo htmlspecialchars($row['customer_name']); ?>
                                    </a>
                                </td>
                                <td>
                                    <span class="badge bg-<?php echo ($row['customer_type'] === 'wholesale') ? 'info' : 'success'; ?>">
                                        <?php echo ucfirst($row['customer_type']); ?>
                                    </span>
                                </td>
                                <td><?php echo formatCurrency($row['total_amount']); ?></td>
                                <td><?php echo formatCurrency($row['paid_amount']); ?></td>
                                <td><?php echo formatCurrency($outstanding); ?></td>
                                <td>
                                    <span class="badge bg-<?php
                                                            echo ($row['payment_status'] === 'paid') ? 'success' : (($row['payment_status'] === 'partial') ? 'warning' : 'danger');
                                                            ?>">
                                        <?php echo ucfirst($row['payment_status']); ?>
                                    </span>
                                </td>
                                <td>
                                    <div class="btn-group">
                                        <a href="edit_order.php?id=<?php echo $row['id']; ?>" class="btn btn-info btn-sm">
                                            <i class="fas fa-eye"></i>
                                        </a>
                                        <?php if ($row['payment_status'] !== 'paid'): ?>
                                            <a href="payments.php?order_id=<?php echo $row['id']; ?>" class="btn btn-success btn-sm">
                                                <i class="fas fa-money-bill-wave"></i>
                                            </a>
                                        <?php endif; ?>

                                        <?php if ($row['payment_status'] === 'pending'): ?>
                                            <a href="orders.php?delete=<?php echo $row['id']; ?>" class="btn btn-danger btn-sm" onclick="return confirm('Are you sure you want to delete this order?');">
                                                <i class="fas fa-trash"></i>
                                            </a>
                                        <?php endif; ?>
                                    </div>
                                </td>
                            </tr>
                        <?php endwhile; ?>
                    <?php else: ?>
                        <tr>
                            <td colspan="9" class="text-center">No sales orders found</td>
                        </tr>
                    <?php endif; ?>
                </tbody>
            </table>
        </div>
    </div>
</div>

<!-- Charts.js Script -->
<script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
<script>
    // Payment Status Chart
    const ctx = document.getElementById('paymentStatusChart').getContext('2d');
    const paymentStatusChart = new Chart(ctx, {
        type: 'pie',
        data: {
            labels: ['Pending', 'Partial', 'Paid'],
            datasets: [{
                data: [
                    <?php echo $stats['pending_count']; ?>,
                    <?php echo $stats['partial_count']; ?>,
                    <?php echo $stats['paid_count']; ?>
                ],
                backgroundColor: [
                    'rgba(231, 74, 59, 0.8)',
                    'rgba(246, 194, 62, 0.8)',
                    'rgba(40, 167, 69, 0.8)'
                ],
                borderColor: [
                    'rgba(231, 74, 59, 1)',
                    'rgba(246, 194, 62, 1)',
                    'rgba(40, 167, 69, 1)'
                ],
                borderWidth: 1
            }]
        },
        options: {
            responsive: true,
            maintainAspectRatio: false,
            plugins: {
                legend: {
                    position: 'right'
                }
            }
        }
    });
</script>

<?php require_once '../includes/footer.php'; ?>