<?php

/**
 * Payments Page
 * Manages payments for sales orders
 */
require_once '../includes/header.php';

// Get order ID if provided
$orderId = isset($_GET['order_id']) ? (int)$_GET['order_id'] : 0;

// Get order data if order ID is provided
$order = null;
if ($orderId > 0) {
    $orderSql = "SELECT so.*, c.name AS customer_name, c.customer_type
                FROM sales_orders so
                JOIN customers c ON so.customer_id = c.id
                WHERE so.id = $orderId";
    $orderResult = executeQuery($conn, $orderSql);

    if ($orderResult && $orderResult->num_rows > 0) {
        $order = $orderResult->fetch_assoc();
        $outstanding = $order['total_amount'] - $order['paid_amount'];
    } else {
        setFlashMessage('Sales order not found.', 'danger');
        redirect('sales/orders.php');
    }
}

// Handle payment deletion
if (isset($_GET['delete']) && !empty($_GET['delete'])) {
    $paymentId = (int)$_GET['delete'];

    // Start transaction
    $conn->begin_transaction();

    try {
        // Get payment details first
        $paymentSql = "SELECT * FROM payments WHERE id = $paymentId";
        $paymentResult = executeQuery($conn, $paymentSql);

        if ($paymentResult && $paymentResult->num_rows > 0) {
            $payment = $paymentResult->fetch_assoc();
            $paymentAmount = $payment['amount'];
            $paymentOrderId = $payment['sales_order_id'];

            // Delete the payment
            $deleteSql = "DELETE FROM payments WHERE id = $paymentId";
            executeQuery($conn, $deleteSql);

            // Update the order's paid amount
            $updateOrderSql = "UPDATE sales_orders SET 
                              paid_amount = paid_amount - $paymentAmount,
                              payment_status = CASE 
                                  WHEN (paid_amount - $paymentAmount) <= 0 THEN 'pending'
                                  WHEN (paid_amount - $paymentAmount) < total_amount THEN 'partial'
                                  ELSE payment_status
                              END
                              WHERE id = $paymentOrderId";
            executeQuery($conn, $updateOrderSql);

            // Commit transaction
            $conn->commit();

            setFlashMessage('Payment deleted successfully.', 'success');
            logActivity('delete_payment', "Deleted payment ID: $paymentId, Amount: $paymentAmount for order #$paymentOrderId");

            // If specific order page, stay there
            if ($orderId > 0) {
                redirect('sales/payments.php?order_id=' . $orderId);
            } else {
                redirect('sales/payments.php');
            }
        } else {
            throw new Exception('Payment not found.');
        }
    } catch (Exception $e) {
        // Rollback on error
        $conn->rollback();
        setFlashMessage('Error deleting payment: ' . $e->getMessage(), 'danger');

        if ($orderId > 0) {
            redirect('sales/payments.php?order_id=' . $orderId);
        } else {
            redirect('sales/payments.php');
        }
    }
}

// Handle payment form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['add_payment'])) {
    // Sanitize input
    $paymentOrderId = (int)$_POST['order_id'];
    $amount = (float)$_POST['amount'];
    $paymentDate = sanitizeInput($conn, $_POST['payment_date']);
    $paymentMethod = sanitizeInput($conn, $_POST['payment_method']);
    $referenceNumber = sanitizeInput($conn, $_POST['reference_number']);
    $notes = sanitizeInput($conn, $_POST['notes']);

    // Validate input
    $errors = [];

    if ($paymentOrderId <= 0) {
        $errors[] = 'Invalid order ID.';
    }

    if ($amount <= 0) {
        $errors[] = 'Amount must be greater than zero.';
    }

    if (empty($paymentDate)) {
        $errors[] = 'Payment date is required.';
    }

    if (empty($paymentMethod)) {
        $errors[] = 'Payment method is required.';
    }

    // Get order details to validate payment amount
    $orderDetailsSql = "SELECT * FROM sales_orders WHERE id = $paymentOrderId";
    $orderDetailsResult = executeQuery($conn, $orderDetailsSql);
    $orderDetails = $orderDetailsResult->fetch_assoc();

    $outstanding = $orderDetails['total_amount'] - $orderDetails['paid_amount'];

    if ($amount > $outstanding) {
        $errors[] = 'Payment amount exceeds outstanding balance. Maximum allowed: ' . formatCurrency($outstanding);
    }

    // If no errors, process payment
    if (empty($errors)) {
        // Start transaction
        $conn->begin_transaction();

        try {
            // Add payment record
            $paymentSql = "INSERT INTO payments (
                            sales_order_id, 
                            amount, 
                            payment_date, 
                            payment_method, 
                            reference_number, 
                            notes
                        ) VALUES (
                            $paymentOrderId, 
                            $amount, 
                            '$paymentDate', 
                            '$paymentMethod', 
                            " . (!empty($referenceNumber) ? "'$referenceNumber'" : "NULL") . ", 
                            " . (!empty($notes) ? "'$notes'" : "NULL") . "
                        )";

            executeQuery($conn, $paymentSql);

            // Update order paid amount and status
            $newPaidAmount = $orderDetails['paid_amount'] + $amount;
            $newPaymentStatus = ($newPaidAmount >= $orderDetails['total_amount']) ? 'paid' : (($newPaidAmount > 0) ? 'partial' : 'pending');

            $updateOrderSql = "UPDATE sales_orders SET 
                              paid_amount = $newPaidAmount,
                              payment_status = '$newPaymentStatus'
                              WHERE id = $paymentOrderId";

            executeQuery($conn, $updateOrderSql);

            // Commit transaction
            $conn->commit();

            logActivity('add_payment', "Added payment of $amount for order #$paymentOrderId");

            setFlashMessage('Payment added successfully.', 'success');

            // If payment was for a specific order, return to that order
            if ($orderId > 0) {
                redirect('sales/edit_order.php?id=' . $orderId);
            } else {
                redirect('sales/payments.php');
            }
        } catch (Exception $e) {
            // Rollback on error
            $conn->rollback();
            $errors[] = 'Error processing payment: ' . $e->getMessage();
        }
    }
}

// Get filter parameters
$customerFilter = isset($_GET['customer_id']) ? (int)$_GET['customer_id'] : 0;
$dateFrom = isset($_GET['date_from']) ? sanitizeInput($conn, $_GET['date_from']) : '';
$dateTo = isset($_GET['date_to']) ? sanitizeInput($conn, $_GET['date_to']) : '';
$methodFilter = isset($_GET['method']) ? sanitizeInput($conn, $_GET['method']) : '';

// Build query with filters
$sql = "SELECT p.*, so.customer_id, c.name AS customer_name
        FROM payments p
        JOIN sales_orders so ON p.sales_order_id = so.id
        JOIN customers c ON so.customer_id = c.id
        WHERE 1=1";

if ($customerFilter > 0) {
    $sql .= " AND so.customer_id = $customerFilter";
}

if (!empty($dateFrom)) {
    $sql .= " AND p.payment_date >= '$dateFrom'";
}

if (!empty($dateTo)) {
    $sql .= " AND p.payment_date <= '$dateTo'";
}

if (!empty($methodFilter)) {
    $sql .= " AND p.payment_method = '$methodFilter'";
}

// If viewing for a specific order
if ($orderId > 0) {
    $sql .= " AND p.sales_order_id = $orderId";
}

$sql .= " ORDER BY p.payment_date DESC";

$result = executeQuery($conn, $sql);

// Get customers list for filter dropdown
$customersSql = "SELECT id, name FROM customers ORDER BY name";
$customersResult = executeQuery($conn, $customersSql);
$customers = [];

if ($customersResult && $customersResult->num_rows > 0) {
    while ($customer = $customersResult->fetch_assoc()) {
        $customers[$customer['id']] = $customer['name'];
    }
}

// If adding a payment for a specific order, get orders with outstanding balance
$openOrdersSql = "SELECT so.id, so.order_date, c.name AS customer_name, 
                 so.total_amount, so.paid_amount, (so.total_amount - so.paid_amount) AS outstanding
                 FROM sales_orders so
                 JOIN customers c ON so.customer_id = c.id
                 WHERE so.payment_status != 'paid'
                 ORDER BY so.order_date DESC";
$openOrdersResult = executeQuery($conn, $openOrdersSql);
$openOrders = [];

if ($openOrdersResult && $openOrdersResult->num_rows > 0) {
    while ($openOrder = $openOrdersResult->fetch_assoc()) {
        $openOrders[$openOrder['id']] = $openOrder;
    }
}

// Get payment statistics
$statsSql = "SELECT 
              COUNT(*) AS total_payments,
              SUM(amount) AS total_amount,
              COUNT(DISTINCT sales_order_id) AS order_count
            FROM payments";
$statsResult = executeQuery($conn, $statsSql);
$stats = $statsResult->fetch_assoc();

// Get payment methods distribution
$methodsSql = "SELECT payment_method, COUNT(*) AS count, SUM(amount) AS total
              FROM payments
              GROUP BY payment_method";
$methodsResult = executeQuery($conn, $methodsSql);
$methodStats = [];

if ($methodsResult && $methodsResult->num_rows > 0) {
    while ($method = $methodsResult->fetch_assoc()) {
        $methodStats[$method['payment_method']] = [
            'count' => $method['count'],
            'total' => $method['total']
        ];
    }
}
?>

<div class="d-flex justify-content-between align-items-center mb-4">
    <h1>
        <?php echo $orderId > 0 ? 'Order Payments' : 'Payments Management'; ?>
    </h1>
    <?php if (!$orderId): ?>
        <button type="button" class="btn btn-primary" data-bs-toggle="modal" data-bs-target="#addPaymentModal">
            <i class="fas fa-plus"></i> Add Payment
        </button>
    <?php else: ?>
        <div>
            <a href="edit_order.php?id=<?php echo $orderId; ?>" class="btn btn-secondary me-2">
                <i class="fas fa-arrow-left"></i> Back to Order
            </a>
            <?php if ($order && $order['payment_status'] !== 'paid'): ?>
                <button type="button" class="btn btn-primary" data-bs-toggle="modal" data-bs-target="#addPaymentModal">
                    <i class="fas fa-plus"></i> Add Payment
                </button>
            <?php endif; ?>
        </div>
    <?php endif; ?>
</div>

<?php if (isset($errors) && !empty($errors)): ?>
    <div class="alert alert-danger">
        <ul class="mb-0">
            <?php foreach ($errors as $error): ?>
                <li><?php echo $error; ?></li>
            <?php endforeach; ?>
        </ul>
    </div>
<?php endif; ?>

<?php if ($orderId > 0 && $order): ?>
    <!-- Order Information -->
    <div class="card shadow mb-4">
        <div class="card-header py-3">
            <h6 class="m-0 font-weight-bold text-primary">Order Information</h6>
        </div>
        <div class="card-body">
            <div class="row">
                <div class="col-md-6">
                    <p><strong>Order #:</strong> <?php echo $orderId; ?></p>
                    <p><strong>Date:</strong> <?php echo formatDate($order['order_date']); ?></p>
                    <p><strong>Customer:</strong> <?php echo htmlspecialchars($order['customer_name']); ?></p>
                    <p><strong>Customer Type:</strong> <?php echo ucfirst($order['customer_type']); ?></p>
                </div>
                <div class="col-md-6">
                    <p><strong>Total Amount:</strong> <?php echo formatCurrency($order['total_amount']); ?></p>
                    <p><strong>Paid Amount:</strong> <?php echo formatCurrency($order['paid_amount']); ?></p>
                    <p><strong>Outstanding:</strong> <?php echo formatCurrency($outstanding); ?></p>
                    <p>
                        <strong>Status:</strong>
                        <span class="badge bg-<?php
                                                echo ($order['payment_status'] === 'paid') ? 'success' : (($order['payment_status'] === 'partial') ? 'warning' : 'danger');
                                                ?>">
                            <?php echo ucfirst($order['payment_status']); ?>
                        </span>
                    </p>
                </div>
            </div>
        </div>
    </div>
<?php else: ?>
    <!-- Payment Statistics -->
    <div class="row mb-4">
        <!-- Total Payments -->
        <div class="col-xl-4 col-md-6 mb-4">
            <div class="card border-left-primary shadow h-100 py-2">
                <div class="card-body">
                    <div class="row no-gutters align-items-center">
                        <div class="col mr-2">
                            <div class="text-xs font-weight-bold text-primary text-uppercase mb-1">
                                Total Payments</div>
                            <div class="h5 mb-0 font-weight-bold text-gray-800">
                                <?php echo number_format($stats['total_payments']); ?>
                            </div>
                        </div>
                        <div class="col-auto">
                            <i class="fas fa-money-check fa-2x text-gray-300"></i>
                        </div>
                    </div>
                </div>
            </div>
        </div>

        <!-- Total Amount -->
        <div class="col-xl-4 col-md-6 mb-4">
            <div class="card border-left-success shadow h-100 py-2">
                <div class="card-body">
                    <div class="row no-gutters align-items-center">
                        <div class="col mr-2">
                            <div class="text-xs font-weight-bold text-success text-uppercase mb-1">
                                Total Amount</div>
                            <div class="h5 mb-0 font-weight-bold text-gray-800">
                                <?php echo formatCurrency($stats['total_amount']); ?>
                            </div>
                        </div>
                        <div class="col-auto">
                            <i class="fas fa-dollar-sign fa-2x text-gray-300"></i>
                        </div>
                    </div>
                </div>
            </div>
        </div>

        <!-- Orders Paid -->
        <div class="col-xl-4 col-md-6 mb-4">
            <div class="card border-left-info shadow h-100 py-2">
                <div class="card-body">
                    <div class="row no-gutters align-items-center">
                        <div class="col mr-2">
                            <div class="text-xs font-weight-bold text-info text-uppercase mb-1">
                                Orders Paid</div>
                            <div class="h5 mb-0 font-weight-bold text-gray-800">
                                <?php echo number_format($stats['order_count']); ?>
                            </div>
                        </div>
                        <div class="col-auto">
                            <i class="fas fa-shopping-cart fa-2x text-gray-300"></i>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <!-- Filters -->
    <div class="card mb-4">
        <div class="card-header">
            <i class="fas fa-filter"></i> Filter Payments
        </div>
        <div class="card-body">
            <form method="get" action="" class="row g-3">
                <div class="col-md-3">
                    <label for="customer_id" class="form-label">Customer</label>
                    <select name="customer_id" id="customer_id" class="form-select">
                        <option value="">All Customers</option>
                        <?php foreach ($customers as $id => $name): ?>
                            <option value="<?php echo $id; ?>" <?php echo ($customerFilter == $id) ? 'selected' : ''; ?>>
                                <?php echo htmlspecialchars($name); ?>
                            </option>
                        <?php endforeach; ?>
                    </select>
                </div>
                <div class="col-md-3">
                    <label for="method" class="form-label">Payment Method</label>
                    <select name="method" id="method" class="form-select">
                        <option value="">All Methods</option>
                        <option value="cash" <?php echo ($methodFilter === 'cash') ? 'selected' : ''; ?>>Cash</option>
                        <option value="check" <?php echo ($methodFilter === 'check') ? 'selected' : ''; ?>>Check</option>
                        <option value="bank_transfer" <?php echo ($methodFilter === 'bank_transfer') ? 'selected' : ''; ?>>Bank Transfer</option>
                        <option value="other" <?php echo ($methodFilter === 'other') ? 'selected' : ''; ?>>Other</option>
                    </select>
                </div>
                <div class="col-md-2">
                    <label for="date_from" class="form-label">Date From</label>
                    <input type="date" class="form-control" id="date_from" name="date_from" value="<?php echo $dateFrom; ?>">
                </div>
                <div class="col-md-2">
                    <label for="date_to" class="form-label">Date To</label>
                    <input type="date" class="form-control" id="date_to" name="date_to" value="<?php echo $dateTo; ?>">
                </div>
                <div class="col-md-2 d-flex align-items-end">
                    <button type="submit" class="btn btn-primary me-2">Filter</button>
                    <a href="payments.php" class="btn btn-secondary">Reset</a>
                </div>
            </form>
        </div>
    </div>
<?php endif; ?>

<!-- Payments Table -->
<div class="card shadow mb-4">
    <div class="card-header py-3">
        <h6 class="m-0 font-weight-bold text-primary">
            <?php echo $orderId > 0 ? 'Order Payments History' : 'All Payments'; ?>
        </h6>
    </div>
    <div class="card-body">
        <?php if ($result && $result->num_rows > 0): ?>
            <div class="table-responsive">
                <table class="table table-bordered table-striped" id="paymentsTable" width="100%" cellspacing="0">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>Order #</th>
                            <?php if (!$orderId): ?><th>Customer</th><?php endif; ?>
                            <th>Date</th>
                            <th>Amount</th>
                            <th>Method</th>
                            <th>Reference</th>
                            <th>Notes</th>
                            <th>Actions</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php while ($row = $result->fetch_assoc()): ?>
                            <tr>
                                <td><?php echo $row['id']; ?></td>
                                <td>
                                    <a href="edit_order.php?id=<?php echo $row['sales_order_id']; ?>">
                                        <?php echo $row['sales_order_id']; ?>
                                    </a>
                                </td>
                                <?php if (!$orderId): ?>
                                    <td><?php echo htmlspecialchars($row['customer_name']); ?></td>
                                <?php endif; ?>
                                <td><?php echo formatDate($row['payment_date']); ?></td>
                                <td><?php echo formatCurrency($row['amount']); ?></td>
                                <td><?php echo ucfirst(str_replace('_', ' ', $row['payment_method'])); ?></td>
                                <td><?php echo !empty($row['reference_number']) ? htmlspecialchars($row['reference_number']) : '-'; ?></td>
                                <td><?php echo !empty($row['notes']) ? htmlspecialchars($row['notes']) : '-'; ?></td>
                                <td>
                                    <div class="btn-group">
                                        <button type="button" class="btn btn-sm btn-danger"
                                            onclick="confirmDelete(<?php echo $row['id']; ?>)">
                                            <i class="fas fa-trash"></i>
                                        </button>
                                    </div>
                                </td>
                            </tr>
                        <?php endwhile; ?>
                    </tbody>
                </table>
            </div>
        <?php else: ?>
            <div class="alert alert-info">
                No payments found.
            </div>
        <?php endif; ?>
    </div>
</div>

<!-- Add Payment Modal -->
<div class="modal fade" id="addPaymentModal" tabindex="-1" aria-labelledby="addPaymentModalLabel" aria-hidden="true">
    <div class="modal-dialog modal-lg">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="addPaymentModalLabel">Add Payment</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
            </div>
            <form method="post" action="">
                <div class="modal-body">
                    <div class="mb-3">
                        <label for="order_id" class="form-label">Order</label>
                        <?php if ($orderId > 0): ?>
                            <input type="hidden" name="order_id" value="<?php echo $orderId; ?>">
                            <input type="text" class="form-control" value="Order #<?php echo $orderId; ?> - <?php echo htmlspecialchars($order['customer_name']); ?>" readonly>
                        <?php else: ?>
                            <select name="order_id" id="order_id" class="form-select" required>
                                <option value="">Select Order</option>
                                <?php foreach ($openOrders as $id => $openOrder): ?>
                                    <option value="<?php echo $id; ?>" data-outstanding="<?php echo $openOrder['outstanding']; ?>">
                                        #<?php echo $id; ?> - <?php echo htmlspecialchars($openOrder['customer_name']); ?>
                                        (Outstanding: <?php echo formatCurrency($openOrder['outstanding']); ?>)
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        <?php endif; ?>
                    </div>
                    <div class="mb-3">
                        <label for="amount" class="form-label">Payment Amount</label>
                        <input type="number" step="0.01" min="0.01" class="form-control" id="amount" name="amount"
                            required <?php echo $orderId > 0 ? 'max="' . $outstanding . '"' : ''; ?>>
                        <?php if ($orderId > 0): ?>
                            <div class="form-text">Maximum amount: <?php echo formatCurrency($outstanding); ?></div>
                        <?php endif; ?>
                    </div>
                    <div class="mb-3">
                        <label for="payment_date" class="form-label">Payment Date</label>
                        <input type="date" class="form-control" id="payment_date" name="payment_date"
                            value="<?php echo date('Y-m-d'); ?>" required>
                    </div>
                    <div class="mb-3">
                        <label for="payment_method" class="form-label">Payment Method</label>
                        <select class="form-select" id="payment_method" name="payment_method" required>
                            <option value="">Select Method</option>
                            <option value="cash">Cash</option>
                            <option value="check">Check</option>
                            <option value="bank_transfer">Bank Transfer</option>
                            <option value="credit_card">Credit Card</option>
                            <option value="other">Other</option>
                        </select>
                    </div>
                    <div class="mb-3">
                        <label for="reference_number" class="form-label">Reference Number</label>
                        <input type="text" class="form-control" id="reference_number" name="reference_number">
                        <div class="form-text">Check number, transaction ID, etc.</div>
                    </div>
                    <div class="mb-3">
                        <label for="notes" class="form-label">Notes</label>
                        <textarea class="form-control" id="notes" name="notes" rows="3"></textarea>
                    </div>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Cancel</button>
                    <button type="submit" name="add_payment" class="btn btn-primary">Add Payment</button>
                </div>
            </form>
        </div>
    </div>
</div>

<!-- Delete Confirmation Modal -->
<div class="modal fade" id="deleteModal" tabindex="-1" aria-labelledby="deleteModalLabel" aria-hidden="true">
    <div class="modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="deleteModalLabel">Confirm Delete</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
            </div>
            <div class="modal-body">
                Are you sure you want to delete this payment? This action cannot be undone.
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Cancel</button>
                <a href="#" id="confirmDeleteButton" class="btn btn-danger">Delete</a>
            </div>
        </div>
    </div>
</div>

<script>
    // Initialize DataTable
    $(document).ready(function() {
        $('#paymentsTable').DataTable({
            order: [
                [3, 'desc']
            ], // Sort by date by default
            responsive: true
        });

        // Order select change handler - update max amount
        $('#order_id').on('change', function() {
            const selectedOption = $(this).find('option:selected');
            const outstanding = selectedOption.data('outstanding');

            if (outstanding) {
                $('#amount').attr('max', outstanding);
                $('#amount').next('.form-text').text('Maximum amount: ' + new Intl.NumberFormat('en-US', {
                    style: 'currency',
                    currency: 'USD'
                }).format(outstanding));
            } else {
                $('#amount').removeAttr('max');
                $('#amount').next('.form-text').text('');
            }
        });
    });

    // Delete confirmation
    function confirmDelete(paymentId) {
        const deleteUrl = 'payments.php?delete=' + paymentId +
            <?php echo $orderId > 0 ? "'&order_id=$orderId'" : "''"; ?>;
        $('#confirmDeleteButton').attr('href', deleteUrl);
        $('#deleteModal').modal('show');
    }
</script>

<?php require_once '../includes/footer.php'; ?>